AreaChartConfig class

Inheritance

Constructors

AreaChartConfig({required List<Series> series, XYAxis? xAxis, XYAxis? yAxis, double? maxY, double curveSmoothness = 0.2, bool showDots = true, double dotSize = 4.0, String areaColor = 'red', double areaOpacity = 0.2, bool gradientArea = true, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
AreaChartConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setterinherited
areaColor String
final
areaOpacity double
final
controller ChartController?
finalinherited
curveSmoothness double
finalinherited
dotSize double
finalinherited
gradientArea bool
final
grid GridData?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
legend ChartLegend?
finalinherited
maxY double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<Series>
finalinherited
showBelowArea bool
finalinherited
showDots bool
finalinherited
theme ChartTheme
finalinherited
title TitlesData?
finalinherited
toolbox ChartToolbox?
finalinherited
tooltip ChartTooltip?
finalinherited
type ChartType
finalinherited
xAxis XYAxis?
finalinherited
xAxisConfig ChartAxisConfig?
finalinherited
yAxis XYAxis?
finalinherited
yAxisConfig ChartAxisConfig?
finalinherited

Methods

buildChart() Widget
Method to create the appropriate chart widget
override
copyWith({List<Series>? series, XYAxis? xAxis, XYAxis? yAxis, double? maxY, bool? showBelowArea, double? curveSmoothness, bool? showDots, double? dotSize, String? areaColor, double? areaOpacity, bool? gradientArea, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig}) AreaChartConfig
override
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
inherited
toJson() Map<String, dynamic>
Convert configuration to JSON
override
toString() String
A string representation of this object.
inherited
withController(ChartController controller) AreaChartConfig
Override in concrete configs to return a controller-attached copy.
override
withTheme(ChartTheme theme) AreaChartConfig
Override in concrete configs to return a themed copy.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited