SimpleBarChart class
A lightweight, polished bar chart for small comparison datasets.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleBarChart
- Available extensions
Constructors
-
SimpleBarChart({Key? key, required List<
SimpleBarChartData> data, SimpleBarChartOrientation orientation = SimpleBarChartOrientation.vertical, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 240, EdgeInsets? padding, Color? barColor, Color? gridColor, Color? axisColor, Color? trackColor, Color? activeBarColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = true, bool showTrack = false, bool showTooltip = true, bool showActiveBar = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? barRadius, double? barWidthFactor, double? maxBarWidth, bool? useGradient, SimpleBarValueFormatter? valueFormatter, SimpleBarTapCallback? onBarTap, SimpleBarTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 650), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeBarColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- barColor → Color?
-
final
- barRadius → double?
-
final
- barWidthFactor → double?
-
final
-
data
→ List<
SimpleBarChartData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- maxBarWidth → double?
-
final
- maxValue → double?
-
final
- minValue → double?
-
final
- onBarTap → SimpleBarTapCallback?
-
final
- orientation → SimpleBarChartOrientation
-
final
- padding → EdgeInsets?
-
final
-
referenceBands
→ List<
SimpleChartReferenceBand> -
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveBar → bool
-
final
- showGrid → bool
-
final
- showTooltip → bool
-
final
- showTrack → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleBarTooltipBuilder?
-
final
- trackColor → Color?
-
final
- useGradient → bool?
-
final
- valueFormatter → SimpleBarValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited