SimpleBinnedDotPlotChart class

A compact distribution chart that stacks one or more observations as dots inside numeric bins.

Inheritance
Available extensions

Constructors

SimpleBinnedDotPlotChart({Key? key, List<double> values = const [], List<SimpleBinnedDotPlotBin> bins = const [], int binCount = 8, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 250, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? dotColor, Color? gridColor, Color? axisColor, Color? activeDotColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = true, bool showAxisLabels = true, bool showTooltip = true, bool showActiveBin = true, int gridLineCount = 4, double? dotRadius, double dotGap = 2, double dotOpacity = 0.84, double dotValue = 1, SimpleBinnedDotPlotValueFormatter? valueFormatter, SimpleBinnedDotPlotValueFormatter? countFormatter, SimpleBinnedDotPlotTapCallback? onBinTap, SimpleBinnedDotPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 650), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeDotColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
binCount int
final
bins List<SimpleBinnedDotPlotBin>
final
countFormatter SimpleBinnedDotPlotValueFormatter?
final
dotColor Color?
final
dotGap double
final
dotOpacity double
final
dotRadius double?
final
dotValue double
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
maxValue double?
final
minValue double?
final
onBinTap SimpleBinnedDotPlotTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveBin bool
final
showAxisLabels bool
final
showGrid bool
final
showTooltip bool
final
showValues bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleBinnedDotPlotTooltipBuilder?
final
valueFormatter SimpleBinnedDotPlotValueFormatter?
final
values List<double>
final
valueStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited