BoxSummary class

Constructors

BoxSummary({required double min, required double q1, required double median, required double q3, required double max, double? mean, List<double> outliers = const []})
const
BoxSummary.fromJson(Map<String, dynamic> j)
factory
BoxSummary.fromValues(List<double> values)
Compute from raw values.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
max double
final
mean double?
final
median double
final
min double
final
outliers List<double>
final
q1 double
final
q3 double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited