SimpleBoxPlotData class

Constructors

SimpleBoxPlotData({required String label, List<double> values = const [], double? min, double? q1, double? median, double? q3, double? max, double? mean, List<double> outliers = const [], Color? color})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
max double?
final
mean double?
final
median double?
final
min double?
final
outliers List<double>
final
q1 double?
final
q3 double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited