charts/boxen/simple_boxen_plot_chart library
Classes
- SimpleBoxenPlotChart
- A letter-value, or boxen, plot for showing deeper distribution tails than a classic box plot while staying compact across categories.
- SimpleBoxenPlotData
- SimpleBoxenPlotInterval
- SimpleBoxenPlotSummary
Typedefs
- SimpleBoxenPlotTapCallback = void Function(SimpleBoxenPlotData data, int index, SimpleBoxenPlotSummary summary)
- SimpleBoxenPlotTooltipBuilder = Widget Function(BuildContext context, SimpleBoxenPlotData data, int index, SimpleBoxenPlotSummary summary, SimpleBoxenPlotValueFormatter valueFormatter)
- SimpleBoxenPlotValueFormatter = String Function(double value)