SimpleBoxenPlotChart class

A letter-value, or boxen, plot for showing deeper distribution tails than a classic box plot while staying compact across categories.

Inheritance
Available extensions

Constructors

SimpleBoxenPlotChart({Key? key, required List<SimpleBoxenPlotData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? boxColor, Color? medianColor, Color? whiskerColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = true, bool showMedian = true, bool showWhiskers = true, bool showTooltip = true, bool showActiveBox = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, int maxDepth = 4, double? boxWidthFactor, double? strokeWidth, SimpleBoxenPlotValueFormatter? valueFormatter, SimpleBoxenPlotTapCallback? onBoxTap, SimpleBoxenPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
boxColor Color?
final
boxWidthFactor double?
final
data List<SimpleBoxenPlotData>
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
maxDepth int
final
maxValue double?
final
medianColor Color?
final
minValue double?
final
onBoxTap SimpleBoxenPlotTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
referenceBands List<SimpleChartReferenceBand>
final
referenceLines List<SimpleChartReferenceLine>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveBox bool
final
showGrid bool
final
showMedian bool
final
showTooltip bool
final
showValues bool
final
showWhiskers bool
final
strokeWidth double?
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleBoxenPlotTooltipBuilder?
final
valueFormatter SimpleBoxenPlotValueFormatter?
final
valueStyle TextStyle?
final
whiskerColor Color?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited