BubbleChartConfig class
- Inheritance
-
- Object
- BaseChartConfig
- BubbleChartConfig
Constructors
-
BubbleChartConfig({required List<
BubbleSeries> bubbleSeries, double minBubbleRadius = 4, double maxBubbleRadius = 40, bool showLabels = false, ChartTheme? theme = ChartTheme.light, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid}) -
BubbleChartConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apiContract → ChartApiContract
-
Shared API contract for all config-driven chart families.
no setterinherited
-
bubbleSeries
→ List<
BubbleSeries> -
final
- controller → ChartController?
-
finalinherited
- grid → GridData?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → ChartLegend?
-
finalinherited
- maxBubbleRadius → double
-
final
- minBubbleRadius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
Series> -
finalinherited
- showLabels → bool
-
final
- theme → ChartTheme
-
finalinherited
- title → TitlesData?
-
finalinherited
- toolbox → ChartToolbox?
-
finalinherited
- tooltip → ChartTooltip?
-
finalinherited
- type → ChartType
-
finalinherited
- xAxisConfig → ChartAxisConfig?
-
finalinherited
- xMax ↔ double
-
latefinal
- xMin ↔ double
-
latefinal
- yAxisConfig → ChartAxisConfig?
-
finalinherited
- yMax ↔ double
-
latefinal
- yMin ↔ double
-
latefinal
Methods
-
buildChart(
) → Widget -
Method to create the appropriate chart widget
override
-
getMaxSeriesValue(
) → double -
Safe maximum value with 10% headroom.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsApiField(
String field) → bool -
inherited
-
toJson(
) → Map< String, dynamic> -
Convert configuration to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withController(
ChartController controller) → BaseChartConfig -
Override in concrete configs to return a controller-attached copy.
inherited
-
withTheme(
ChartTheme theme) → BaseChartConfig -
Override in concrete configs to return a themed copy.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited