BubblePoint class

Constructors

BubblePoint({required double x, required double y, double size = 10, String? label, String? color})
const
BubblePoint.fromJson(Object? raw, {int fallbackIndex = 0})
factory

Properties

color String?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited