SimpleBulletChartData class

Constructors

SimpleBulletChartData({required String label, required double value, required double target, double? minValue, double? maxValue, List<SimpleBulletRange> ranges = const [], Color? color, Color? targetColor})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
maxValue double?
final
minValue double?
final
ranges List<SimpleBulletRange>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
target double
final
targetColor Color?
final
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited