CandlestickData class

Legacy compatibility model for the old package:tenun financial surface.

Prefer package:tenun_pro/tenun_pro_financial.dart, where Financial chart models and implementations are now owned.

Annotations
  • @Deprecated('Financial chart models moved to package:tenun_pro/tenun_pro_financial.dart. ' 'Use CandlestickData from tenun_pro instead.')

Constructors

CandlestickData({required double open, required double high, required double low, required double close, required DateTime date})

Properties

close double
final
date DateTime
final
hashCode int
The hash code for this object.
no setterinherited
high double
final
low double
final
open double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited