SimpleCandlestickChart class

A compact candlestick or OHLC chart for price action, KPI movement, operational open/high/low/close ranges, and market-style dashboards.

Inheritance
Available extensions
Annotations
  • @Deprecated('Financial chart widgets moved to package:tenun_pro/tenun_pro_financial.dart. ' 'Use SimpleCandlestickChart from tenun_pro instead.')

Constructors

SimpleCandlestickChart({Key? key, required List<SimpleCandlestickData> data, SimpleCandlestickChartMode mode = SimpleCandlestickChartMode.candlestick, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 280, EdgeInsets padding = _defaultPadding, Color? bullishColor, Color? bearishColor, Color? wickColor, Color? volumeColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showLabels = true, bool showValues = false, bool showVolume = true, bool showTooltip = true, bool showActiveCandle = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double volumePaneFraction = 0.22, double candleWidthFactor = 0.62, double? maxCandleWidth, double wickWidth = 1.4, double bodyRadius = 3, SimpleCandlestickValueFormatter? valueFormatter, SimpleCandlestickVolumeFormatter? volumeFormatter, SimpleCandlestickTapCallback? onCandleTap, SimpleCandlestickTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
bearishColor Color?
final
bodyRadius double
final
bullishColor Color?
final
candleWidthFactor double
final
data List<SimpleCandlestickData>
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
maxCandleWidth double?
final
maxValue double?
final
minValue double?
final
mode SimpleCandlestickChartMode
final
onCandleTap SimpleCandlestickTapCallback?
final
padding EdgeInsets
final
referenceBands List<SimpleChartReferenceBand>
final
referenceLines List<SimpleChartReferenceLine>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveCandle bool
final
showGrid bool
final
showLabels bool
final
showTooltip bool
final
showValues bool
final
showVolume bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleCandlestickTooltipBuilder?
final
valueFormatter SimpleCandlestickValueFormatter?
final
valueStyle TextStyle?
final
volumeColor Color?
final
volumeFormatter SimpleCandlestickVolumeFormatter?
final
volumePaneFraction double
final
wickColor Color?
final
wickWidth double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited