ComboSeries class

Constructors

ComboSeries({required Series base, ComboSeriesType seriesType = ComboSeriesType.bar, int yAxis = 0})
const
ComboSeries.fromJson(Map<String, dynamic> j)
factory

Properties

base Series
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesType ComboSeriesType
final
values List<double>
no setter
yAxis int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited