SimpleChartReferenceLine class
Constructors
- SimpleChartReferenceLine({required double value, String? label, Color? color, double strokeWidth = 1.4, SimpleChartReferenceLineStyle lineStyle = SimpleChartReferenceLineStyle.dashed, bool showLabel = true})
-
const
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String?
-
final
- lineStyle → SimpleChartReferenceLineStyle
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLabel → bool
-
final
- strokeWidth → double
-
final
- value → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited