SimpleContinuousHeatmapBin class

Constructors

SimpleContinuousHeatmapBin({required int xIndex, required int yIndex, required double xStart, required double xEnd, required double yStart, required double yEnd, required double value, int pointCount = 0, List<SimpleContinuousHeatmapPoint> points = const [], String? label, Color? color})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String?
final
pointCount int
final
points List<SimpleContinuousHeatmapPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final
xCenter double
no setter
xEnd double
final
xIndex int
final
xStart double
final
yCenter double
no setter
yEnd double
final
yIndex int
final
yStart double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited