SimpleContinuousHeatmapChart class

A rectangular density grid for continuous x/y observations, operational hotspots, spatial summaries, product telemetry, and learning analytics.

Inheritance
Available extensions

Constructors

SimpleContinuousHeatmapChart({Key? key, List<SimpleContinuousHeatmapPoint> points = const [], List<SimpleContinuousHeatmapBin> bins = const [], int xBins = 6, int yBins = 5, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minX, double? maxX, double? minY, double? maxY, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, Color? lowColor, Color? highColor, Color? emptyColor, Color? gridColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showXLabels = true, bool showYLabels = true, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActiveCell = true, double cellGap = 3, double cellRadius = 5, SimpleContinuousHeatmapValueFormatter? valueFormatter, SimpleContinuousHeatmapValueFormatter? rangeFormatter, SimpleContinuousHeatmapTapCallback? onBinTap, SimpleContinuousHeatmapTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 650), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
bins List<SimpleContinuousHeatmapBin>
final
cellGap double
final
cellRadius double
final
emptyBuilder WidgetBuilder?
final
emptyColor Color?
final
excludeFromSemantics bool
final
gridColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
highColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
lowColor Color?
final
maxValue double?
final
maxX double?
final
maxY double?
final
minValue double?
final
minX double?
final
minY double?
final
onBinTap SimpleContinuousHeatmapTapCallback?
final
padding EdgeInsets
final
points List<SimpleContinuousHeatmapPoint>
final
rangeFormatter SimpleContinuousHeatmapValueFormatter?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveCell bool
final
showGrid bool
final
showLegend bool
final
showTooltip bool
final
showValues bool
final
showXLabels bool
final
showYLabels bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleContinuousHeatmapTooltipBuilder?
final
valueFormatter SimpleContinuousHeatmapValueFormatter?
final
valueStyle TextStyle?
final
xBins int
final
yBins int
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited