SimpleContourChart class

A simple contour chart for risk surfaces, demand fields, performance landscapes, geographic-like intensity, and scientific/education dashboards.

Inheritance
Available extensions

Constructors

SimpleContourChart({Key? key, required List<SimpleContourPoint> points, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minX, double? maxX, double? minY, double? maxY, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, String? xAxisLabel, String? yAxisLabel, Color? lowColor, Color? highColor, Color? lineColor, Color? pointColor, Color? gridColor, Color? axisColor, Color? activeColor, List<Color>? palette, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showFilledBands = true, bool showContourLines = true, bool showSamplePoints = true, bool showLabels = true, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActiveSelection = true, bool showAxisLabels = true, int gridLineCount = 4, int gridResolution = 26, int levelCount = 6, double contourLineWidth = 1.2, double pointRadius = 4, double interpolationPower = 2, List<double> levels = const [], SimpleContourValueFormatter? xValueFormatter, SimpleContourValueFormatter? yValueFormatter, SimpleContourValueFormatter? valueFormatter, SimpleContourTapCallback? onSelectionTap, SimpleContourTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
contourLineWidth double
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
gridResolution int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
highColor Color?
final
interpolationPower double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
levelCount int
final
levels List<double>
final
lineColor Color?
final
lowColor Color?
final
maxValue double?
final
maxX double?
final
maxY double?
final
minValue double?
final
minX double?
final
minY double?
final
onSelectionTap SimpleContourTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
pointColor Color?
final
pointRadius double
final
points List<SimpleContourPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveSelection bool
final
showAxisLabels bool
final
showContourLines bool
final
showFilledBands bool
final
showGrid bool
final
showLabels bool
final
showLegend bool
final
showSamplePoints bool
final
showTooltip bool
final
showValues bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleContourTooltipBuilder?
final
valueFormatter SimpleContourValueFormatter?
final
valueStyle TextStyle?
final
xAxisLabel String?
final
xValueFormatter SimpleContourValueFormatter?
final
yAxisLabel String?
final
yValueFormatter SimpleContourValueFormatter?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited