SimpleContourSelection class
Constructors
- SimpleContourSelection({required double x, required double y, required double value, required double lowerBound, required double upperBound, required int bandIndex, SimpleContourPoint? nearestPoint})
-
const
Properties
- bandIndex → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lowerBound → double
-
final
- nearestPoint → SimpleContourPoint?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- upperBound → double
-
final
- value → double
-
final
- x → double
-
final
- y → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited