SimpleControlChart class

A simple process-control chart for stability, quality, SLA, learning, measurement, and operational monitoring workflows.

Inheritance
Available extensions

Constructors

SimpleControlChart({Key? key, required List<SimpleControlChartPoint> points, SimpleTrendChartStyle style = SimpleTrendChartStyle.elegant, double? minValue, double? maxValue, double? centerValue, double? lowerControlLimit, double? upperControlLimit, double? lowerWarningLimit, double? upperWarningLimit, double sigmaMultiplier = 3, double warningSigmaMultiplier = 2, double height = 260, EdgeInsets padding = _defaultPadding, Color? lineColor, Color? dotColor, Color? centerLineColor, Color? controlLimitColor, Color? warningBandColor, Color? signalColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showLine = true, bool showDots = true, bool showValues = false, bool showLabels = true, bool showCenterLine = true, bool showControlLimits = true, bool showWarningBand = true, bool highlightSignals = true, bool showTooltip = true, bool showActivePoint = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? strokeWidth, double? dotRadius, SimpleControlValueFormatter? valueFormatter, SimpleControlPointTapCallback? onPointTap, SimpleControlTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
centerLineColor Color?
final
centerValue double?
final
controlLimitColor Color?
final
dotColor Color?
final
dotRadius double?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
highlightSignals bool
final
includeZero bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
lineColor Color?
final
lowerControlLimit double?
final
lowerWarningLimit double?
final
maxValue double?
final
minValue double?
final
onPointTap SimpleControlPointTapCallback?
final
padding EdgeInsets
final
points List<SimpleControlChartPoint>
final
referenceBands List<SimpleChartReferenceBand>
final
referenceLines List<SimpleChartReferenceLine>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActivePoint bool
final
showCenterLine bool
final
showControlLimits bool
final
showDots bool
final
showGrid bool
final
showLabels bool
final
showLine bool
final
showTooltip bool
final
showValues bool
final
showWarningBand bool
final
sigmaMultiplier double
final
signalColor Color?
final
strokeWidth double?
final
style SimpleTrendChartStyle
final
tooltipBuilder SimpleControlTooltipBuilder?
final
upperControlLimit double?
final
upperWarningLimit double?
final
valueFormatter SimpleControlValueFormatter?
final
valueStyle TextStyle?
final
warningBandColor Color?
final
warningSigmaMultiplier double
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited