SimpleControlChartStats class

Constructors

SimpleControlChartStats({required double center, required double lowerControlLimit, required double upperControlLimit, required double lowerWarningLimit, required double upperWarningLimit, required double standardDeviation, required int count, required int signalCount})
const

Properties

center double
final
count int
final
hashCode int
The hash code for this object.
no setterinherited
lowerControlLimit double
final
lowerWarningLimit double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signalCount int
final
standardDeviation double
final
upperControlLimit double
final
upperWarningLimit double
final

Methods

isSignal(double value) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited