SimpleDensityChart class

A simple kernel density chart for comparing smooth distributions across samples, cohorts, latency, scores, prices, and measurements.

Inheritance
Available extensions

Constructors

SimpleDensityChart({Key? key, required List<SimpleDensitySeries> series, SimpleTrendChartStyle style = SimpleTrendChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? lineColor, Color? fillColor, Color? meanColor, Color? medianColor, Color? rugColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showLine = true, bool showArea = true, bool showRug = false, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActiveSeries = true, bool showMean = false, bool showMedian = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, int sampleCount = 96, double? strokeWidth, double? fillOpacity, double? rugHeight, SimpleDensityValueFormatter? valueFormatter, SimpleDensityValueFormatter? densityFormatter, SimpleDensityTapCallback? onSeriesTap, SimpleDensityTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
densityFormatter SimpleDensityValueFormatter?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
fillColor Color?
final
fillOpacity double?
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
includeZero bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
lineColor Color?
final
maxValue double?
final
meanColor Color?
final
medianColor Color?
final
minValue double?
final
onSeriesTap SimpleDensityTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
referenceBands List<SimpleChartReferenceBand>
final
referenceLines List<SimpleChartReferenceLine>
final
rugColor Color?
final
rugHeight double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleCount int
final
semanticLabel String?
final
series List<SimpleDensitySeries>
final
showActiveSeries bool
final
showArea bool
final
showGrid bool
final
showLegend bool
final
showLine bool
final
showMean bool
final
showMedian bool
final
showRug bool
final
showTooltip bool
final
showValues bool
final
strokeWidth double?
final
style SimpleTrendChartStyle
final
tooltipBuilder SimpleDensityTooltipBuilder?
final
valueFormatter SimpleDensityValueFormatter?
final
valueStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited