SimpleDensityStats class

Constructors

SimpleDensityStats({required int count, required double min, required double mean, required double median, required double max, required double peakValue, required double peakDensity})
const

Properties

count int
final
hashCode int
The hash code for this object.
no setterinherited
max double
final
mean double
final
median double
final
min double
final
peakDensity double
final
peakValue double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited