SimpleDotPlotChart class
A compact Cleveland-style dot plot for ranking, benchmarking, survey scores, and multi-series category comparisons.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleDotPlotChart
- Available extensions
Constructors
-
SimpleDotPlotChart({Key? key, required List<
String> categories, required List<SimpleDotPlotSeries> series, SimpleBarChartOrientation orientation = SimpleBarChartOrientation.horizontal, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets? padding, List<Color> ? palette, Color? dotColor, Color? guideLineColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showGuideLines = true, bool showValues = true, bool showLegend = true, bool showTooltip = true, bool showActiveDot = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? dotRadius, double? guideLineWidth, SimpleDotPlotValueFormatter? valueFormatter, SimpleDotPlotTapCallback? onPointTap, SimpleDotPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 650), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
-
categories
→ List<
String> -
final
- dotColor → Color?
-
final
- dotRadius → double?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- guideLineColor → Color?
-
final
- guideLineWidth → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- maxValue → double?
-
final
- minValue → double?
-
final
- onPointTap → SimpleDotPlotTapCallback?
-
final
- orientation → SimpleBarChartOrientation
-
final
- padding → EdgeInsets?
-
final
-
palette
→ List<
Color> ? -
final
-
referenceBands
→ List<
SimpleChartReferenceBand> -
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
-
series
→ List<
SimpleDotPlotSeries> -
final
- showActiveDot → bool
-
final
- showGrid → bool
-
final
- showGuideLines → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleDotPlotTooltipBuilder?
-
final
- valueFormatter → SimpleDotPlotValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited