charts/ecdf/simple_ecdf_chart library

Classes

SimpleEcdfChart
A compact empirical cumulative distribution function chart for thresholds, samples, latency, scores, measurements, and model error distributions.
SimpleEcdfSeries
SimpleEcdfStats

Typedefs

SimpleEcdfTapCallback = void Function(SimpleEcdfSeries series, double value, double percentile, int valueIndex, int seriesIndex)
SimpleEcdfTooltipBuilder = Widget Function(BuildContext context, SimpleEcdfSeries series, double value, double percentile, SimpleEcdfStats stats, int valueIndex, int seriesIndex, String formattedValue, String formattedPercentile)
SimpleEcdfValueFormatter = String Function(double value)