SimpleEcdfChart class

A compact empirical cumulative distribution function chart for thresholds, samples, latency, scores, measurements, and model error distributions.

Inheritance
Available extensions

Constructors

SimpleEcdfChart({Key? key, required List<SimpleEcdfSeries> series, SimpleTrendChartStyle style = SimpleTrendChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? lineColor, Color? fillColor, Color? medianColor, Color? p90Color, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showDots = true, bool showValues = false, bool showArea = false, bool showLegend = true, bool showTooltip = true, bool showActivePoint = true, bool showMedianLine = true, bool showP90Line = false, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? strokeWidth, double? dotRadius, double? fillOpacity, SimpleEcdfValueFormatter? valueFormatter, SimpleEcdfValueFormatter? percentileFormatter, SimpleEcdfTapCallback? onPointTap, SimpleEcdfTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
dotRadius double?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
fillColor Color?
final
fillOpacity double?
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
includeZero bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
lineColor Color?
final
maxValue double?
final
medianColor Color?
final
minValue double?
final
onPointTap SimpleEcdfTapCallback?
final
p90Color Color?
final
padding EdgeInsets
final
palette List<Color>?
final
percentileFormatter SimpleEcdfValueFormatter?
final
referenceBands List<SimpleChartReferenceBand>
final
referenceLines List<SimpleChartReferenceLine>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
series List<SimpleEcdfSeries>
final
showActivePoint bool
final
showArea bool
final
showDots bool
final
showGrid bool
final
showLegend bool
final
showMedianLine bool
final
showP90Line bool
final
showTooltip bool
final
showValues bool
final
strokeWidth double?
final
style SimpleTrendChartStyle
final
tooltipBuilder SimpleEcdfTooltipBuilder?
final
valueFormatter SimpleEcdfValueFormatter?
final
valueStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited