SimpleEventStripChart class
A compact time-based event strip for incidents, releases, classes, campaigns, orders, audits, experiments, and activity streams.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleEventStripChart
- Available extensions
Constructors
-
SimpleEventStripChart({Key? key, required List<
SimpleEventStripLane> lanes, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, DateTime? minDate, DateTime? maxDate, DateTime? markerDate, double height = 260, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? eventColor, Color? laneColor, Color? gridColor, Color? axisColor, Color? markerDateColor, Color? activeColor, Color? laneBackgroundColor, TextStyle? laneLabelStyle, TextStyle? dateStyle, TextStyle? eventLabelStyle, bool sortByDate = true, bool showGrid = true, bool showLaneLabels = true, bool showDates = true, bool showEventLabels = false, bool showWeights = true, bool showMarkerDate = true, bool showTooltip = true, bool showActiveEvent = true, int tickCount = 4, double minEventRadius = 3.5, double maxEventRadius = 8, double eventOpacity = 0.86, SimpleEventStripDateFormatter? dateFormatter, SimpleEventStripWeightFormatter? weightFormatter, SimpleEventStripTapCallback? onEventTap, SimpleEventStripTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- dateFormatter → SimpleEventStripDateFormatter?
-
final
- dateStyle → TextStyle?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- eventColor → Color?
-
final
- eventLabelStyle → TextStyle?
-
final
- eventOpacity → double
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- laneBackgroundColor → Color?
-
final
- laneColor → Color?
-
final
- laneLabelStyle → TextStyle?
-
final
-
lanes
→ List<
SimpleEventStripLane> -
final
- markerDate → DateTime?
-
final
- markerDateColor → Color?
-
final
- maxDate → DateTime?
-
final
- maxEventRadius → double
-
final
- minDate → DateTime?
-
final
- minEventRadius → double
-
final
- onEventTap → SimpleEventStripTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveEvent → bool
-
final
- showDates → bool
-
final
- showEventLabels → bool
-
final
- showGrid → bool
-
final
- showLaneLabels → bool
-
final
- showMarkerDate → bool
-
final
- showTooltip → bool
-
final
- showWeights → bool
-
final
- sortByDate → bool
-
final
- style → SimpleBarChartStyle
-
final
- tickCount → int
-
final
- tooltipBuilder → SimpleEventStripTooltipBuilder?
-
final
- weightFormatter → SimpleEventStripWeightFormatter?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited