SimpleFanChart class
A simple fan chart for forecast uncertainty, confidence intervals, scenario ranges, projections, and planning dashboards.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleFanChart
- Available extensions
Constructors
-
SimpleFanChart({Key? key, required List<
SimpleFanChartPoint> points, SimpleTrendChartStyle style = SimpleTrendChartStyle.elegant, double? minValue, double? maxValue, double height = 250, EdgeInsets padding = _defaultPadding, String? valueLabel, Color? lineColor, Color? bandColor, Color? gridColor, Color? axisColor, Color? activeColor, List<Color> ? palette, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showBands = true, bool showLine = true, bool showDots = true, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActivePoint = true, bool showAxisLabels = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double strokeWidth = 2.4, double dotRadius = 3.6, double bandOpacity = 0.34, SimpleFanValueFormatter? valueFormatter, SimpleFanPointTapCallback? onPointTap, SimpleFanTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 750), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- bandColor → Color?
-
final
- bandOpacity → double
-
final
- dotRadius → double
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- includeZero → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- lineColor → Color?
-
final
- maxValue → double?
-
final
- minValue → double?
-
final
- onPointTap → SimpleFanPointTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
-
points
→ List<
SimpleFanChartPoint> -
final
-
referenceBands
→ List<
SimpleChartReferenceBand> -
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActivePoint → bool
-
final
- showAxisLabels → bool
-
final
- showBands → bool
-
final
- showDots → bool
-
final
- showGrid → bool
-
final
- showLegend → bool
-
final
- showLine → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- strokeWidth → double
-
final
- style → SimpleTrendChartStyle
-
final
- tooltipBuilder → SimpleFanTooltipBuilder?
-
final
- valueFormatter → SimpleFanValueFormatter?
-
final
- valueLabel → String?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited