SimpleForestPlotChart class

A compact forest plot for treatment effects, experiment lift, risk ratios, research summaries, policy comparisons, and confidence intervals.

Inheritance
Available extensions

Constructors

SimpleForestPlotChart({Key? key, required List<SimpleForestPlotData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double referenceValue = 0, double height = 280, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? intervalColor, Color? markerColor, Color? referenceColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeReference = true, bool showGrid = true, bool showLabels = true, bool showValues = true, bool showIntervalLabels = false, bool showWeights = false, bool showReferenceLine = true, bool showTooltip = true, bool showActiveItem = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? intervalStrokeWidth, double? markerSize, double? minMarkerSize, double? maxMarkerSize, SimpleForestPlotValueFormatter? valueFormatter, SimpleForestPlotValueFormatter? weightFormatter, SimpleForestPlotTapCallback? onItemTap, SimpleForestPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
data List<SimpleForestPlotData>
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
includeReference bool
final
intervalColor Color?
final
intervalStrokeWidth double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
markerColor Color?
final
markerSize double?
final
maxMarkerSize double?
final
maxValue double?
final
minMarkerSize double?
final
minValue double?
final
onItemTap SimpleForestPlotTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
referenceBands List<SimpleChartReferenceBand>
final
referenceColor Color?
final
referenceLines List<SimpleChartReferenceLine>
final
referenceValue double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveItem bool
final
showGrid bool
final
showIntervalLabels bool
final
showLabels bool
final
showReferenceLine bool
final
showTooltip bool
final
showValues bool
final
showWeights bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleForestPlotTooltipBuilder?
final
valueFormatter SimpleForestPlotValueFormatter?
final
valueStyle TextStyle?
final
weightFormatter SimpleForestPlotValueFormatter?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited