SimpleForestPlotData class

Constructors

SimpleForestPlotData({required String label, required double estimate, required double lower, required double upper, double? weight, String? group, Color? color})
const

Properties

color Color?
final
estimate double
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
high double
no setter
label String
final
low double
no setter
lower double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
upper double
final
weight double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited