SimpleFrequencyPolygonSeries class

Constructors

SimpleFrequencyPolygonSeries({required String name, List<double> values = const [], List<SimpleFrequencyPolygonBin> bins = const [], Color? color, SimpleTrendLineStyle lineStyle = SimpleTrendLineStyle.solid})
const

Properties

bins List<SimpleFrequencyPolygonBin>
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
lineStyle SimpleTrendLineStyle
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited