FunnelChartConfig class
- Inheritance
-
- Object
- BaseChartConfig
- FunnelChartConfig
Constructors
-
FunnelChartConfig({required List<
FunnelItem> items, ChartTheme? theme = ChartTheme.light, FunnelMode funnelMode = FunnelMode.funnel, bool showLabels = true, bool showValues = true, bool showPercentage = false, bool showConversionRate = false, double neckWidthFraction = 0.18, double gapFraction = 0.015, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid}) -
FunnelChartConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- apiContract → ChartApiContract
-
Shared API contract for all config-driven chart families.
no setterinherited
- controller → ChartController?
-
finalinherited
- funnelMode → FunnelMode
-
final
- gapFraction → double
-
final
- grid → GridData?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
FunnelItem> -
final
- legend → ChartLegend?
-
finalinherited
- neckWidthFraction → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
Series> -
finalinherited
- showConversionRate → bool
-
final
- showLabels → bool
-
final
- showPercentage → bool
-
final
- showValues → bool
-
final
- theme → ChartTheme
-
finalinherited
- title → TitlesData?
-
finalinherited
- toolbox → ChartToolbox?
-
finalinherited
- tooltip → ChartTooltip?
-
finalinherited
- type → ChartType
-
finalinherited
- xAxisConfig → ChartAxisConfig?
-
finalinherited
- yAxisConfig → ChartAxisConfig?
-
finalinherited
Methods
-
buildChart(
) → Widget -
Method to create the appropriate chart widget
override
-
getMaxSeriesValue(
) → double -
Safe maximum value with 10% headroom.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsApiField(
String field) → bool -
inherited
-
toJson(
) → Map< String, dynamic> -
Convert configuration to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withController(
ChartController controller) → BaseChartConfig -
Override in concrete configs to return a controller-attached copy.
inherited
-
withTheme(
ChartTheme theme) → BaseChartConfig -
Override in concrete configs to return a themed copy.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited