SimpleHistogramChart class

A lightweight distribution chart for scores, prices, latency, ages, and other numeric samples.

Inheritance
Available extensions

Constructors

SimpleHistogramChart({Key? key, List<double> values = const [], List<SimpleHistogramBin> bins = const [], int binCount = 8, SimpleHistogramScale scale = SimpleHistogramScale.count, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? barColor, Color? curveColor, Color? meanColor, Color? medianColor, Color? gridColor, Color? axisColor, Color? activeBarColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = true, bool showAxisLabels = true, bool showMean = true, bool showMedian = false, bool showDistributionCurve = false, bool showTooltip = true, bool showActiveBin = true, int gridLineCount = 4, double? barRadius, double? gapRatio, bool? useGradient, SimpleHistogramValueFormatter? valueFormatter, SimpleHistogramValueFormatter? countFormatter, SimpleHistogramValueFormatter? percentFormatter, SimpleHistogramTapCallback? onBinTap, SimpleHistogramTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 650), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeBarColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
barColor Color?
final
barRadius double?
final
binCount int
final
bins List<SimpleHistogramBin>
final
countFormatter SimpleHistogramValueFormatter?
final
curveColor Color?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gapRatio double?
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
maxValue double?
final
meanColor Color?
final
medianColor Color?
final
minValue double?
final
onBinTap SimpleHistogramTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
percentFormatter SimpleHistogramValueFormatter?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scale SimpleHistogramScale
final
semanticLabel String?
final
showActiveBin bool
final
showAxisLabels bool
final
showDistributionCurve bool
final
showGrid bool
final
showMean bool
final
showMedian bool
final
showTooltip bool
final
showValues bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleHistogramTooltipBuilder?
final
useGradient bool?
final
valueFormatter SimpleHistogramValueFormatter?
final
values List<double>
final
valueStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited