IndicatorChartConfig class

Inheritance

Constructors

IndicatorChartConfig({required double value, required String label, double? previousValue, String? unit, int precision = 0, ChartTheme? theme, TitlesData? title, ChartController? controller})
IndicatorChartConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setterinherited
controller ChartController?
finalinherited
grid GridData?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
label String
final
legend ChartLegend?
finalinherited
precision int
final
previousValue double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<Series>
finalinherited
theme ChartTheme
finalinherited
title TitlesData?
finalinherited
toolbox ChartToolbox?
finalinherited
tooltip ChartTooltip?
finalinherited
type ChartType
finalinherited
unit String?
final
value double
final
xAxisConfig ChartAxisConfig?
finalinherited
yAxisConfig ChartAxisConfig?
finalinherited

Methods

buildChart() Widget
Method to create the appropriate chart widget
override
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
inherited
toJson() Map<String, dynamic>
Convert configuration to JSON
override
toString() String
A string representation of this object.
inherited
withController(ChartController controller) BaseChartConfig
Override in concrete configs to return a controller-attached copy.
override
withTheme(ChartTheme theme) BaseChartConfig
Override in concrete configs to return a themed copy.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited