DynamicTimeSeriesConfig class
- Inheritance
-
- Object
- BaseChartConfig
- DynamicTimeSeriesConfig
Constructors
- DynamicTimeSeriesConfig({int windowSize = 60, Duration updateInterval = const Duration(milliseconds: 500), double dataGenerator()?, ChartTheme theme = ChartTheme.light, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid})
-
DynamicTimeSeriesConfig.fromJson(Map<
String, dynamic> j) -
factory
Properties
- apiContract → ChartApiContract
-
Shared API contract for all config-driven chart families.
no setterinherited
- controller → ChartController?
-
finalinherited
- dataGenerator → double Function()?
-
final
- grid → GridData?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → ChartLegend?
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
Series> -
finalinherited
- theme → ChartTheme
-
final
- title → TitlesData?
-
finalinherited
- toolbox → ChartToolbox?
-
finalinherited
- tooltip → ChartTooltip?
-
finalinherited
- type → ChartType
-
finalinherited
- updateInterval → Duration
-
final
- windowSize → int
-
final
- xAxisConfig → ChartAxisConfig?
-
finalinherited
- yAxisConfig → ChartAxisConfig?
-
finalinherited
Methods
-
buildChart(
) → Widget -
Method to create the appropriate chart widget
override
-
getMaxSeriesValue(
) → double -
Safe maximum value with 10% headroom.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsApiField(
String field) → bool -
inherited
-
toJson(
) → Map< String, dynamic> -
Convert configuration to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withController(
ChartController controller) → BaseChartConfig -
Override in concrete configs to return a controller-attached copy.
inherited
-
withTheme(
ChartTheme theme) → BaseChartConfig -
Override in concrete configs to return a themed copy.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited