FunctionPlotConfig class
- Inheritance
-
- Object
- BaseChartConfig
- FunctionPlotConfig
Constructors
-
FunctionPlotConfig({required List<
FunctionSeries> functions, double xMin = -10, double xMax = 10, double yMin = -10, double yMax = 10, int resolution = 400, ChartTheme theme = ChartTheme.light, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid}) -
FunctionPlotConfig.fromJson(Map<
String, dynamic> j) -
factory
Properties
- apiContract → ChartApiContract
-
Shared API contract for all config-driven chart families.
no setterinherited
- controller → ChartController?
-
finalinherited
-
functions
→ List<
FunctionSeries> -
final
- grid → GridData?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → ChartLegend?
-
finalinherited
- resolution → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
Series> -
finalinherited
- theme → ChartTheme
-
final
- title → TitlesData?
-
finalinherited
- toolbox → ChartToolbox?
-
finalinherited
- tooltip → ChartTooltip?
-
finalinherited
- type → ChartType
-
finalinherited
- xAxisConfig → ChartAxisConfig?
-
finalinherited
- xMax → double
-
final
- xMin → double
-
final
- yAxisConfig → ChartAxisConfig?
-
finalinherited
- yMax → double
-
final
- yMin → double
-
final
Methods
-
buildChart(
) → Widget -
Method to create the appropriate chart widget
override
-
getMaxSeriesValue(
) → double -
Safe maximum value with 10% headroom.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsApiField(
String field) → bool -
inherited
-
toJson(
) → Map< String, dynamic> -
Convert configuration to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withController(
ChartController controller) → BaseChartConfig -
Override in concrete configs to return a controller-attached copy.
inherited
-
withTheme(
ChartTheme theme) → BaseChartConfig -
Override in concrete configs to return a themed copy.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited