LineChartConfig class

Inheritance
Implementers

Constructors

LineChartConfig({required List<Series> series, XYAxis? xAxis, XYAxis? yAxis, double? maxY, bool showBelowArea = false, double curveSmoothness = 0.2, bool showDots = true, double dotSize = 4.0, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
LineChartConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setterinherited
controller ChartController?
finalinherited
curveSmoothness double
final
dotSize double
final
grid GridData?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
legend ChartLegend?
finalinherited
maxY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<Series>
finalinherited
showBelowArea bool
final
showDots bool
final
theme ChartTheme
finalinherited
title TitlesData?
finalinherited
toolbox ChartToolbox?
finalinherited
tooltip ChartTooltip?
finalinherited
type ChartType
finalinherited
xAxis XYAxis?
final
xAxisConfig ChartAxisConfig?
finalinherited
yAxis XYAxis?
final
yAxisConfig ChartAxisConfig?
finalinherited

Methods

buildChart() Widget
Method to create the appropriate chart widget
override
copyWith({List<Series>? series, XYAxis? xAxis, XYAxis? yAxis, double? maxY, bool? showBelowArea, double? curveSmoothness, bool? showDots, double? dotSize, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig}) LineChartConfig
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
inherited
toJson() Map<String, dynamic>
Convert configuration to JSON
override
toString() String
A string representation of this object.
inherited
withController(ChartController controller) LineChartConfig
Override in concrete configs to return a controller-attached copy.
override
withTheme(ChartTheme theme) LineChartConfig
Override in concrete configs to return a themed copy.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited