withTheme method
Override in concrete configs to return a themed copy.
Implementation
@override
LineChartConfig withTheme(ChartTheme theme) => copyWith(theme: theme);
Override in concrete configs to return a themed copy.
@override
LineChartConfig withTheme(ChartTheme theme) => copyWith(theme: theme);