SimpleTrendSeries class

Constructors

SimpleTrendSeries({String? name, required List<SimpleTrendPoint> points, Color? color, double? strokeWidth, SimpleTrendLineStyle lineStyle = SimpleTrendLineStyle.solid})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
lineStyle SimpleTrendLineStyle
final
name String?
final
points List<SimpleTrendPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited