SimpleStepChart class
A stepped trend chart for values that hold until a change point.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleStepChart
- Available extensions
Constructors
-
SimpleStepChart({Key? key, required List<
SimpleTrendSeries> series, SimpleTrendChartStyle style = SimpleTrendChartStyle.elegant, SimpleStepChartMode mode = SimpleStepChartMode.after, double? minValue, double? maxValue, double height = 240, EdgeInsets padding = _defaultPadding, Color? lineColor, Color? fillColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showDots = true, bool showValues = true, bool showArea = false, bool showLegend = true, bool showTooltip = true, bool showActiveStep = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], double? strokeWidth, double? dotRadius, double? fillOpacity, int gridLineCount = 4, SimpleTrendValueFormatter? valueFormatter, SimpleTrendPointTapCallback? onPointTap, SimpleTrendTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- dotRadius → double?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- fillColor → Color?
-
final
- fillOpacity → double?
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- includeZero → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- lineColor → Color?
-
final
- maxValue → double?
-
final
- minValue → double?
-
final
- mode → SimpleStepChartMode
-
final
- onPointTap → SimpleTrendPointTapCallback?
-
final
- padding → EdgeInsets
-
final
-
referenceBands
→ List<
SimpleChartReferenceBand> -
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
-
series
→ List<
SimpleTrendSeries> -
final
- showActiveStep → bool
-
final
- showArea → bool
-
final
- showDots → bool
-
final
- showGrid → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- strokeWidth → double?
-
final
- style → SimpleTrendChartStyle
-
final
- tooltipBuilder → SimpleTrendTooltipBuilder?
-
final
- valueFormatter → SimpleTrendValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited