SimpleMilestoneData class

Constructors

SimpleMilestoneData({required DateTime date, required String label, String? description, String? tag, SimpleMilestoneStatus status = SimpleMilestoneStatus.planned, Color? color})
const

Properties

color Color?
final
date DateTime
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status SimpleMilestoneStatus
final
tag String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited