SimpleMosaicPlotChart class

A categorical mosaic plot for showing size and composition together.

Inheritance
Available extensions

Constructors

SimpleMosaicPlotChart({Key? key, List<String> xLabels = const [], List<String> yLabels = const [], required List<SimpleMosaicPlotCell> cells, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 260, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? cellColor, Color? borderColor, Color? gridColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = true, bool showPercentages = true, bool showCellLabels = true, bool showXLabels = true, bool showColumnTotals = true, bool showLegend = true, bool showTooltip = true, bool showActiveCell = true, double columnGap = 5, double cellGap = 2, double cellRadius = 4, SimpleMosaicPlotValueFormatter? valueFormatter, SimpleMosaicPlotValueFormatter? shareFormatter, SimpleMosaicPlotTapCallback? onCellTap, SimpleMosaicPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 750), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
borderColor Color?
final
cellColor Color?
final
cellGap double
final
cellRadius double
final
cells List<SimpleMosaicPlotCell>
final
columnGap double
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
onCellTap SimpleMosaicPlotTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
shareFormatter SimpleMosaicPlotValueFormatter?
final
showActiveCell bool
final
showCellLabels bool
final
showColumnTotals bool
final
showGrid bool
final
showLegend bool
final
showPercentages bool
final
showTooltip bool
final
showValues bool
final
showXLabels bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleMosaicPlotTooltipBuilder?
final
valueFormatter SimpleMosaicPlotValueFormatter?
final
valueStyle TextStyle?
final
xLabels List<String>
final
yLabels List<String>
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited