SimpleNetworkNode class

Constructors

SimpleNetworkNode({required String id, required String label, double value = 1, String? group, Color? color, double? x, double? y})
const

Properties

color Color?
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final
x double?
Optional normalized x position from 0 to 1 inside the plot area.
final
y double?
Optional normalized y position from 0 to 1 inside the plot area.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited