SimplePackedBubbleChart class
A compact packed bubble chart for showing part-to-whole magnitude through area while keeping the composition visually approachable.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimplePackedBubbleChart
- Available extensions
Constructors
-
SimplePackedBubbleChart({Key? key, required List<
SimplePackedBubbleData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? totalValue, double height = 260, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? bubbleColor, Color? borderColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showLabels = true, bool showValues = true, bool showLegend = true, bool showTooltip = true, bool showActiveBubble = true, double? minBubbleRadius, double? maxBubbleRadius, double bubbleSpacing = 4, SimplePackedBubbleValueFormatter? valueFormatter, SimplePackedBubbleValueFormatter? percentFormatter, SimplePackedBubbleTapCallback? onBubbleTap, SimplePackedBubbleTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 720), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - borderColor → Color?
-
final
- bubbleColor → Color?
-
final
- bubbleSpacing → double
-
final
-
data
→ List<
SimplePackedBubbleData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- maxBubbleRadius → double?
-
final
- minBubbleRadius → double?
-
final
- onBubbleTap → SimplePackedBubbleTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- percentFormatter → SimplePackedBubbleValueFormatter?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveBubble → bool
-
final
- showLabels → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimplePackedBubbleTooltipBuilder?
-
final
- totalValue → double?
-
final
- valueFormatter → SimplePackedBubbleValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited