SimplePictogramChart class
A compact icon-array chart for countable part-to-whole stories.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimplePictogramChart
- Available extensions
Constructors
-
SimplePictogramChart({Key? key, required List<
SimplePictogramChartData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? totalValue, int rows = 5, int columns = 10, double height = 260, EdgeInsets padding = _defaultPadding, SimplePictogramSymbol symbol = SimplePictogramSymbol.person, SimplePictogramFillDirection fillDirection = SimplePictogramFillDirection.bottomToTop, List<Color> ? palette, Color? symbolColor, Color? emptyColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showLegend = true, bool showValues = true, bool showTooltip = true, bool showActiveUnits = true, bool showEmptyUnits = true, double unitGap = 5, double symbolScale = 0.82, SimplePictogramValueFormatter? valueFormatter, SimplePictogramValueFormatter? percentFormatter, SimplePictogramTapCallback? onUnitTap, SimplePictogramTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - columns → int
-
final
-
data
→ List<
SimplePictogramChartData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- emptyColor → Color?
-
final
- excludeFromSemantics → bool
-
final
- fillDirection → SimplePictogramFillDirection
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- onUnitTap → SimplePictogramTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- percentFormatter → SimplePictogramValueFormatter?
-
final
- rows → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveUnits → bool
-
final
- showEmptyUnits → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- symbol → SimplePictogramSymbol
-
final
- symbolColor → Color?
-
final
- symbolScale → double
-
final
- tooltipBuilder → SimplePictogramTooltipBuilder?
-
final
- totalValue → double?
-
final
- unitGap → double
-
final
- valueFormatter → SimplePictogramValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited