NestedPieChartConfig class
- Inheritance
-
- Object
- BaseChartConfig
- NestedPieChartConfig
Constructors
-
NestedPieChartConfig({required List<
PieRing> rings, ChartTheme theme = ChartTheme.light, double ringGap = 8.0, double padAngle = 0.02, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid}) -
NestedPieChartConfig.fromJson(Map<
String, dynamic> j) -
factory
Properties
- apiContract → ChartApiContract
-
Shared API contract for all config-driven chart families.
no setterinherited
- controller → ChartController?
-
finalinherited
- grid → GridData?
-
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → ChartLegend?
-
finalinherited
- padAngle → double
-
final
- ringGap → double
-
final
-
rings
→ List<
PieRing> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
Series> -
finalinherited
- theme → ChartTheme
-
final
- title → TitlesData?
-
finalinherited
- toolbox → ChartToolbox?
-
finalinherited
- tooltip → ChartTooltip?
-
finalinherited
- type → ChartType
-
finalinherited
- xAxisConfig → ChartAxisConfig?
-
finalinherited
- yAxisConfig → ChartAxisConfig?
-
finalinherited
Methods
-
buildChart(
) → Widget -
Method to create the appropriate chart widget
override
-
getMaxSeriesValue(
) → double -
Safe maximum value with 10% headroom.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsApiField(
String field) → bool -
inherited
-
toJson(
) → Map< String, dynamic> -
Convert configuration to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
-
withController(
ChartController controller) → BaseChartConfig -
Override in concrete configs to return a controller-attached copy.
inherited
-
withTheme(
ChartTheme theme) → BaseChartConfig -
Override in concrete configs to return a themed copy.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited