PieChartConfig class

Inheritance

Constructors

PieChartConfig({required List<Series> series, ChartType? chartType, double centerSpaceRadius = 40.0, double sectionsSpace = 2.0, bool enableSections = true, double startDegreeOffset = 0, bool donut = false, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
PieChartConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setterinherited
centerSpaceRadius double
final
controller ChartController?
finalinherited
donut bool
final
enableSections bool
final
grid GridData?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
legend ChartLegend?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionsSpace double
final
series List<Series>
finalinherited
startDegreeOffset double
final
theme ChartTheme
finalinherited
title TitlesData?
finalinherited
toolbox ChartToolbox?
finalinherited
tooltip ChartTooltip?
finalinherited
type ChartType
finalinherited
xAxisConfig ChartAxisConfig?
finalinherited
yAxisConfig ChartAxisConfig?
finalinherited

Methods

buildChart() Widget
Method to create the appropriate chart widget
override
copyWith({List<Series>? series, ChartType? chartType, double? centerSpaceRadius, double? sectionsSpace, bool? enableSections, double? startDegreeOffset, bool? donut, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig}) PieChartConfig
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
inherited
toJson() Map<String, dynamic>
Convert configuration to JSON
override
toString() String
A string representation of this object.
inherited
withController(ChartController controller) PieChartConfig
Override in concrete configs to return a controller-attached copy.
override
withTheme(ChartTheme theme) PieChartConfig
Override in concrete configs to return a themed copy.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited