SimpleDonutChart class
A polished composition chart for showing proportions with a compact center summary and optional legend.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleDonutChart
- Available extensions
Constructors
-
SimpleDonutChart({Key? key, required List<
SimpleDonutChartData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 250, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? trackColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, String? centerLabel, String? centerValue, bool showLabels = true, bool showLegend = true, bool showValues = true, bool showTooltip = true, bool showActiveSegment = true, double innerRadiusFactor = 0.62, double segmentSpacing = 0.018, double startAngle = -math.pi / 2, SimpleDonutValueFormatter? valueFormatter, SimpleDonutTapCallback? onSegmentTap, SimpleDonutTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - centerLabel → String?
-
final
- centerValue → String?
-
final
-
data
→ List<
SimpleDonutChartData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- innerRadiusFactor → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- onSegmentTap → SimpleDonutTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- segmentSpacing → double
-
final
- semanticLabel → String?
-
final
-
final
- showActiveSegment → bool
-
final
- showLabels → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- startAngle → double
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleDonutTooltipBuilder?
-
final
- trackColor → Color?
-
final
- valueFormatter → SimpleDonutValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited