SimpleQQPlotPoint class

Constructors

SimpleQQPlotPoint({required double percentile, required double referenceQuantile, required double sampleQuantile})
const

Properties

deviation double
no setter
hashCode int
The hash code for this object.
no setterinherited
percentile double
final
referenceQuantile double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleQuantile double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited