SimpleQQPlotSeries class
Constructors
-
SimpleQQPlotSeries({required String name, required List<
double> sampleValues, List<double> referenceValues = const [], SimpleQQPlotReferenceDistribution referenceDistribution = SimpleQQPlotReferenceDistribution.normal, String? referenceName, Color? color}) -
const
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- referenceDistribution → SimpleQQPlotReferenceDistribution
-
final
- referenceName → String?
-
final
-
referenceValues
→ List<
double> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sampleValues
→ List<
double> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited