SimpleQuadrantChart class
A simple 2x2 decision matrix for effort/value, risk/impact, maturity, prioritization, portfolio maps, and learning assessments.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleQuadrantChart
- Available extensions
Constructors
-
SimpleQuadrantChart({Key? key, required List<
SimpleQuadrantPoint> points, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minX, double? maxX, double? minY, double? maxY, double? xSplit, double? ySplit, double height = 260, EdgeInsets padding = _defaultPadding, String? xAxisLabel, String? yAxisLabel, SimpleQuadrantLabels quadrantLabels = const SimpleQuadrantLabels(), List<Color> ? palette, List<Color> ? quadrantColors, Color? pointColor, Color? gridColor, Color? axisColor, Color? splitLineColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showAxisLabels = true, bool showQuadrantLabels = true, bool showPointLabels = false, bool showLegend = true, bool showTooltip = true, bool showActivePoint = true, List<SimpleChartReferenceLine> referenceLines = const [], int gridLineCount = 4, double? pointRadius, double? minPointRadius, double? maxPointRadius, double quadrantOpacity = 0.08, SimpleQuadrantValueFormatter? xValueFormatter, SimpleQuadrantValueFormatter? yValueFormatter, SimpleQuadrantValueFormatter? sizeFormatter, SimpleQuadrantPointTapCallback? onPointTap, SimpleQuadrantTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- maxPointRadius → double?
-
final
- maxX → double?
-
final
- maxY → double?
-
final
- minPointRadius → double?
-
final
- minX → double?
-
final
- minY → double?
-
final
- onPointTap → SimpleQuadrantPointTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- pointColor → Color?
-
final
- pointRadius → double?
-
final
-
points
→ List<
SimpleQuadrantPoint> -
final
-
quadrantColors
→ List<
Color> ? -
final
- quadrantLabels → SimpleQuadrantLabels
-
final
- quadrantOpacity → double
-
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActivePoint → bool
-
final
- showAxisLabels → bool
-
final
- showGrid → bool
-
final
- showLegend → bool
-
final
- showPointLabels → bool
-
final
- showQuadrantLabels → bool
-
final
- showTooltip → bool
-
final
- sizeFormatter → SimpleQuadrantValueFormatter?
-
final
- splitLineColor → Color?
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleQuadrantTooltipBuilder?
-
final
- valueStyle → TextStyle?
-
final
- xAxisLabel → String?
-
final
- xSplit → double?
-
final
- xValueFormatter → SimpleQuadrantValueFormatter?
-
final
- yAxisLabel → String?
-
final
- ySplit → double?
-
final
- yValueFormatter → SimpleQuadrantValueFormatter?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited