SimpleQuadrantLabels class

Constructors

SimpleQuadrantLabels({String topRight = 'High impact', String topLeft = 'Strategic bets', String bottomLeft = 'Defer', String bottomRight = 'Quick wins'})
const

Properties

bottomLeft String
final
bottomRight String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topLeft String
final
topRight String
final

Methods

labelFor({required bool right, required bool top}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited