SimpleQuadrantPoint class

Constructors

SimpleQuadrantPoint({required String label, required double x, required double y, double? size, String? group, Color? color})
const

Properties

color Color?
final
group String?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double?
final
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited