SimpleRadarChart class

A compact radar chart for comparing multi-dimensional scores and profiles.

Inheritance
Available extensions

Constructors

SimpleRadarChart({Key? key, required List<SimpleRadarAxis> axes, required List<SimpleRadarSeries> series, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 260, EdgeInsets padding = _defaultPadding, List<Color>? palette, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showLabels = true, bool showValues = false, bool showDots = true, bool showLegend = true, bool showTooltip = true, bool showActiveAxis = true, int gridLevels = 4, double? strokeWidth, double? dotRadius, double fillOpacity = 0.18, double startAngle = -math.pi / 2, SimpleRadarValueFormatter? valueFormatter, SimpleRadarAxisTapCallback? onAxisTap, SimpleRadarTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 750), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axes List<SimpleRadarAxis>
final
axisColor Color?
final
dotRadius double?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
fillOpacity double
final
gridColor Color?
final
gridLevels int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
onAxisTap SimpleRadarAxisTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
series List<SimpleRadarSeries>
final
showActiveAxis bool
final
showDots bool
final
showGrid bool
final
showLabels bool
final
showLegend bool
final
showTooltip bool
final
showValues bool
final
startAngle double
final
strokeWidth double?
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleRadarTooltipBuilder?
final
valueFormatter SimpleRadarValueFormatter?
final
valueStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited