SimpleRaincloudChart class
A compact raincloud chart combining half-density, box summary, and raw observations for rich but readable distribution comparison.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleRaincloudChart
- Available extensions
Constructors
-
SimpleRaincloudChart({Key? key, required List<
SimpleRaincloudChartData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 280, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? cloudColor, Color? outlineColor, Color? boxColor, Color? dotColor, Color? medianColor, Color? meanColor, Color? outlierColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = true, bool showCloud = true, bool showBox = true, bool showDots = true, bool showMean = true, bool showOutliers = true, bool showTooltip = true, bool showActiveGroup = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, int densitySteps = 36, double? cloudWidthFactor, double? dotRadius, double dotOpacity = 0.72, double jitter = 0.44, int jitterSeed = 31, SimpleRaincloudValueFormatter? valueFormatter, SimpleRaincloudTapCallback? onGroupTap, SimpleRaincloudTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 760), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- boxColor → Color?
-
final
- cloudColor → Color?
-
final
- cloudWidthFactor → double?
-
final
-
data
→ List<
SimpleRaincloudChartData> -
final
- densitySteps → int
-
final
- dotColor → Color?
-
final
- dotOpacity → double
-
final
- dotRadius → double?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- jitter → double
-
final
- jitterSeed → int
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- maxValue → double?
-
final
- meanColor → Color?
-
final
- medianColor → Color?
-
final
- minValue → double?
-
final
- onGroupTap → SimpleRaincloudTapCallback?
-
final
- outlierColor → Color?
-
final
- outlineColor → Color?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
-
referenceBands
→ List<
SimpleChartReferenceBand> -
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveGroup → bool
-
final
- showBox → bool
-
final
- showCloud → bool
-
final
- showDots → bool
-
final
- showGrid → bool
-
final
- showMean → bool
-
final
- showOutliers → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleRaincloudTooltipBuilder?
-
final
- valueFormatter → SimpleRaincloudValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited