SimpleScatterPlotMatrixChart class
A compact scatter plot matrix for exploratory analysis across multiple numeric dimensions, with pairwise scatter cells and diagonal histograms.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleScatterPlotMatrixChart
- Available extensions
Constructors
-
SimpleScatterPlotMatrixChart({Key? key, List<
String> variableLabels = const [], required List<SimpleScatterPlotMatrixPoint> points, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, List<double> minValues = const [], List<double> maxValues = const [], double height = 320, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? pointColor, Color? histogramColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showDiagonalHistograms = true, bool showVariableLabels = true, bool showLegend = true, bool showTooltip = true, bool showActivePoint = true, int histogramBinCount = 6, double pointRadius = 3.2, double pointOpacity = 0.78, SimpleScatterPlotMatrixValueFormatter? valueFormatter, SimpleScatterPlotMatrixTapCallback? onPointTap, SimpleScatterPlotMatrixTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- histogramBinCount → int
-
final
- histogramColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
-
maxValues
→ List<
double> -
final
-
minValues
→ List<
double> -
final
- onPointTap → SimpleScatterPlotMatrixTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- pointColor → Color?
-
final
- pointOpacity → double
-
final
- pointRadius → double
-
final
-
points
→ List<
SimpleScatterPlotMatrixPoint> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActivePoint → bool
-
final
- showDiagonalHistograms → bool
-
final
- showGrid → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showVariableLabels → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleScatterPlotMatrixTooltipBuilder?
-
final
- valueFormatter → SimpleScatterPlotMatrixValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
-
variableLabels
→ List<
String> -
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited