ScatterChartConfig class

Inheritance

Constructors

ScatterChartConfig({required List<Series> series, XYAxis? xAxis, XYAxis? yAxis, double? maxX, double? maxY, double? minX, double? minY, double dotSize = 6.0, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
ScatterChartConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setterinherited
controller ChartController?
finalinherited
dotSize double
final
grid GridData?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
legend ChartLegend?
finalinherited
maxX double
final
maxY double
final
minX double
final
minY double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<Series>
finalinherited
theme ChartTheme
finalinherited
title TitlesData?
finalinherited
toolbox ChartToolbox?
finalinherited
tooltip ChartTooltip?
finalinherited
type ChartType
finalinherited
xAxis XYAxis?
final
xAxisConfig ChartAxisConfig?
finalinherited
yAxis XYAxis?
final
yAxisConfig ChartAxisConfig?
finalinherited

Methods

buildChart() Widget
Method to create the appropriate chart widget
override
copyWith({List<Series>? series, XYAxis? xAxis, XYAxis? yAxis, double? maxX, double? maxY, double? minX, double? minY, double? dotSize, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig}) ScatterChartConfig
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
inherited
toJson() Map<String, dynamic>
Convert configuration to JSON
override
toString() String
A string representation of this object.
inherited
withController(ChartController controller) ScatterChartConfig
Override in concrete configs to return a controller-attached copy.
override
withTheme(ChartTheme theme) ScatterChartConfig
Override in concrete configs to return a themed copy.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited