SimpleConnectedScatterChart class

A connected scatter chart for trajectories through a two-metric space: strategy movement, product maturity, education progress, and path analysis.

Inheritance
Available extensions

Constructors

SimpleConnectedScatterChart({Key? key, required List<SimpleConnectedScatterSeries> series, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minX, double? maxX, double? minY, double? maxY, double height = 260, EdgeInsets padding = _defaultPadding, String? xAxisLabel, String? yAxisLabel, Color? lineColor, Color? pointColor, Color? gridColor, Color? axisColor, Color? activeColor, List<Color>? palette, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showLines = true, bool showPoints = true, bool showArrows = true, bool showLabels = true, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActivePoint = true, bool showAxisLabels = true, bool showEndpointLabels = true, List<SimpleScatterReferenceLine> referenceLines = const [], List<SimpleScatterReferenceBand> referenceBands = const [], int gridLineCount = 4, double? strokeWidth, double pointRadius = 4.5, double arrowSize = 8, SimpleConnectedScatterValueFormatter? xValueFormatter, SimpleConnectedScatterValueFormatter? yValueFormatter, SimpleConnectedScatterValueFormatter? valueFormatter, SimpleConnectedScatterPointTapCallback? onPointTap, SimpleConnectedScatterTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
arrowSize double
final
axisColor Color?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
lineColor Color?
final
maxX double?
final
maxY double?
final
minX double?
final
minY double?
final
onPointTap SimpleConnectedScatterPointTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
pointColor Color?
final
pointRadius double
final
referenceBands List<SimpleScatterReferenceBand>
final
referenceLines List<SimpleScatterReferenceLine>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
series List<SimpleConnectedScatterSeries>
final
showActivePoint bool
final
showArrows bool
final
showAxisLabels bool
final
showEndpointLabels bool
final
showGrid bool
final
showLabels bool
final
showLegend bool
final
showLines bool
final
showPoints bool
final
showTooltip bool
final
showValues bool
final
strokeWidth double?
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleConnectedScatterTooltipBuilder?
final
valueFormatter SimpleConnectedScatterValueFormatter?
final
valueStyle TextStyle?
final
xAxisLabel String?
final
xValueFormatter SimpleConnectedScatterValueFormatter?
final
yAxisLabel String?
final
yValueFormatter SimpleConnectedScatterValueFormatter?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited