SimpleHexbinChart class

A compact hexbin chart for dense scatter, location-like density, clickstream concentration, cohorts, and operational hotspots.

Inheritance
Available extensions

Constructors

SimpleHexbinChart({Key? key, required List<SimpleHexbinPoint> points, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minX, double? maxX, double? minY, double? maxY, double height = 260, EdgeInsets padding = _defaultPadding, String? xAxisLabel, String? yAxisLabel, Color? binColor, Color? emptyBinColor, Color? gridColor, Color? axisColor, Color? activeColor, List<Color>? palette, TextStyle? labelStyle, TextStyle? valueStyle, bool showGrid = true, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActiveBin = true, bool showAxisLabels = true, bool showOutlines = true, bool showEmptyBins = false, bool useLogScale = false, int gridLineCount = 4, double? cellRadius, double minOpacity = 0.28, double maxOpacity = 0.92, SimpleHexbinValueFormatter? valueFormatter, SimpleHexbinValueFormatter? xValueFormatter, SimpleHexbinValueFormatter? yValueFormatter, SimpleHexbinBinTapCallback? onBinTap, SimpleHexbinTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
binColor Color?
final
cellRadius double?
final
emptyBinColor Color?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
maxOpacity double
final
maxX double?
final
maxY double?
final
minOpacity double
final
minX double?
final
minY double?
final
onBinTap SimpleHexbinBinTapCallback?
final
padding EdgeInsets
final
palette List<Color>?
final
points List<SimpleHexbinPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveBin bool
final
showAxisLabels bool
final
showEmptyBins bool
final
showGrid bool
final
showLegend bool
final
showOutlines bool
final
showTooltip bool
final
showValues bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleHexbinTooltipBuilder?
final
useLogScale bool
final
valueFormatter SimpleHexbinValueFormatter?
final
valueStyle TextStyle?
final
xAxisLabel String?
final
xValueFormatter SimpleHexbinValueFormatter?
final
yAxisLabel String?
final
yValueFormatter SimpleHexbinValueFormatter?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited