SimpleSinaPlotChart class

A Sina-style distribution plot that shows every observation with density-aware lateral spread, plus optional mean and median markers.

Inheritance
Available extensions

Constructors

SimpleSinaPlotChart({Key? key, required List<SimpleSinaPlotData> data, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets? padding, List<Color>? palette, Color? dotColor, Color? meanColor, Color? medianColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showLabels = true, bool showValues = false, bool showMean = true, bool showMedian = true, bool showTooltip = true, bool showActiveDot = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? dotRadius, double dotOpacity = 0.76, double densitySpreadFactor = 0.82, double collisionGap = 1.05, SimpleSinaPlotValueFormatter? valueFormatter, SimpleSinaPlotTapCallback? onPointTap, SimpleSinaPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 720), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
axisColor Color?
final
collisionGap double
final
data List<SimpleSinaPlotData>
final
densitySpreadFactor double
final
dotColor Color?
final
dotOpacity double
final
dotRadius double?
final
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
gridColor Color?
final
gridLineCount int
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
includeZero bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelStyle TextStyle?
final
maxValue double?
final
meanColor Color?
final
medianColor Color?
final
minValue double?
final
onPointTap SimpleSinaPlotTapCallback?
final
padding EdgeInsets?
final
palette List<Color>?
final
referenceBands List<SimpleChartReferenceBand>
final
referenceLines List<SimpleChartReferenceLine>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showActiveDot bool
final
showGrid bool
final
showLabels bool
final
showMean bool
final
showMedian bool
final
showTooltip bool
final
showValues bool
final
style SimpleBarChartStyle
final
tooltipBuilder SimpleSinaPlotTooltipBuilder?
final
valueFormatter SimpleSinaPlotValueFormatter?
final
valueStyle TextStyle?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited