SimpleTileMapChart class
A simple tile-map choropleth for regional, territorial, classroom, department, branch, or grid-based comparisons without requiring map shapes.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleTileMapChart
- Available extensions
Constructors
-
SimpleTileMapChart({Key? key, required List<
SimpleTileMapData> data, SimpleTileMapShape shape = SimpleTileMapShape.rounded, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, int? rows, int? columns, double? minValue, double? maxValue, double height = 260, EdgeInsets padding = _defaultPadding, Color? lowColor, Color? highColor, Color? emptyColor, Color? borderColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showLabels = true, bool showValues = true, bool showLegend = true, bool showTooltip = true, bool showActiveTile = true, bool showEmptyTiles = true, double tileGap = 4, double tileRadius = 7, SimpleTileMapValueFormatter? valueFormatter, SimpleTileMapTapCallback? onTileTap, SimpleTileMapTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 680), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - borderColor → Color?
-
final
- columns → int?
-
final
-
data
→ List<
SimpleTileMapData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- emptyColor → Color?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- highColor → Color?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- lowColor → Color?
-
final
- maxValue → double?
-
final
- minValue → double?
-
final
- onTileTap → SimpleTileMapTapCallback?
-
final
- padding → EdgeInsets
-
final
- rows → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- shape → SimpleTileMapShape
-
final
- showActiveTile → bool
-
final
- showEmptyTiles → bool
-
final
- showLabels → bool
-
final
- showLegend → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tileGap → double
-
final
- tileRadius → double
-
final
- tooltipBuilder → SimpleTileMapTooltipBuilder?
-
final
- valueFormatter → SimpleTileMapValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited