SimpleTileMapData class

Constructors

SimpleTileMapData({required String label, required double value, required int row, required int column, String? code, Color? color})
const

Properties

code String?
final
color Color?
final
column int
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
row int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited