SimpleTimelineChart class
A lightweight timeline for milestones, releases, incidents, audits, and learning or project plans.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleTimelineChart
- Available extensions
Constructors
-
SimpleTimelineChart({Key? key, required List<
SimpleTimelineEvent> events, SimpleTimelineOrientation orientation = SimpleTimelineOrientation.vertical, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 280, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? markerColor, Color? connectorColor, Color? activeColor, Color? eventBackgroundColor, TextStyle? dateStyle, TextStyle? titleStyle, TextStyle? descriptionStyle, bool sortByDate = true, bool alternating = false, bool showDates = true, bool showDescriptions = true, bool showTags = true, bool showConnector = true, bool showTooltip = true, bool showActiveEvent = true, double markerRadius = 7, double connectorWidth = 2, double eventSpacing = 14, SimpleTimelineDateFormatter? dateFormatter, SimpleTimelineTapCallback? onEventTap, SimpleTimelineTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 680), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- alternating → bool
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - connectorColor → Color?
-
final
- connectorWidth → double
-
final
- dateFormatter → SimpleTimelineDateFormatter?
-
final
- dateStyle → TextStyle?
-
final
- descriptionStyle → TextStyle?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- eventBackgroundColor → Color?
-
final
-
events
→ List<
SimpleTimelineEvent> -
final
- eventSpacing → double
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- markerColor → Color?
-
final
- markerRadius → double
-
final
- onEventTap → SimpleTimelineTapCallback?
-
final
- orientation → SimpleTimelineOrientation
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveEvent → bool
-
final
- showConnector → bool
-
final
- showDates → bool
-
final
- showDescriptions → bool
-
final
- showTags → bool
-
final
- showTooltip → bool
-
final
- sortByDate → bool
-
final
- style → SimpleBarChartStyle
-
final
- titleStyle → TextStyle?
-
final
- tooltipBuilder → SimpleTimelineTooltipBuilder?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited