SimpleTimelineEvent class

Constructors

SimpleTimelineEvent({required DateTime date, required String title, String? description, String? tag, Color? color})
const

Properties

color Color?
final
date DateTime
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String?
final
title String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited