SimpleTornadoChartData class

Constructors

SimpleTornadoChartData({required String label, required double low, required double high, String? group, Color? lowColor, Color? highColor})
const

Properties

group String?
final
hashCode int
The hash code for this object.
no setterinherited
high double
final
highColor Color?
final
impact double
no setter
label String
final
low double
final
lowColor Color?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited