SimpleTreeDiagramData class

Constructors

SimpleTreeDiagramData({required String label, double value = 0, List<SimpleTreeDiagramData> children = const [], Color? color})
const

Properties

children List<SimpleTreeDiagramData>
final
color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited