WaterfallChartConfig class

Inheritance

Constructors

WaterfallChartConfig({required List<WaterfallItem> items, ChartTheme? theme = ChartTheme.light, bool showConnectors = true, bool showLabels = true, bool showRunningTotal = false, Color increaseColor = const Color(0xFF4CAF50), Color decreaseColor = const Color(0xFFF44336), Color totalColor = const Color(0xFF2196F3), double barWidthFraction = 0.65, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid})
WaterfallChartConfig.fromJson(Map<String, dynamic> json)
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setterinherited
barWidthFraction double
final
controller ChartController?
finalinherited
decreaseColor Color
final
grid GridData?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
increaseColor Color
final
items List<WaterfallItem>
final
legend ChartLegend?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<Series>
finalinherited
showConnectors bool
final
showLabels bool
final
showRunningTotal bool
final
theme ChartTheme
finalinherited
title TitlesData?
finalinherited
toolbox ChartToolbox?
finalinherited
tooltip ChartTooltip?
finalinherited
totalColor Color
final
type ChartType
finalinherited
xAxisConfig ChartAxisConfig?
finalinherited
yAxisConfig ChartAxisConfig?
finalinherited

Methods

buildChart() Widget
Method to create the appropriate chart widget
override
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
inherited
toJson() Map<String, dynamic>
Convert configuration to JSON
override
toString() String
A string representation of this object.
inherited
withController(ChartController controller) BaseChartConfig
Override in concrete configs to return a controller-attached copy.
inherited
withTheme(ChartTheme theme) BaseChartConfig
Override in concrete configs to return a themed copy.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited