SimpleWordCloudChart class

A polished word cloud for survey themes, feedback tags, search terms, learning topics, content analytics, and qualitative signal summaries.

Inheritance
Available extensions

Constructors

SimpleWordCloudChart({Key? key, required List<SimpleWordCloudData> words, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, SimpleWordCloudShape shape = SimpleWordCloudShape.cloud, double height = 260, EdgeInsets padding = _defaultPadding, Color? wordColor, Color? activeColor, Color? labelColor, TextStyle? textStyle, TextStyle? valueStyle, bool showValues = false, bool showLegend = true, bool showTooltip = true, bool showActiveWord = true, bool allowRotation = true, int maxWords = 32, int layoutSeed = 7, double minFontSize = 12, double maxFontSize = 44, double rotationRatio = 0.16, double wordGap = 6, SimpleWordCloudValueFormatter? valueFormatter, SimpleWordCloudTapCallback? onWordTap, SimpleWordCloudTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic})
const

Properties

activeColor Color?
final
allowRotation bool
final
animationCurve Curve
final
animationDuration Duration
final
apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
emptyBuilder WidgetBuilder?
final
excludeFromSemantics bool
final
hashCode int
The hash code for this object.
no setterinherited
height double
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
labelColor Color?
final
layoutSeed int
final
maxFontSize double
final
maxWords int
final
minFontSize double
final
onWordTap SimpleWordCloudTapCallback?
final
padding EdgeInsets
final
rotationRatio double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
shape SimpleWordCloudShape
final
showActiveWord bool
final
showLegend bool
final
showTooltip bool
final
showValues bool
final
style SimpleBarChartStyle
final
textStyle TextStyle?
final
tooltipBuilder SimpleWordCloudTooltipBuilder?
final
valueFormatter SimpleWordCloudValueFormatter?
final
valueStyle TextStyle?
final
wordColor Color?
final
wordGap double
final
words List<SimpleWordCloudData>
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited