BaseChartConfig class abstract

Implementers

Constructors

BaseChartConfig({required ChartType type, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, required List<Series> series, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
BaseChartConfig.fromJson(Map<String, dynamic> json)
Factory method to create chart config from JSON
factory

Properties

apiContract ChartApiContract
Shared API contract for all config-driven chart families.
no setter
controller ChartController?
final
grid GridData?
final
hashCode int
The hash code for this object.
no setterinherited
legend ChartLegend?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
series List<Series>
final
theme ChartTheme
final
title TitlesData?
final
toolbox ChartToolbox?
final
tooltip ChartTooltip?
final
type ChartType
final
xAxisConfig ChartAxisConfig?
final
yAxisConfig ChartAxisConfig?
final

Methods

buildChart() Widget
Method to create the appropriate chart widget
getMaxSeriesValue() double
Safe maximum value with 10% headroom.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsApiField(String field) bool
toJson() Map<String, dynamic>
Convert configuration to JSON
toString() String
A string representation of this object.
inherited
withController(ChartController controller) BaseChartConfig
Override in concrete configs to return a controller-attached copy.
withTheme(ChartTheme theme) BaseChartConfig
Override in concrete configs to return a themed copy.

Operators

operator ==(Object other) bool
The equality operator.
inherited