ChartDataMode enum
Data handling mode for chart series rendering.
- regular: disable sampling, render as-is.
- auto: use LargeDataSamplingConfig.enabled and threshold rules.
- large: force sampling path for supported chart types.
Values
- regular → const ChartDataMode
- auto → const ChartDataMode
- large → const ChartDataMode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChartDataMode> - A constant List of the values in this enum, in order of their declaration.