PathAnimator class

Draws the first progress fraction of path onto canvas.

Used for the "draw" animation type where a line is drawn left-to-right.

Constructors

PathAnimator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

drawPartial(Canvas canvas, Path path, Paint paint, double progress, {bool reverse = false}) → void
Draw progress (0..1) fraction of path using paint.