ChartApiContracts class
Shared contracts for the major Tenun chart API surfaces.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
byName(
String name) → ChartApiContract? -
schemaJson(
) → List< Map< String, dynamic> > -
supporting(
String field) → List< ChartApiContract>
Constants
-
all
→ const List<
ChartApiContract> - cartesian → const ChartApiContract
-
configFoundationFields
→ const List<
String> - densitySpatial → const ChartApiContract
-
displayFields
→ const List<
String> - financial → const ChartApiContract
-
formatterFields
→ const List<
String> - hierarchyFlow → const ChartApiContract
-
interactionFields
→ const List<
String> -
layoutFields
→ const List<
String> - optionConfig → const ChartApiContract
- polar → const ChartApiContract
- simpleWidget → const ChartApiContract
- statistical → const ChartApiContract
- temporal → const ChartApiContract
-
widgetFoundationFields
→ const List<
String>