ChartApiFieldSpec class

Constructors

ChartApiFieldSpec({required String canonicalField, required List<String> aliases, required ChartApiFieldCategory category, required ChartApiFieldValueKind valueKind, required String description, bool configFriendly = true, bool widgetFriendly = true})
const

Properties

aliases List<String>
final
canonicalField String
final
category ChartApiFieldCategory
final
configFriendly bool
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
valueKind ChartApiFieldValueKind
final
widgetFriendly bool
final

Methods

matches(String field) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited