ChartAnimationOptions class

Constructors

ChartAnimationOptions({Duration duration = const Duration(milliseconds: 700), Curve curve = Curves.easeOutCubic})
const

Properties

curve Curve
final
duration Duration
final
hashCode int
The hash code for this object.
no setterinherited
isEnabled bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Duration? duration, Curve? curve}) ChartAnimationOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited