ChartVisibilityOptions class

Constructors

ChartVisibilityOptions({bool showGrid = true, bool showLegend = true, bool showValues = false, bool showLabels = true, bool showAxisLabels = true})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showAxisLabels bool
final
showGrid bool
final
showLabels bool
final
showLegend bool
final
showValues bool
final

Methods

copyWith({bool? showGrid, bool? showLegend, bool? showValues, bool? showLabels, bool? showAxisLabels}) ChartVisibilityOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

clean → const ChartVisibilityOptions