core/chart_builder library

Classes

ChartFactory
Factory class for creating charts from configurations or JSON
TenunChart
Main chart widget that can be configured with either a config object or JSON
TenunChartFromJson
Convenience widget for creating charts directly from JSON

Typedefs

ChartRenderErrorBuilder = Widget Function(BuildContext context, Object error, StackTrace stackTrace)
ChartRenderErrorHandler = void Function(Object error, StackTrace stackTrace)