catchRenderErrors property
If true, config resolution/build errors render a fallback instead of bubbling through Flutter's widget error path.
Implementation
final bool catchRenderErrors;
If true, config resolution/build errors render a fallback instead of bubbling through Flutter's widget error path.
final bool catchRenderErrors;