dropUnsupportedSampling property
If true, unsupported chart types are normalized to regular mode and sampling is disabled during auto-normalization.
Implementation
final bool dropUnsupportedSampling;
If true, unsupported chart types are normalized to regular mode and sampling is disabled during auto-normalization.
final bool dropUnsupportedSampling;