TenunChartFromJson class
Convenience widget for creating charts directly from JSON
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TenunChartFromJson
- Available extensions
Constructors
-
TenunChartFromJson({Key? key, required Map<
String, dynamic> jsonConfig, double? width, double? height, EdgeInsetsGeometry? padding, bool validatePayload = false, bool strictValidation = false, int validationReportMaxIssues = 3, TenunDiagnosticFallbackOptions diagnosticFallbackOptions = const TenunDiagnosticFallbackOptions(), void onValidationResult(ValidationResult result)?, void onPayloadNormalizationResult(PayloadNormalizationResult result)?, void onRuntimeDiagnostics(ChartRuntimeDiagnostics diagnostics)?, ChartRuntimePerformancePolicy runtimePerformancePolicy = ChartRuntimePerformancePolicy.defaults, ChartRenderErrorHandler? onRenderError, Widget validationErrorBuilder(BuildContext context, ValidationResult result)?, ChartRenderErrorBuilder? renderErrorBuilder, bool catchRenderErrors = true, bool autoNormalizePayload = false, bool sanitizeTradingPayload = true, bool dropUnsupportedSampling = true, int? normalizeDefaultThreshold, ChartDataMode normalizeDefaultMode = ChartDataMode.auto, PayloadNormalizationOptions? normalizationOptions}) -
const
Properties
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - autoNormalizePayload → bool
-
final
- catchRenderErrors → bool
-
Render JSON payload failures as a diagnostic fallback by default.
final
- diagnosticFallbackOptions → TenunDiagnosticFallbackOptions
-
final
- dropUnsupportedSampling → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
-
jsonConfig
→ Map<
String, dynamic> -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- normalizationOptions → PayloadNormalizationOptions?
-
final
- normalizeDefaultMode → ChartDataMode
-
final
- normalizeDefaultThreshold → int?
-
final
- onPayloadNormalizationResult → void Function(PayloadNormalizationResult result)?
-
final
- onRenderError → ChartRenderErrorHandler?
-
final
- onRuntimeDiagnostics → void Function(ChartRuntimeDiagnostics diagnostics)?
-
final
- onValidationResult → void Function(ValidationResult result)?
-
final
- padding → EdgeInsetsGeometry?
-
final
- renderErrorBuilder → ChartRenderErrorBuilder?
-
final
- runtimePerformancePolicy → ChartRuntimePerformancePolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sanitizeTradingPayload → bool
-
final
- strictValidation → bool
-
final
- validatePayload → bool
-
final
- validationErrorBuilder → Widget Function(BuildContext context, ValidationResult result)?
-
final
- validationReportMaxIssues → int
-
final
- width → double?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited