ChartObjectCacheStats class

Shared hit/miss/eviction snapshot for lightweight render-object caches.

Constructors

ChartObjectCacheStats({required String name, required int size, required int hits, required int misses, required int evictions, int? maxSize})
const

Properties

evictions int
final
hashCode int
The hash code for this object.
no setterinherited
hitRate double
no setter
hits int
final
maxSize int?
final
misses int
final
name String
final
requests int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited