ChartRenderCacheStats class

Combined diagnostics for the global render-object caches.

Constructors

ChartRenderCacheStats({required ChartObjectCacheStats colors, required ChartObjectCacheStats paints, required ChartObjectCacheStats textPainters, required ChartObjectCacheStats paths})
const

Properties

colors ChartObjectCacheStats
final
hashCode int
The hash code for this object.
no setterinherited
paints ChartObjectCacheStats
final
paths ChartObjectCacheStats
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textPainters ChartObjectCacheStats
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited