PaintCache class

Constructors

PaintCache()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stats ChartObjectCacheStats
no setter

Methods

clear({bool resetMetrics = true}) → void
fill(Color color) Paint
fillMutable(Color color) Paint
Returns a new Paint seeded from the cached fill paint.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resetStats() → void
stroke(Color color, double width) Paint
strokeMutable(Color color, double width) Paint
Returns a new mutable stroke paint seeded from the cache.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited