PayloadDiff class

Constructors

PayloadDiff({required String path, required Object? rawValue, required Object? normalizedValue, bool hasRawValue = true, bool hasNormalizedValue = true, int maxInlineLength = 56})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
hasNormalizedValue bool
final
hasRawValue bool
final
kind PayloadDiffKind
no setter
maxInlineLength int
final
normalizedText String
no setter
normalizedValue Object?
final
path String
final
rawText String
no setter
rawValue Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool includeValues = false}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

valueToInline(Object? value, {int maxLength = 56}) String