PayloadDiffSummary class

Constructors

PayloadDiffSummary({required int added, required int removed, required int changed})
const
PayloadDiffSummary.fromDiffs(Iterable<PayloadDiff> diffs)
factory

Properties

added int
final
changed int
final
compactLabel String
no setter
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setter
isNotEmpty bool
no setter
removed int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited