PayloadNormalizationOptions class

Constructors

PayloadNormalizationOptions({bool dropUnsupportedSampling = true, int? defaultThreshold, ChartDataMode defaultMode = ChartDataMode.auto, bool sanitizeTradingPayload = true, int maxInlineLength = 56})
const
PayloadNormalizationOptions.fromJson(Object? raw, {PayloadNormalizationOptions fallback = const PayloadNormalizationOptions()})
factory

Properties

defaultMode ChartDataMode
final
defaultThreshold int?
final
dropUnsupportedSampling bool
final
hashCode int
The hash code for this object.
no setterinherited
maxInlineLength int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sanitizeTradingPayload bool
final

Methods

copyWith({bool? dropUnsupportedSampling, int? defaultThreshold, bool clearDefaultThreshold = false, ChartDataMode? defaultMode, bool? sanitizeTradingPayload, int? maxInlineLength}) PayloadNormalizationOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolve(Object? raw, {PayloadNormalizationOptions fallback = const PayloadNormalizationOptions()}) PayloadNormalizationOptions
shouldAutoNormalize(Object? raw, {bool fallback = false}) bool