ValidationIssue class
Constructors
- ValidationIssue({required ValidationSeverity severity, required String code, required String message, String? field, String? suggestion})
-
const
Properties
- code → String
-
final
- field → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool
-
no setter
- isWarning → bool
-
no setter
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- severity → ValidationSeverity
-
final
- suggestion → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited