ValidationResult class
Constructors
-
ValidationResult({required List<
ValidationIssue> issues, required ChartType type}) -
const
Properties
-
errors
→ List<
ValidationIssue> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWarnings → bool
-
no setter
-
infos
→ List<
ValidationIssue> -
no setter
-
issues
→ List<
ValidationIssue> -
final
- isValid → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ChartType
-
final
-
warnings
→ List<
ValidationIssue> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toReport(
{int maxIssues = 8}) → ValidationReport -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited