ChartController class

Programmatic control over a live chart widget.

Inheritance

Constructors

ChartController()

Properties

animationTrigger bool
no setter
dataVersion int
no setter
filters Map<String, dynamic>
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
hiddenSeries Set<int>
no setter
highlightedSeries Set<int>
no setter
isBatchingNotifications bool
Whether listener notifications are currently being coalesced.
no setter
isDisposed bool
Whether this controller has been disposed.
no setter
onCrosshairMove CrosshairCallback?
getter/setter pair
onDataPointTap DataPointTapCallback?
getter/setter pair
onExportRequested Stream<void>
no setter
onRangeSelect RangeSelectCallback?
getter/setter pair
onSelectionChanged Stream<ChartSelection?>
no setter
onZoomChanged ZoomChangeCallback?
getter/setter pair
panOffset double
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selection ChartSelection?
no setter
yMax double?
no setter
yMin double?
no setter
zoom ZoomRange
no setter

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
animateToRange(double start, double end, {Duration duration = const Duration(milliseconds: 450)}) Future<void>
Smoothly animate zoom to a fractional range 0..1
batchUpdate(VoidCallback updates) → void
Coalesce multiple controller mutations into one listener notification.
clearFilters() → void
clearSelection() → void
clearYRange() → void
dispose() → void
Discards any resources used by the object.
override
exportToImage(GlobalKey<State<StatefulWidget>> key, {double pixelRatio = 3.0}) Future<Uint8List?>
highlightSeries(int seriesIndex) → void
incrementDataVersion() → void
isSeriesVisible(int seriesIndex) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
pan(double deltaIndex) → void
removeFilter(String key) → void
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
replay() → void
requestExport() → void
resetZoom() → void
resolveHitAt(Offset localPos) → dynamic
selectIndex(int dataIndex, {int seriesIndex = 0, dynamic value}) → void
setFilter(String key, dynamic value) → void
setYRange(double min, double max) → void
syncFilters(Map<String, dynamic> filters) → void
Synchronize filter state without firing user interaction callbacks.
syncSelection(ChartSelection? selection) → void
Synchronize selection state without firing user tap callbacks.
syncSeriesState({Set<int>? highlightedSeries, Set<int>? hiddenSeries}) → void
Synchronize highlight/visibility state without replaying UI callbacks.
syncViewport(ZoomRange zoom, double panOffset) → void
toggleSeriesHighlight(int seriesIndex) → void
toggleSeriesVisibility(int seriesIndex) → void
toString() String
A string representation of this object.
inherited
unhighlightSeries(int seriesIndex) → void
updateData(List newData) → void
zoomTo({int start = 0, int end = -1, double factor = 1.0}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited