ChartIndexRange class

Constructors

ChartIndexRange({required int start, required int end})
const

Properties

count int
no setter
end int
final
hashCode int
The hash code for this object.
no setteroverride
isEmpty bool
no setter
isNotEmpty bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

empty → const ChartIndexRange