ZoomRange class

Defines the visible x-range and zoom level.

Constructors

ZoomRange({int start = 0, int end = -1, double factor = 1.0})
const

Properties

end int
final
factor double
final
hashCode int
The hash code for this object.
no setteroverride
isZoomed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
final

Methods

normalized() ZoomRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override
visibleIndexRange(int dataLength) ChartIndexRange

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

full → const ZoomRange