ChartDataCacheAdmissionReason enum
Explains why a cache path was admitted or skipped for a processing run.
Values
- eligible → const ChartDataCacheAdmissionReason
- forcedOn → const ChartDataCacheAdmissionReason
- forcedOff → const ChartDataCacheAdmissionReason
- disabled → const ChartDataCacheAdmissionReason
- noEntryCapacity → const ChartDataCacheAdmissionReason
- noByteCapacity → const ChartDataCacheAdmissionReason
- emptyEffectiveWindow → const ChartDataCacheAdmissionReason
- belowEffectivePointThreshold → const ChartDataCacheAdmissionReason
- extractionDisabled → const ChartDataCacheAdmissionReason
- noExtractionEntryCapacity → const ChartDataCacheAdmissionReason
- noExtractionByteCapacity → const ChartDataCacheAdmissionReason
- belowExtractionPointThreshold → const ChartDataCacheAdmissionReason
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChartDataCacheAdmissionReason> - A constant List of the values in this enum, in order of their declaration.