ChartDataProcessingCacheStats class
Runtime diagnostics for the chart data processing cache.
Constructors
- ChartDataProcessingCacheStats({required bool enabled, required int size, required int maxEntries, required int minPointCount, required int hits, required int misses, required int writes, required int evictions, int currentBytes = 0, int maxBytes = 0, int largestEntryBytes = 0, int evictedBytes = 0, int skippedWrites = 0, bool extractionCacheEnabled = false, int extractionSize = 0, int maxExtractionEntries = 0, int extractionCurrentBytes = 0, int maxExtractionBytes = 0, int extractionLargestEntryBytes = 0, int minExtractionPointCount = 0, int extractionHits = 0, int extractionMisses = 0, int extractionWrites = 0, int extractionEvictions = 0, int extractionEvictedBytes = 0, int extractionSkippedWrites = 0})
-
const
Properties
- currentBytes → int
-
final
- enabled → bool
-
final
- evictedBytes → int
-
final
- evictions → int
-
final
- extractionCacheEnabled → bool
-
final
- extractionCurrentBytes → int
-
final
- extractionEvictedBytes → int
-
final
- extractionEvictions → int
-
final
- extractionHitRate → double
-
no setter
- extractionHits → int
-
final
- extractionLargestEntryBytes → int
-
final
- extractionLookups → int
-
no setter
- extractionMisses → int
-
final
- extractionSize → int
-
final
- extractionSkippedWrites → int
-
final
- extractionWrites → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hitRate → double
-
no setter
- hits → int
-
final
- largestEntryBytes → int
-
final
- lookups → int
-
no setter
- maxBytes → int
-
final
- maxEntries → int
-
final
- maxExtractionBytes → int
-
final
- maxExtractionEntries → int
-
final
- minExtractionPointCount → int
-
final
- minPointCount → int
-
final
- misses → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
final
- skippedWrites → int
-
final
- writes → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited