ChartDataProcessingCacheWriteReport class

Constructors

ChartDataProcessingCacheWriteReport({required bool written, required ChartDataCacheWriteReason reason, required ChartDataCacheAdmissionReason admissionReason, int estimatedBytes = 0, int maxBytes = 0})
const

Properties

admissionReason ChartDataCacheAdmissionReason
final
estimatedBytes int
final
hashCode int
The hash code for this object.
no setterinherited
maxBytes int
final
reason ChartDataCacheWriteReason
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
written bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited