ChartStats class

Pre-computed stats across all series in a chart.

Constructors

ChartStats({required double globalMin, required double globalMax, required double globalSum, required List<SeriesStats> perSeries})
const

Properties

globalMax double
final
globalMin double
final
globalSum double
final
hashCode int
The hash code for this object.
no setterinherited
perSeries List<SeriesStats>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

empty → const ChartStats