ProcessedSeries class
Sampled version of a series ready for rendering.
Constructors
-
ProcessedSeries({required Series series, required List<
DataPoint> points, required List<double> sampledValues, required SeriesStats stats, List<int> sourceIndices = const []}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
points
→ List<
DataPoint> -
Sampled (or full) data points — x = original source index.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sampledValues
→ List<
double> -
Sampled raw doubles — avoids re-extraction from points.
final
- series → Series
-
Original series metadata.
final
-
sourceIndices
→ List<
int> -
Source indices for sampled values. This preserves viewport/source
positions after downsampling.
final
- stats → SeriesStats
-
Pre-computed stats (on full dataset, before sampling).
final
- wasDownsampled → bool
-
Whether this series was downsampled.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited