ChartPointValue class

A normalized 2D point read from flexible chart JSON data.

Constructors

ChartPointValue({required double x, required double y, String? label, Object? raw})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String?
final
raw Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited