chartBuilder property
Builder function that renders the chart using the validated configuration.
Implementation
final Widget Function(BaseChartConfig config) chartBuilder;
Builder function that renders the chart using the validated configuration.
final Widget Function(BaseChartConfig config) chartBuilder;