ChartExportBatchOptions class

Constructors

ChartExportBatchOptions({bool stopOnFirstFailure = false, bool skipUnavailable = false, bool continueOnProgressError = false, Duration? timeout, ChartExportCancellationToken? cancellationToken, ChartExportBatchProgressHandler? onProgress, ChartExportBatchProgressErrorHandler? onProgressError})
const

Properties

cancellationToken ChartExportCancellationToken?
final
continueOnProgressError bool
final
hashCode int
The hash code for this object.
no setterinherited
onProgress ChartExportBatchProgressHandler?
final
onProgressError ChartExportBatchProgressErrorHandler?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipUnavailable bool
final
stopOnFirstFailure bool
final
timeout Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited