ChartExportBatchResult class

Available extensions

Constructors

ChartExportBatchResult(Iterable<ChartExportResult> results, {Iterable<ChartExportCapability> skippedUnavailable = const [], int? requestedCount})
factory

Properties

completedWithoutOutput bool
no setter
failed List<ChartExportResult>
no setter
failureCount int
no setter
hasFailures bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasIssues bool
no setter
hasNotRun bool
no setter
hasOutput bool
no setter
hasSkippedUnavailable bool
no setter
issueCount int
no setter
issueMessages List<String>
no setter
notRunCount int
no setter
outputCount int
no setter
primaryIssue String?
no setter
requestedCount int
final
results List<ChartExportResult>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedUnavailable List<ChartExportCapability>
final
skippedUnavailableCount int
no setter
skippedUnavailableMessages List<String>

Available on ChartExportBatchResult, provided by the ChartExportBatchSummary extension

no setter
success bool
no setter
successCount int
no setter
successful List<ChartExportResult>
no setter
totalDurationMicros int
no setter
totalSizeBytes int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resultFor(ChartExportFormat format) ChartExportResult?
resultsFor(ChartExportFormat format) List<ChartExportResult>
summaryText({bool includeSize = true}) String

Available on ChartExportBatchResult, provided by the ChartExportBatchSummary extension

toMetadataJson({bool includePayload = false}) Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited