ChartExportCancellationToken class

Properties

hashCode int
The hash code for this object.
no setterinherited
isCancelled bool
no setter
reason String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
whenCancelled Future<void>
no setter

Methods

cancel([String reason = 'Operation cancelled.']) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited