ChartExportArchive class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
deliveryBatchZip(ChartExportDeliveryBatchResult batch, {String filename = defaultDeliveryFilename, bool includeManifest = true, String manifestFilename = defaultManifestFilename, DateTime? createdAt})
→ ChartExportFile
-
Bundle successfully delivered files into a ZIP file.
-
exportBatchZip(ChartExportBatchResult batch, {String filename = defaultExportFilename, bool includeManifest = true, String manifestFilename = defaultManifestFilename, DateTime? createdAt})
→ ChartExportFile
-
Bundle successful export results into a ZIP file.
-
filesZip(Iterable<ChartExportFile> files, {String filename = defaultExportFilename, Map<String, Object?> metadata = const {}})
→ ChartExportFile
-
Bundle arbitrary export files into a ZIP file.