ChartExportDelivery class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

chain(Iterable<ChartExportDeliveryAdapter> adapters, {ChartExportDeliveryIntent intent = ChartExportDeliveryIntent.custom, bool stopOnFirstFailure = true}) ChartExportDeliveryAdapter
deliverBatch(ChartExportBatchResult batch, ChartExportDeliveryAdapter adapter, {Duration? timeout, ChartExportCancellationToken? cancellationToken, ChartExportDeliveryBatchOptions batchOptions = const ChartExportDeliveryBatchOptions()}) Future<ChartExportDeliveryBatchResult>
deliverFile(ChartExportFile file, ChartExportDeliveryAdapter adapter, {Duration? timeout, ChartExportCancellationToken? cancellationToken}) Future<ChartExportDeliveryResult>
deliverFiles(Iterable<ChartExportFile> files, ChartExportDeliveryAdapter adapter, {Duration? timeout, ChartExportCancellationToken? cancellationToken, ChartExportDeliveryBatchOptions batchOptions = const ChartExportDeliveryBatchOptions()}) Future<ChartExportDeliveryBatchResult>
deliverResult(ChartExportResult result, ChartExportDeliveryAdapter adapter, {Duration? timeout, ChartExportCancellationToken? cancellationToken}) Future<ChartExportDeliveryResult>
dryRun({ChartExportDeliveryIntent intent = ChartExportDeliveryIntent.custom}) ChartExportDeliveryAdapter
exportAllAndDeliver(Iterable<ChartExportRequest> requests, ChartExportDeliveryAdapter adapter, {Duration? deliveryTimeout, ChartExportCancellationToken? deliveryCancellationToken, ChartExportBatchOptions exportBatchOptions = const ChartExportBatchOptions(), ChartExportDeliveryBatchOptions deliveryBatchOptions = const ChartExportDeliveryBatchOptions()}) Future<ChartExportDeliveryBatchResult>
exportAndDeliver(ChartExportRequest request, ChartExportDeliveryAdapter adapter, {Duration? deliveryTimeout, ChartExportCancellationToken? deliveryCancellationToken}) Future<ChartExportDeliveryResult>
fileFromResult(ChartExportResult result) ChartExportFile
filesFromBatch(ChartExportBatchResult batch) List<ChartExportFile>
filesFromResults(Iterable<ChartExportResult> results) List<ChartExportFile>
withRetry(ChartExportDeliveryAdapter adapter, {int maxAttempts = 3, Duration delay = Duration.zero, ChartExportDeliveryRetryPredicate? shouldRetry, ChartExportDeliveryRetryDelayBuilder? delayBuilder}) ChartExportDeliveryAdapter