ChartExportDeliveryBatchOptions class
Constructors
- ChartExportDeliveryBatchOptions({bool stopOnFirstFailure = false, bool continueOnProgressError = false, Duration? timeout, ChartExportCancellationToken? cancellationToken, ChartExportDeliveryBatchProgressHandler? onProgress, ChartExportDeliveryBatchProgressErrorHandler? onProgressError})
-
const
Properties
- cancellationToken → ChartExportCancellationToken?
-
final
- continueOnProgressError → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onProgress → ChartExportDeliveryBatchProgressHandler?
-
final
- onProgressError → ChartExportDeliveryBatchProgressErrorHandler?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stopOnFirstFailure → bool
-
final
- timeout → Duration?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited