ChartExportDeliveryBatchProgress class

Constructors

ChartExportDeliveryBatchProgress({required int completed, required int total, required ChartExportDeliveryResult result})
const

Properties

completed int
final
fraction double
no setter
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
no setter
remaining int
no setter
result ChartExportDeliveryResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadataJson({bool includePayload = false}) Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited