ChartExportDeliveryBatchResult class

Available extensions

Properties

failed List<ChartExportDeliveryResult>
no setter
failureCount int
no setter
files List<ChartExportFile>
no setter
hasFailures bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasIssues bool
no setter
hasOutput bool
no setter
issueCount int
no setter
issueMessages List<String>
no setter
outputCount int
no setter
primaryIssue String?
no setter
results List<ChartExportDeliveryResult>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success bool
no setter
successCount int
no setter
successful List<ChartExportDeliveryResult>
no setter
totalDurationMicros int
no setter
totalSizeBytes int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
summaryText({bool includeSize = true}) String

Available on ChartExportDeliveryBatchResult, provided by the ChartExportDeliveryBatchSummary extension

toMetadataJson({bool includePayload = false}) Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited