ChartExportFilename class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sanitize(String? filename, {String fallback = defaultFallback, int maxLength = defaultMaxLength}) String
withExtension(String? filename, String extension, {String fallback = defaultFallback, int maxLength = defaultMaxLength}) String

Constants

defaultFallback → const String
defaultMaxLength → const int