ChartExportJobCallbackError class

Constructors

ChartExportJobCallbackError({required String callbackName, required Object error, required StackTrace stackTrace, ChartExportJobStage? stage})
const

Properties

callbackName String
final
error Object
final
hashCode int
The hash code for this object.
no setterinherited
message String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace
final
stage ChartExportJobStage?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadataJson({bool includeStackTrace = false}) Map<String, Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited