ChartExportJobController class
Constructors
- ChartExportJobController({ChartExportCancellationToken? cancellationToken})
Properties
- cancellationToken → ChartExportCancellationToken
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
no setter
- isRunning → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
cancel(
[String reason = 'Export job cancelled.']) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
ChartExportJobOptions options) → Future< ChartExportJobResult> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited