ChartExportJobOptions class

Constructors

ChartExportJobOptions({Iterable<ChartExportFormat> formats = ChartExportFormat.values, Iterable<ChartExportRequest>? requests, BaseChartConfig? config, Map<String, dynamic>? jsonConfig, List<List<Object?>>? rows, GlobalKey<State<StatefulWidget>>? boundaryKey, List<String>? categoryLabels, String? filename = ChartExportFilename.defaultFallback, String sheetName = 'Chart Data', String delimiter = ',', String lineEnding = '\r\n', double pixelRatio = 2.0, int jpegQuality = 90, Color jpegBackgroundColor = Colors.white, Duration? exportTimeout, Duration? deliveryTimeout, ChartExportCancellationToken? cancellationToken, bool stopBatchOnFirstFailure = false, bool skipUnavailable = false, bool stopDeliveryOnFirstFailure = false, ChartExportDeliveryAdapter? deliveryAdapter, bool deliverExports = false, bool createArchive = false, bool deliverArchive = false, String? archiveFilename, bool includeArchiveManifest = true, String archiveManifestFilename = ChartExportArchive.defaultManifestFilename, ChartExportJobPreflightPolicy preflightPolicy = ChartExportJobPreflightPolicy.failOnBlockers, bool continueOnCallbackError = true, ChartExportBatchReadyHandler? onExportBatchReady, ChartExportBatchProgressHandler? onExportProgress, ChartExportDeliveryBatchProgressHandler? onDeliveryProgress, ChartExportJobProgressHandler? onProgress, ChartExportJobCallbackErrorHandler? onCallbackError, ChartExportJobEventHandler? onEvent})

Properties

archiveFilename String?
final
archiveManifestFilename String
final
boundaryKey GlobalKey<State<StatefulWidget>>?
final
cancellationToken ChartExportCancellationToken?
final
categoryLabels List<String>?
final
config BaseChartConfig?
final
continueOnCallbackError bool
final
createArchive bool
final
delimiter String
final
deliverArchive bool
final
deliverExports bool
final
deliveryAdapter ChartExportDeliveryAdapter?
final
deliveryTimeout Duration?
final
exportTimeout Duration?
final
filename String?
final
formats List<ChartExportFormat>
final
hasDeliveryAdapter bool
no setter
hashCode int
The hash code for this object.
no setterinherited
includeArchiveManifest bool
final
jpegBackgroundColor Color
final
jpegQuality int
final
jsonConfig Map<String, dynamic>?
final
lineEnding String
final
onCallbackError ChartExportJobCallbackErrorHandler?
final
onDeliveryProgress ChartExportDeliveryBatchProgressHandler?
final
onEvent ChartExportJobEventHandler?
final
onExportBatchReady ChartExportBatchReadyHandler?
final
onExportProgress ChartExportBatchProgressHandler?
final
onProgress ChartExportJobProgressHandler?
final
pixelRatio double
final
preflightPolicy ChartExportJobPreflightPolicy
final
requests List<ChartExportRequest>?
final
rows List<List<Object?>>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheetName String
final
shouldBuildArchive bool
no setter
shouldFailOnPreflightBlockers bool
no setter
skipUnavailable bool
final
stopBatchOnFirstFailure bool
final
stopDeliveryOnFirstFailure bool
final

Methods

buildPlan() ChartExportJobPlan
buildRequests() List<ChartExportRequest>
deliveryBatchOptions({ChartExportCancellationToken? effectiveCancellationToken, ChartExportDeliveryBatchProgressHandler? onProgress}) ChartExportDeliveryBatchOptions
exportBatchOptions({ChartExportCancellationToken? effectiveCancellationToken}) ChartExportBatchOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited