ChartExportJobPlanIssue class

Constructors

ChartExportJobPlanIssue({required String code, required String message, required ChartExportJobPlanIssueSeverity severity, int? requestIndex, ChartExportFormat? format})
const

Properties

code String
final
format ChartExportFormat?
final
hashCode int
The hash code for this object.
no setterinherited
isBlocker bool
no setter
isWarning bool
no setter
message String
final
requestIndex int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity ChartExportJobPlanIssueSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadataJson() Map<String, Object?>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited