ChartExportJobPlannedRequest class

Constructors

ChartExportJobPlannedRequest({required int index, required ChartExportRequest request, required ChartExportCapability capability})
const

Properties

canExport bool
no setter
capability ChartExportCapability
final
filename String
no setter
format ChartExportFormat
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
final
isUnavailable bool
no setter
request ChartExportRequest
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadataJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited