ChartExportJobProgress class

Constructors

ChartExportJobProgress({required ChartExportJobStage stage, required int completed, required int total, required String message, ChartExportBatchProgress? exportProgress, ChartExportDeliveryBatchProgress? deliveryProgress})
const

Properties

completed int
final
deliveryProgress ChartExportDeliveryBatchProgress?
final
exportProgress ChartExportBatchProgress?
final
fraction double
no setter
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
no setter
message String
final
remaining int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stage ChartExportJobStage
final
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMetadataJson({bool includePayload = false}) Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited