ChartExportJobResult class

Constructors

ChartExportJobResult({required ChartExportBatchResult exportBatch, ChartExportJobPlan? plan, ChartExportDeliveryBatchResult? exportDelivery, ChartExportFile? archive, ChartExportDeliveryResult? archiveDelivery, ChartExportJobTiming? timing, bool preflightBlocked = false, String? cancellationReason, Iterable<ChartExportJobEvent> events = const [], Iterable<String> warnings = const []})

Properties

archive ChartExportFile?
final
archiveDelivery ChartExportDeliveryResult?
final
cancellationReason String?
final
completed bool
no setter
duration Duration?
no setter
events List<ChartExportJobEvent>
final
exportBatch ChartExportBatchResult
final
exportDelivery ChartExportDeliveryBatchResult?
final
exportFiles List<ChartExportFile>
no setter
failedExports List<ChartExportResult>
no setter
hasEvents bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasIssues bool
no setter
hasOutput bool
no setter
isCancelled bool
no setter
isCompletedWithIssues bool
no setter
isFailed bool
no setter
isSucceeded bool
no setter
issueCount int
no setter
issueMessages List<String>
no setter
lastEvent ChartExportJobEvent?
no setter
outputCount int
no setter
outputFilenames List<String>
no setter
outputFiles List<ChartExportFile>
no setter
plan ChartExportJobPlan?
final
preflightBlocked bool
final
primaryIssue String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stageDurations Map<ChartExportJobStage, Duration>
no setter
status ChartExportJobStatus
no setter
statusText String
no setter
success bool
no setter
successfulExports List<ChartExportResult>
no setter
timing ChartExportJobTiming?
final
totalSizeBytes int
no setter
warnings List<String>
final

Methods

eventsOfType(ChartExportJobEventType type) List<ChartExportJobEvent>
exportFileFor(ChartExportFormat format) ChartExportFile?
exportResultFor(ChartExportFormat format) ChartExportResult?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
outputFileNamed(String filename) ChartExportFile?
stageDuration(ChartExportJobStage stage) Duration?
summaryText({bool includeSize = true, bool includeTiming = false}) String
toMetadataJson({bool includePayload = false}) Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited