ChartExportJobTiming class

Constructors

ChartExportJobTiming({required DateTime startedAt, required DateTime endedAt, required Duration duration, Map<ChartExportJobStage, Duration> stageDurations = const {}})

Properties

duration Duration
final
durationMicros int
no setter
durationMs double
no setter
endedAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slowestStage ChartExportJobStage?
no setter
slowestStageDuration Duration?
no setter
stageDurations Map<ChartExportJobStage, Duration>
final
startedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stageDuration(ChartExportJobStage stage) Duration?
summaryText() String
toMetadataJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited