core/chart_interaction_layer library

Classes

ChartInteractionLayer
ZoomMinimap
A thin horizontal strip that shows the current zoom window.
ZoomResetButton
A small overlay button shown when the chart is zoomed in.