ChartInteractionLayer class

Inheritance
Available extensions

Constructors

ChartInteractionLayer({Key? key, required ChartZoomController zoomController, required Widget child, void onTap(double fraction)?, void onCrosshairMove(double fraction)?, void onCrosshairEnd()?, void onDoubleTap(double fraction)?})
const

Properties

apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
child Widget
The chart widget rendered underneath this interaction layer.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCrosshairEnd → void Function()?
Called when the crosshair is dismissed (finger lifted).
final
onCrosshairMove → void Function(double fraction)?
Called during a long-press drag (crosshair tracking).
final
onDoubleTap → void Function(double fraction)?
Called when the user double-taps — useful to trigger drill-down.
final
onTap → void Function(double fraction)?
Called when the user taps a data point. fraction is the x-position in 0..1 of the full data range.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
zoomController ChartZoomController
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChartInteractionLayer>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited