ChartJsonOptionCompletion class

Constructors

ChartJsonOptionCompletion({required String schemaName, required String canonicalField, required String containerPath, required String jsonPath, required String label, required String insertText, required List<String> aliases, required bool preferred, String? kind, String? description, ChartJsonOptionValueHint? valueHint})
const
ChartJsonOptionCompletion.fromReference(ChartJsonOptionFieldReference reference, {required String containerPath})
factory

Properties

aliases List<String>
final
canonicalField String
final
containerPath String
final
description String?
final
entrySnippet String
no setter
examplePayloadFragment Map<String, dynamic>
no setter
exampleValue Object?
no setter
hashCode int
The hash code for this object.
no setterinherited
insertText String
final
jsonPath String
final
kind String?
final
label String
final
preferred bool
final
resolvedValueHint ChartJsonOptionValueHint
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaName String
final
valueHint ChartJsonOptionValueHint?
final
valueSnippet String
no setter

Methods

applyToPayload(Map<String, dynamic> payload, {Object? value, bool hasValue = false}) Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
payloadFragment({Object? value, bool hasValue = false}) Map<String, dynamic>
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
validateValue(Object? value) ChartJsonOptionValueValidation

Operators

operator ==(Object other) bool
The equality operator.
inherited