ChartJsonOptionFieldReference class

Constructors

ChartJsonOptionFieldReference({required String schemaName, required String schemaDescription, required String canonicalField, required Map<String, dynamic> field, required List<String> acceptedContainers})
const

Properties

acceptedContainers List<String>
final
aliases List<String>
no setter
canonicalField String
final
description String?
no setter
field Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
kind String?
no setter
preferredContainer String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaDescription String
final
schemaName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited