ChartJsonOptionPatchIssue class

Constructors

ChartJsonOptionPatchIssue({required String code, required ChartJsonOptionPatchIssueSeverity severity, required String message, String? schemaName, String? canonicalField, String? jsonPath, String? valueKey, Object? value, bool hasValue = false, ChartJsonOptionValueValidation? validation})
const
ChartJsonOptionPatchIssue.ignoredValueKey(String valueKey, {Object? value, bool hasValue = false})
factory
ChartJsonOptionPatchIssue.invalidValue(ChartJsonOptionPatchEntry entry)
factory

Properties

canonicalField String?
final
code String
final
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
final
jsonPath String?
final
jsonPointer String?
no setter
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaName String?
final
severity ChartJsonOptionPatchIssueSeverity
final
validation ChartJsonOptionValueValidation?
final
value Object?
final
valueKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited