ChartJsonOptionPatchOperation class

Constructors

ChartJsonOptionPatchOperation({required ChartJsonOptionPatchOperationKind kind, required String schemaName, required String canonicalField, required String jsonPath, required Object? value, required bool hasPreviousValue, required bool isValid, Object? previousValue, String? valueKey})
const
ChartJsonOptionPatchOperation.fromEntry(ChartJsonOptionPatchEntry entry)
factory

Properties

canonicalField String
final
changesValue bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPreviousValue bool
final
isValid bool
final
jsonPath String
final
jsonPointer String
no setter
kind ChartJsonOptionPatchOperationKind
final
previousValue Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaName String
final
value Object?
final
valueKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toJsonPatchOperation() Map<String, dynamic>?
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited