ChartJsonOptionPaths class

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fieldPath(String containerPath, String canonicalField) String
fragment(String jsonPath, Object? value) Map<String, dynamic>
jsonPointer(String path) String
mergeFragment(Map<String, dynamic> base, Map<String, dynamic> fragment) Map<String, dynamic>
mergeFragments(Iterable<Map<String, dynamic>> fragments) Map<String, dynamic>
normalizeContainer(String value) String
sameContainer(String a, String b) bool
segments(String path) List<String>

Constants

root → const String