ChartJsonOptionSchema class

Constructors

ChartJsonOptionSchema({required String name, required String description, required List<String> acceptedContainers, required List<Map<String, dynamic>> fields, Map<String, dynamic> examplePayload = const {}, Map<String, dynamic> exampleChartPayload = const {}})
const

Properties

acceptedContainers List<String>
final
canonicalFields List<String>
no setter
description String
final
exampleChartPayload Map<String, dynamic>
final
examplePayload Map<String, dynamic>
final
fieldReferences List<ChartJsonOptionFieldReference>
no setter
fields List<Map<String, dynamic>>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptsContainer(String containerPath) bool
canonicalFieldFor(String fieldName) String?
fieldJsonFor(String fieldName) Map<String, dynamic>?
fieldReferenceFor(String fieldName) ChartJsonOptionFieldReference?
matchesName(String value) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsField(String fieldName) bool
toJson({bool includeExamplePayload = true, bool includeExampleChartPayload = true}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited