ChartJsonOptionSchemas class

Public schema registry for cross-cutting JSON option groups.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

byName(String name) ChartJsonOptionSchema?
canonicalFieldFor(String fieldName, {String? schemaName, String? containerPath}) String?
exampleChartPayloadFor(String name) Map<String, dynamic>?
exampleChartPayloads() Map<String, Map<String, dynamic>>
examplePayloadFor(String name) Map<String, dynamic>?
examplePayloads() Map<String, Map<String, dynamic>>
fieldJsonFor(String fieldName, {String? schemaName, String? containerPath}) Map<String, dynamic>?
fieldReferenceFor(String fieldName, {String? schemaName, String? containerPath}) ChartJsonOptionFieldReference?
fieldReferences({String? containerPath}) List<ChartJsonOptionFieldReference>
forContainer(String containerPath) List<ChartJsonOptionSchema>
forField(String fieldName, {String? containerPath}) List<ChartJsonOptionSchema>
schemaForField(String fieldName, {String? containerPath}) ChartJsonOptionSchema?
schemaJson({bool includeExamplePayload = true, bool includeExampleChartPayload = true}) List<Map<String, dynamic>>
schemaJsonForContainer(String containerPath, {bool includeExamplePayload = true, bool includeExampleChartPayload = true}) List<Map<String, dynamic>>