ChartJsonOptionValueHint class

Constructors

ChartJsonOptionValueHint({required String? kind, required Object? value, required String jsonLiteral, List<Object?> examples = const []})
const
ChartJsonOptionValueHint.forKind(String? kind, {String? canonicalField})
factory

Properties

examples List<Object?>
final
hashCode int
The hash code for this object.
no setterinherited
jsonLiteral String
final
kind String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited
validate(Object? candidate, {String? canonicalField}) ChartJsonOptionValueValidation

Operators

operator ==(Object other) bool
The equality operator.
inherited