ChartJsonOptionValueValidation class

Constructors

ChartJsonOptionValueValidation({required String? canonicalField, required String? kind, required Object? value, required bool isValid, String? message})
const

Properties

canonicalField String?
final
hashCode int
The hash code for this object.
no setterinherited
isValid bool
final
kind String?
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited