ChartPayloadDoctorReport class

Constructors

ChartPayloadDoctorReport({required ChartType type, required ChartSeriesDataShape expectedShape, required ChartSeriesDataShape inferredShape, required ChartPayloadContract payloadContract, required ChartApiContract apiContract, required ValidationResult rawValidation, required ValidationResult normalizedValidation, required PayloadNormalizationResult normalization, required List<ChartPayloadDoctorFinding> findings})
const

Properties

apiContract ChartApiContract
final
canNormalizeToValid bool
no setter
expectedShape ChartSeriesDataShape
final
findings List<ChartPayloadDoctorFinding>
final
hasErrors bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasWarnings bool
no setter
inferredShape ChartSeriesDataShape
final
normalization PayloadNormalizationResult
final
normalizedValidation ValidationResult
final
payloadContract ChartPayloadContract
final
quickFixes List<String>
no setter
rawValidation ValidationResult
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ChartPayloadDoctorStatus
no setter
summary String
no setter
type ChartType
final
typeString String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool includePayloads = false, bool includeDiffValues = false}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited