RegistrationBundle class

A named group of ChartRegistration objects.

Bundles are the unit of optional inclusion — register a whole bundle to pull in a category of charts:

ChartRegistry.registerAll(CoreCharts.bundle);
ChartRegistry.registerAll(TradingCharts.bundle);

Constructors

RegistrationBundle({required String name, required String description, required List<ChartRegistration> registrations})
const

Properties

description String
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
registrations List<ChartRegistration>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() → void
Register all charts in this bundle.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited