clearDirty method
void
clearDirty()
Call at the end of paint to clear the dirty flag.
Implementation
void clearDirty() => _dirty = false;
Call at the end of paint to clear the dirty flag.
void clearDirty() => _dirty = false;