ChartRenderLayerReport class

Per-layer timing/cache report emitted by ChartRenderPipeline.

Constructors

ChartRenderLayerReport({required String name, required bool cacheable, required bool dirtyBeforePaint, required bool sizeChanged, required bool cacheHit, required bool recordedPicture, bool retainedPicture = false, bool skippedPictureCacheWrite = false, required bool livePaint, required Duration paintDuration})
const

Properties

cacheable bool
final
cacheHit bool
final
dirtyBeforePaint bool
final
hashCode int
The hash code for this object.
no setterinherited
livePaint bool
final
name String
final
paintDuration Duration
final
recordedPicture bool
final
retainedPicture bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sizeChanged bool
final
skippedPictureCacheWrite bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited