ChartRenderPipeline class
Orchestrates an ordered stack of RenderLayer objects.
Layers are painted in order (index 0 = bottom, last = top).
Constructors
-
ChartRenderPipeline(List<
RenderLayer> layers, {ChartRenderPipelineDiagnosticsCallback? onReport, bool enableDiagnostics = false})
Properties
- enableDiagnostics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDisposed → bool
-
no setter
- lastReport → ChartRenderPipelineReport?
-
no setter
- onReport → ChartRenderPipelineDiagnosticsCallback?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
markAllDirty(
) → void - Mark all layers dirty (equivalent to full repaint).
-
markDirty<
T extends RenderLayer> () → void -
Mark a specific layer dirty by type
T. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
paint(
Canvas canvas, Size size) → void -
Execute all layers in order onto
canvas. -
setSize(
Size size) → void - Update canvas size — propagated to all layers.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited