ChartRenderPipelineReport class

Aggregate paint timing/cache report for one pipeline frame.

Constructors

ChartRenderPipelineReport({required Size size, required Duration totalPaintDuration, required List<ChartRenderLayerReport> layers})
const

Properties

cacheHits int
no setter
cacheMisses int
no setter
dirtyLayers int
no setter
hashCode int
The hash code for this object.
no setterinherited
layerCount int
no setter
layers List<ChartRenderLayerReport>
final
livePaints int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size Size
final
sizeChangedLayers int
no setter
skippedPictureCacheWrites int
no setter
totalPaintDuration Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited