ChartRuntimePerformancePolicy class

Tunable thresholds for runtime performance recommendations.

Constructors

ChartRuntimePerformancePolicy({int largeDatasetPointThreshold = defaultLargeDatasetPointThreshold, double cachePressureWarningThreshold = defaultCachePressureWarningThreshold, double lowRenderCacheHitRateThreshold = defaultLowRenderCacheHitRateThreshold, int lowRenderCacheMinRequests = defaultLowRenderCacheMinRequests})
const
ChartRuntimePerformancePolicy.fromJson(Object? json, {ChartRuntimePerformancePolicy fallback = ChartRuntimePerformancePolicy.defaults})
Resolve a policy from a JSON/config object.
factory

Properties

cachePressureWarningThreshold double
final
hashCode int
The hash code for this object.
no setterinherited
largeDatasetPointThreshold int
final
lowRenderCacheHitRateThreshold double
final
lowRenderCacheMinRequests int
final
normalizedCachePressureWarningThreshold double
no setter
normalizedLargeDatasetPointThreshold int
no setter
normalizedLowRenderCacheHitRateThreshold double
no setter
normalizedLowRenderCacheMinRequests int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stableSignature String
no setter

Methods

copyWith({int? largeDatasetPointThreshold, double? cachePressureWarningThreshold, double? lowRenderCacheHitRateThreshold, int? lowRenderCacheMinRequests}) ChartRuntimePerformancePolicy
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

resolve(Object? json, {ChartRuntimePerformancePolicy fallback = ChartRuntimePerformancePolicy.defaults}) ChartRuntimePerformancePolicyResolution