ChartRuntimePerformancePolicyResolution class
Constructors
- ChartRuntimePerformancePolicyResolution({required ChartRuntimePerformancePolicy policy, required ChartRuntimePerformancePolicySource source, String? sourcePath})
-
const
- ChartRuntimePerformancePolicyResolution.fallback(ChartRuntimePerformancePolicy policy)
-
const
- ChartRuntimePerformancePolicyResolution.json(ChartRuntimePerformancePolicy policy, {String? sourcePath})
-
const
Properties
- fromJson → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- policy → ChartRuntimePerformancePolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → ChartRuntimePerformancePolicySource
-
final
- sourceLabel → String
-
no setter
- sourcePath → String?
-
final
- stableSignature → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited