ChartRuntimePerformancePolicyFieldSpec class

Constructors

ChartRuntimePerformancePolicyFieldSpec({required String canonicalField, required List<String> aliases, required ChartRuntimePerformancePolicyFieldKind kind, required String description})
const

Properties

aliases List<String>
final
canonicalField String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
kind ChartRuntimePerformancePolicyFieldKind
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

matches(String field) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited