controllerCount property
int
get
controllerCount
Number of live controllers currently registered in the group.
Implementation
int get controllerCount => _controllers.length;
Number of live controllers currently registered in the group.
int get controllerCount => _controllers.length;