remove method
Remove a controller from the group and stop synchronization.
Implementation
void remove(ChartController ctrl) {
if (_disposed) return;
if (_controllers.remove(ctrl)) {
_detach(ctrl);
}
}
Remove a controller from the group and stop synchronization.
void remove(ChartController ctrl) {
if (_disposed) return;
if (_controllers.remove(ctrl)) {
_detach(ctrl);
}
}