ChartPalette class

An ordered list of series colors.

Constructors

ChartPalette(List<String> colors)
const

Properties

colors List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

colorAt(int index) String
colorObjectAt(int index) Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

earthy → const ChartPalette
material → const ChartPalette
ocean → const ChartPalette
pastel → const ChartPalette
vivid → const ChartPalette