ChartSpacing class
Constructors
- ChartSpacing({double chartPaddingLeft = 48, double chartPaddingRight = 16, double chartPaddingTop = 16, double chartPaddingBottom = 32, double legendGap = 12, double legendIconSize = 10, double tooltipPadding = 8, double barBorderRadius = 4, double dotRadius = 4, double strokeWidth = 2, double gridLineWidth = 0.5})
-
const
Properties
- barBorderRadius → double
-
final
- chartPaddingBottom → double
-
final
- chartPaddingLeft → double
-
final
- chartPaddingRight → double
-
final
- chartPaddingTop → double
-
final
- dotRadius → double
-
final
- gridLineWidth → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legendGap → double
-
final
- legendIconSize → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
final
- tooltipPadding → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited