AdaptiveCullingConfig class

Adaptive threshold & viewport culling for massive datasets (>50k pts).

Constructors

AdaptiveCullingConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getRenderThreshold(BuildContext context, int totalPoints) int

Constants

maxRenderThreshold → const int
minRenderThreshold → const int
ultraLargePointCount → const int