ChartZipStoreWriter class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
writeBytes(
Map< String, Uint8List> files) → Uint8List - Write byte files to a dependency-free ZIP archive.
-
writeFiles(
Iterable< ChartZipStoreFile> files) → Uint8List - Write files to a dependency-free ZIP archive.
-
writeText(
Map< String, String> files) → Uint8List - Write UTF-8 text files to a dependency-free ZIP archive.