DataSampler class

Constructors

DataSampler()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

auto(List<DataPoint> data, int threshold, {SamplingStrategy? forceStrategy}) List<DataPoint>
Automatically samples data to threshold points.
fromDoubles(List<double> values) List<DataPoint>
Convert List<double> to DataPoint list with index-based x values, skipping non-finite values.
fromRaw(List raw) List<DataPoint>
Convert raw numeric series data to DataPoint list.