targetShape static method
Returns the expected data shape for a chart type.
Implementation
static registry.ChartSeriesDataShape targetShape(ChartType type) =>
registry.targetSeriesDataShape(type);
Returns the expected data shape for a chart type.
static registry.ChartSeriesDataShape targetShape(ChartType type) =>
registry.targetSeriesDataShape(type);