ChartHitResult class

Unified hit-test result emitted by chart painters.

Constructors

ChartHitResult({required int seriesIndex, required int dataIndex, required Offset localPosition, dynamic value})
const

Properties

dataIndex int
final
hashCode int
The hash code for this object.
no setterinherited
localPosition Offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesIndex int
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited