toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'ChartLegend('
      'type: $type, '
      'id: $id, '
      'show: $show, '
      'zlevel: $zlevel, '
      'z: $z, '
      'left: $left, '
      'top: $top, '
      'right: $right, '
      'bottom: $bottom, '
      'orient: $orient, '
      'align: $align, '
      'padding: $padding, '
      'itemGap: $itemGap, '
      'itemWidth: $itemWidth, '
      'itemHeight: $itemHeight, '
      'formatter: $formatter, '
      'selectedMode: $selectedMode, '
      'selected: $selected, '
      'icon: $icon, '
      'textStyle: $textStyle, '
      'backgroundColor: $backgroundColor, '
      'borderColor: $borderColor, '
      'borderWidth: $borderWidth, '
      'borderRadius: $borderRadius, '
      'shadowBlur: $shadowBlur, '
      'shadowColor: $shadowColor, '
      'shadowOffsetX: $shadowOffsetX, '
      'shadowOffsetY: $shadowOffsetY, '
      'scrollDataIndex: $scrollDataIndex, '
      'pageButtonPosition: $pageButtonPosition, '
      'pageIconsColor: $pageIconsColor, '
      'pageIconsInactiveColor: $pageIconsInactiveColor'
      ')';
}