PictureCacheResult class

Result of a PictureCache lookup/build operation.

Constructors

PictureCacheResult({required Picture picture, required bool cacheHit, required bool retained, required bool skippedWrite})
const

Properties

cacheHit bool
final
hashCode int
The hash code for this object.
no setterinherited
picture Picture
final
retained bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skippedWrite bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited