PictureCacheStats class

Memory and cache-efficiency snapshot for PictureCache.

Constructors

PictureCacheStats({required int size, required int currentMemoryBytes, required int maxMemoryBytes, required int hits, required int misses, required int evictions, int skippedWrites = 0})
const

Properties

currentMemoryBytes int
final
evictions int
final
hashCode int
The hash code for this object.
no setterinherited
hitRate double
no setter
hits int
final
maxMemoryBytes int
final
misses int
final
requests int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final
skippedWrites int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited