BaseRenderLayer class abstract

Base implementation with dirty flag tracking.

Implemented types

Constructors

BaseRenderLayer()

Properties

cacheable bool
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isDirty bool
no setteroverride
name String
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearDirty() → void
override
markDirty() → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSizeChanged(Size size) → void
override
paint(Canvas canvas, Size size) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited