ChartRenderPipeline class

Orchestrates layers in order.

Constructors

ChartRenderPipeline(List<RenderLayer> layers)

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
markAllDirty() → void
markDirty<T extends RenderLayer>() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(Canvas canvas, Size size) → void
setSize(Size size) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited