RenderLayer class abstract

Abstract base for composable chart render layers.

Implementers

Constructors

RenderLayer()

Properties

cacheable bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isDirty bool
no setter
name String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearDirty() → void
markDirty() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSizeChanged(Size size) → void
paint(Canvas canvas, Size size) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited