Series class

Implementers

Constructors

Series({required ChartType type, String? name, List? data, String? stack, int? xAxisIndex, int? yAxisIndex, Label? label, ChartTooltip? tooltip, ItemStyle? itemStyle, Emphasis? emphasis, List<String>? dataLabels, Color? color, double? width})
Series.fromJson(Object? raw)
factory

Properties

color Color?
final
data List?
final
dataLabels List<String>?
final
emphasis Emphasis?
final
hashCode int
The hash code for this object.
no setterinherited
itemStyle ItemStyle?
final
label Label?
final
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stack String?
final
tooltip ChartTooltip?
final
type ChartType
final
width double?
final
xAxisIndex int?
final
yAxisIndex int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited