ToolboxFeature class

Constructors

ToolboxFeature({required Feature saveAsImage, required Feature dataZoom, required Feature dataView, required Feature restore})

Properties

dataView Feature
final
dataZoom Feature
final
hashCode int
The hash code for this object.
no setterinherited
restore Feature
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveAsImage Feature
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited