ShadowStyle class
Constructors
- ShadowStyle({String? color, double? shadowBlur, double? shadowOffsetX, double? shadowOffsetY})
- ShadowStyle.fromJson(Object? raw)
-
factory
Properties
- color ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowBlur ↔ double?
-
getter/setter pair
- shadowOffsetX ↔ double?
-
getter/setter pair
- shadowOffsetY ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited