LabelConfig class

Constructors

LabelConfig({double rotate = 0, Alignment alignment = Alignment.center, LabelPosition position = LabelPosition.top, double distance = 15})

Properties

alignment Alignment
final
distance double
final
hashCode int
The hash code for this object.
no setterinherited
position LabelPosition
final
rotate double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({double? rotate, Alignment? alignment, LabelPosition? position, double? distance}) LabelConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited