DrillDownChartView class
A complete drill-down-capable chart view.
Combines:
- Current chart rendering (driven by ChartDrillDownController)
- Breadcrumb navigation bar
- Back button
DrillDownChartView(
controller: drillCtrl,
builder: (config) => TenunChart(config: config),
onLevelChanged: (level) => print('Now at: ${level.label}'),
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DrillDownChartView
- Available extensions
Constructors
- DrillDownChartView({Key? key, required ChartDrillDownController controller, required Widget builder(BaseChartConfig config), void onLevelChanged(DrillDownLevel level)?, bool showBreadcrumbs = true, bool showBackButton = true})
-
const
Properties
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - builder → Widget Function(BaseChartConfig config)
-
Builds the chart widget for the given config.
final
- controller → ChartDrillDownController
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onLevelChanged → void Function(DrillDownLevel level)?
-
Called when the active level changes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBackButton → bool
-
Whether to show the back button when drilled down.
final
- showBreadcrumbs → bool
-
Whether to show the breadcrumb row above the chart.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< DrillDownChartView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited