DrillDownState class
Immutable snapshot of the current drill-down position.
Constructors
-
DrillDownState({required List<
DrillDownLevel> stack})
Properties
-
All breadcrumb labels from root to current.
no setter
- current → DrillDownLevel
-
The currently active level.
no setter
- depth → int
-
Depth from root (0 = root).
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isAtRoot → bool
-
True when at the root (no drill-down has occurred).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stack
→ List<
DrillDownLevel> -
All levels from root to current (inclusive).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited