ChartZoomBridge class

Bridges ChartController zoom operations with a ChartZoomController.

After attaching, calls to chartCtrl.zoomTo(start, end) will update the ChartZoomController and vice versa.

Constructors

ChartZoomBridge({required ChartController chartController, required ChartZoomController zoomController, required int totalDataPoints})

Properties

chartController ChartController
final
hashCode int
The hash code for this object.
no setterinherited
isAttached bool
Whether this bridge currently has listeners attached to both controllers.
no setter
isDisposed bool
Whether this bridge has been disposed.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDataPoints int
final
zoomController ChartZoomController
final

Methods

dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited