isAttached property
bool
get
isAttached
Whether this bridge currently has listeners attached to both controllers.
Implementation
bool get isAttached => _attached;
Whether this bridge currently has listeners attached to both controllers.
bool get isAttached => _attached;