setVisibleRange method
Replace the current visible range without adding zoom history.
Use this for synchronization from another controller. Use zoomToRange when the change should become part of the user's zoom/back history.
Implementation
void setVisibleRange(double start, double end) {
if (_disposed) return;
value = value.withVisibleRange(start, end);
_applyConstraints();
}