value property
The current value stored in this notifier.
When the value is replaced with something that is not equal to the old value as evaluated by the equality operator ==, this class notifies its listeners.
Implementation
@override
T get value => _value;
Implementation
@override
set value(ChartZoomState newValue) {
if (_disposed) return;
super.value = _constrainedState(newValue, preserveVelocity: true);
}