panTo method
Pan so that frac is at the left edge of the viewport.
Implementation
ChartZoomState panTo(double frac) {
return _applyWindow(frac, frac + windowSize);
}
Pan so that frac is at the left edge of the viewport.
ChartZoomState panTo(double frac) {
return _applyWindow(frac, frac + windowSize);
}