withVisibleRange method

ChartZoomState withVisibleRange(
  1. double start,
  2. double end
)

Replace the visible data fraction range without pushing history.

This is intended for controller synchronization, where an external viewport source should not create a new drill-down/zoom breadcrumb level.

Implementation

ChartZoomState withVisibleRange(double start, double end) {
  return _applyWindow(start, end);
}