ChartSeriesDataShape enum
Data-shape groups used to pick compatible chart families.
Values
- cartesian → const ChartSeriesDataShape
- pieLike → const ChartSeriesDataShape
- hierarchical → const ChartSeriesDataShape
- matrix → const ChartSeriesDataShape
- graph → const ChartSeriesDataShape
- flow → const ChartSeriesDataShape
- financial → const ChartSeriesDataShape
- radial → const ChartSeriesDataShape
- calendar → const ChartSeriesDataShape
- geospatial → const ChartSeriesDataShape
- unknown → const ChartSeriesDataShape
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChartSeriesDataShape> - A constant List of the values in this enum, in order of their declaration.