ChartSwitchCompatibility class

Non-throwing compatibility result for a potential runtime chart switch.

Constructors

ChartSwitchCompatibility({required ChartType targetType, required ChartSeriesDataShape sourceShape, required ChartSeriesDataShape targetShape, required bool isCompatible, required bool forceConversionAvailable, required bool targetRegistered, required List<ChartType> compatibleTypes, required ChartCapabilities targetCapabilities, required String reason})
const

Properties

canSwitch bool
no setter
compatibleTypes List<ChartType>
final
forceConversionAvailable bool
final
hashCode int
The hash code for this object.
no setterinherited
isCompatible bool
final
reason String
final
requiresForce bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceShape ChartSeriesDataShape
final
targetCapabilities ChartCapabilities
final
targetRegistered bool
final
targetShape ChartSeriesDataShape
final
targetType ChartType
final
targetTypeString String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited