ChartSwitchOption class

Ranked runtime switch candidate for a JSON chart payload.

Constructors

ChartSwitchOption({required ChartType type, required int rank, required bool isCurrentType, required ChartSeriesDataShape sourceShape, required ChartCapabilities capabilities, required Map<String, dynamic> previewPayload, required String reason})
const

Properties

capabilities ChartCapabilities
final
hashCode int
The hash code for this object.
no setterinherited
isCurrentType bool
final
previewPayload Map<String, dynamic>
final
rank int
final
reason String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceShape ChartSeriesDataShape
final
type ChartType
final
typeString String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool includePreviewPayload = false}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited