RegistrationAuditIssue class

Issue found while auditing a RegistrationBundle.

Constructors

RegistrationAuditIssue({required RegistrationAuditSeverity severity, required String code, required String message, String? key, ChartType? firstType, ChartType? secondType})
const

Properties

code String
final
firstType ChartType?
final
hashCode int
The hash code for this object.
no setterinherited
isError bool
no setter
isWarning bool
no setter
key String?
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondType ChartType?
final
severity RegistrationAuditSeverity
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited