getBundleForSeriesShape function
Returns a bundle with charts compatible to the provided data shape.
Implementation
RegistrationBundle? getBundleForSeriesShape(ChartSeriesDataShape shape) =>
seriesShapeBundles[shape];
Returns a bundle with charts compatible to the provided data shape.
RegistrationBundle? getBundleForSeriesShape(ChartSeriesDataShape shape) =>
seriesShapeBundles[shape];