TenunValidationReportFallback class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TenunValidationReportFallback
- Available extensions
Constructors
-
TenunValidationReportFallback({Key? key, required ValidationResult result, Map<
String, dynamic> ? rawPayload, bool requireRegisteredType = false, required int validationReportMaxIssues, String title = 'Invalid chart payload', String? message, bool showDoctorSummary = true, bool showValidationDetails = true, bool showQuickFixes = true, int maxQuickFixes = 3, TenunDiagnosticFallbackOptions? options}) -
const
Properties
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maxQuickFixes → int
-
final
- message → String?
-
final
- options → TenunDiagnosticFallbackOptions?
-
final
-
rawPayload
→ Map<
String, dynamic> ? -
final
- requireRegisteredType → bool
-
final
- result → ValidationResult
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showDoctorSummary → bool
-
final
- showQuickFixes → bool
-
final
- showValidationDetails → bool
-
final
- title → String
-
final
- validationReportMaxIssues → int
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited