TenunDiagnosticFallbackOptions class

Constructors

TenunDiagnosticFallbackOptions({String? title, String? message, String? detailMessage, List<Widget> footerChildren = const [], bool showDoctorSummary = true, bool showValidationDetails = true, bool showErrorDetails = true, bool showQuickFixes = true, int maxQuickFixes = 3})
const
TenunDiagnosticFallbackOptions.fromJson(Object? raw, {TenunDiagnosticFallbackOptions fallback = defaults})
factory

Properties

detailMessage String?
final
footerChildren List<Widget>
final
hashCode int
The hash code for this object.
no setteroverride
maxQuickFixes int
final
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showDoctorSummary bool
final
showErrorDetails bool
final
showQuickFixes bool
final
showValidationDetails bool
final
title String?
final

Methods

copyWith({String? title, bool clearTitle = false, String? message, bool clearMessage = false, String? detailMessage, bool clearDetailMessage = false, List<Widget>? footerChildren, bool? showDoctorSummary, bool? showValidationDetails, bool? showErrorDetails, bool? showQuickFixes, int? maxQuickFixes}) TenunDiagnosticFallbackOptions
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

resolve(Object? raw, {TenunDiagnosticFallbackOptions fallback = defaults}) TenunDiagnosticFallbackOptions
Resolve fallback options from either a direct options payload or a full chart JSON payload.