ChartExportControls class

Material export toolbar for config-driven charts.

Data exports (csv, xlsx) require config. Image exports (png, jpeg) require either boundaryKey or controller.

Inheritance
Available extensions

Constructors

ChartExportControls({Key? key, BaseChartConfig? config, Map<String, dynamic>? jsonConfig, List<List<Object?>>? rows, GlobalKey<State<StatefulWidget>>? boundaryKey, ExportableChartController? controller, List<ChartExportFormat> formats = defaultFormats, List<String>? categoryLabels, String filename = 'chart_export', String sheetName = 'Chart Data', String delimiter = ',', String lineEnding = '\r\n', double pixelRatio = 2, int jpegQuality = 90, Color jpegBackgroundColor = Colors.white, Duration? exportTimeout, Duration? deliveryTimeout, ChartExportCancellationToken? cancellationToken, ChartExportJobPreflightPolicy preflightPolicy = ChartExportJobPreflightPolicy.failOnBlockers, bool copyTextExportsToClipboard = true, bool showStatus = true, bool showPreflightDiagnostics = true, bool showUnavailableFormatTooltips = true, bool showBatchExportButton = true, bool showArchiveExportButton = false, bool showCancelButton = false, bool stopBatchOnFirstFailure = false, bool stopDeliveryBatchOnFirstFailure = false, String batchExportLabel = 'All', String archiveExportLabel = 'ZIP', String cancelExportLabel = 'Cancel', String cancelExportReason = 'Export cancelled by user.', String? archiveFilename, bool includeArchiveManifest = true, String archiveManifestFilename = ChartExportArchive.defaultManifestFilename, Axis direction = Axis.horizontal, double spacing = 8, double runSpacing = 8, ButtonStyle? buttonStyle, ChartExportDeliveryAdapter? deliveryAdapter, ChartExportStartedHandler? onStarted, ChartExportResultHandler? onResult, ChartExportJobPlanHandler? onExportJobPlan, ChartExportJobProgressHandler? onExportJobProgress, ChartExportJobResultHandler? onExportJobResult, ChartExportBatchStartedHandler? onBatchStarted, ChartExportBatchProgressHandler? onBatchProgress, ChartExportBatchResultHandler? onBatchResult, ChartExportJobPlanHandler? onBatchJobPlan, ChartExportJobProgressHandler? onBatchJobProgress, ChartExportJobResultHandler? onBatchJobResult, ChartExportArchiveStartedHandler? onArchiveStarted, ChartExportJobPlanHandler? onArchiveJobPlan, ChartExportJobProgressHandler? onArchiveJobProgress, ChartExportJobResultHandler? onArchiveJobResult, ChartExportArchiveResultHandler? onArchiveResult, ChartExportDeliveryResultHandler? onDeliveryResult, ChartExportDeliveryResultHandler? onArchiveDeliveryResult, ChartExportDeliveryBatchProgressHandler? onDeliveryBatchProgress, ChartExportDeliveryBatchResultHandler? onDeliveryBatchResult, ChartExportControlsErrorHandler? onError})
const

Properties

apiContract ChartApiContract?

Available on Widget, provided by the ChartWidgetApiContractExtension extension

no setter
archiveExportLabel String
final
archiveFilename String?
final
archiveManifestFilename String
final
batchExportLabel String
final
boundaryKey GlobalKey<State<StatefulWidget>>?
final
buttonStyle ButtonStyle?
final
cancelExportLabel String
final
cancelExportReason String
final
cancellationToken ChartExportCancellationToken?
final
categoryLabels List<String>?
final
config BaseChartConfig?
final
controller ExportableChartController?
final
copyTextExportsToClipboard bool
final
delimiter String
final
deliveryAdapter ChartExportDeliveryAdapter?
final
deliveryTimeout Duration?
final
direction Axis
final
exportTimeout Duration?
final
filename String
final
formats List<ChartExportFormat>
final
hashCode int
The hash code for this object.
no setterinherited
includeArchiveManifest bool
final
jpegBackgroundColor Color
final
jpegQuality int
final
jsonConfig Map<String, dynamic>?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineEnding String
final
onArchiveDeliveryResult ChartExportDeliveryResultHandler?
final
onArchiveJobPlan ChartExportJobPlanHandler?
final
onArchiveJobProgress ChartExportJobProgressHandler?
final
onArchiveJobResult ChartExportJobResultHandler?
final
onArchiveResult ChartExportArchiveResultHandler?
final
onArchiveStarted ChartExportArchiveStartedHandler?
final
onBatchJobPlan ChartExportJobPlanHandler?
final
onBatchJobProgress ChartExportJobProgressHandler?
final
onBatchJobResult ChartExportJobResultHandler?
final
onBatchProgress ChartExportBatchProgressHandler?
final
onBatchResult ChartExportBatchResultHandler?
final
onBatchStarted ChartExportBatchStartedHandler?
final
onDeliveryBatchProgress ChartExportDeliveryBatchProgressHandler?
final
onDeliveryBatchResult ChartExportDeliveryBatchResultHandler?
final
onDeliveryResult ChartExportDeliveryResultHandler?
final
onError ChartExportControlsErrorHandler?
final
onExportJobPlan ChartExportJobPlanHandler?
final
onExportJobProgress ChartExportJobProgressHandler?
final
onExportJobResult ChartExportJobResultHandler?
final
onResult ChartExportResultHandler?
final
onStarted ChartExportStartedHandler?
final
pixelRatio double
final
preflightPolicy ChartExportJobPreflightPolicy
final
rows List<List<Object?>>?
final
runSpacing double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheetName String
final
showArchiveExportButton bool
final
showBatchExportButton bool
final
showCancelButton bool
final
showPreflightDiagnostics bool
final
showStatus bool
final
showUnavailableFormatTooltips bool
final
spacing double
final
stopBatchOnFirstFailure bool
final
stopDeliveryBatchOnFirstFailure bool
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<ChartExportControls>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recommendsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

supportsApiField(String field) bool

Available on Widget, provided by the ChartWidgetApiContractExtension extension

toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaultFormats → const List<ChartExportFormat>