ExportableTenunChart class
Turnkey chart + export controls wrapper.
Accepts either a resolved config or a JSON jsonConfig. The chart is wrapped in ExportableChart, and the same resolved config is passed to ChartExportControls so data exports work for JSON-driven charts too.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ExportableTenunChart
- Available extensions
Constructors
-
ExportableTenunChart({Key? key, BaseChartConfig? config, Map<
String, dynamic> ? jsonConfig, ExportableChartController? exportController, List<ChartExportFormat> formats = ChartExportControls.defaultFormats, List<String> ? categoryLabels, String filename = 'chart_export', String sheetName = 'Chart Data', String delimiter = ',', String lineEnding = '\r\n', double pixelRatio = 2, int jpegQuality = 90, Color jpegBackgroundColor = Colors.white, Duration? exportTimeout, Duration? deliveryTimeout, ChartExportCancellationToken? exportCancellationToken, ChartExportJobPreflightPolicy exportPreflightPolicy = ChartExportJobPreflightPolicy.failOnBlockers, bool copyTextExportsToClipboard = true, bool showExportControls = true, bool showExportStatus = true, bool showExportPreflightDiagnostics = true, bool showBatchExportButton = true, bool showArchiveExportButton = false, bool showCancelExportButton = false, bool stopBatchOnFirstFailure = false, bool stopDeliveryBatchOnFirstFailure = false, String batchExportLabel = 'All', String archiveExportLabel = 'ZIP', String cancelExportLabel = 'Cancel', String cancelExportReason = 'Export cancelled by user.', String? archiveFilename, bool includeArchiveManifest = true, String archiveManifestFilename = ChartExportArchive.defaultManifestFilename, Axis controlsDirection = Axis.horizontal, ChartExportStartedHandler? onExportStarted, ChartExportResultHandler? onExportResult, ChartExportJobPlanHandler? onExportJobPlan, ChartExportJobProgressHandler? onExportJobProgress, ChartExportJobResultHandler? onExportJobResult, ChartExportBatchStartedHandler? onBatchExportStarted, ChartExportBatchProgressHandler? onBatchExportProgress, ChartExportBatchResultHandler? onBatchExportResult, ChartExportJobPlanHandler? onBatchExportJobPlan, ChartExportJobProgressHandler? onBatchExportJobProgress, ChartExportJobResultHandler? onBatchExportJobResult, ChartExportArchiveStartedHandler? onArchiveExportStarted, ChartExportJobPlanHandler? onArchiveExportJobPlan, ChartExportJobProgressHandler? onArchiveExportJobProgress, ChartExportJobResultHandler? onArchiveExportJobResult, ChartExportArchiveResultHandler? onArchiveExportResult, Widget? controlsLeading, Widget? controlsTrailing, MainAxisAlignment controlsMainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.stretch, double controlsSpacing = 8, ButtonStyle? exportButtonStyle, ChartExportDeliveryAdapter? exportDeliveryAdapter, ChartExportDeliveryResultHandler? onExportDeliveryResult, ChartExportDeliveryResultHandler? onArchiveExportDeliveryResult, ChartExportDeliveryBatchProgressHandler? onExportDeliveryBatchProgress, ChartExportDeliveryBatchResultHandler? onExportDeliveryBatchResult, ChartExportControlsErrorHandler? onExportError, double? width, double? height, EdgeInsetsGeometry? chartPadding, EdgeInsetsGeometry? padding, bool validatePayload = false, bool strictValidation = false, int validationReportMaxIssues = 3, TenunDiagnosticFallbackOptions diagnosticFallbackOptions = const TenunDiagnosticFallbackOptions(), void onValidationResult(ValidationResult result)?, void onPayloadNormalizationResult(PayloadNormalizationResult result)?, void onRuntimeDiagnostics(ChartRuntimeDiagnostics diagnostics)?, ChartRuntimePerformancePolicy runtimePerformancePolicy = ChartRuntimePerformancePolicy.defaults, bool catchRenderErrors = false, bool autoNormalizePayload = false, bool sanitizeTradingPayload = true, bool dropUnsupportedSampling = true, int? normalizeDefaultThreshold, ChartDataMode normalizeDefaultMode = ChartDataMode.auto, PayloadNormalizationOptions? normalizationOptions, Widget errorBuilder(BuildContext context, Object error)?}) -
const
Properties
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - archiveExportLabel → String
-
final
- archiveFilename → String?
-
final
- archiveManifestFilename → String
-
final
- autoNormalizePayload → bool
-
final
- batchExportLabel → String
-
final
- cancelExportLabel → String
-
final
- cancelExportReason → String
-
final
- catchRenderErrors → bool
-
final
-
categoryLabels
→ List<
String> ? -
final
- chartPadding → EdgeInsetsGeometry?
-
final
- config → BaseChartConfig?
-
final
- controlsDirection → Axis
-
final
- controlsLeading → Widget?
-
final
- controlsMainAxisAlignment → MainAxisAlignment
-
final
- controlsSpacing → double
-
final
- controlsTrailing → Widget?
-
final
- copyTextExportsToClipboard → bool
-
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- delimiter → String
-
final
- deliveryTimeout → Duration?
-
final
- diagnosticFallbackOptions → TenunDiagnosticFallbackOptions
-
final
- dropUnsupportedSampling → bool
-
final
- errorBuilder → Widget Function(BuildContext context, Object error)?
-
final
- exportButtonStyle → ButtonStyle?
-
final
- exportCancellationToken → ChartExportCancellationToken?
-
final
- exportController → ExportableChartController?
-
final
- exportDeliveryAdapter → ChartExportDeliveryAdapter?
-
final
- exportPreflightPolicy → ChartExportJobPreflightPolicy
-
final
- exportTimeout → Duration?
-
final
- filename → String
-
final
-
formats
→ List<
ChartExportFormat> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- includeArchiveManifest → bool
-
final
- jpegBackgroundColor → Color
-
final
- jpegQuality → int
-
final
-
jsonConfig
→ Map<
String, dynamic> ? -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lineEnding → String
-
final
- normalizationOptions → PayloadNormalizationOptions?
-
final
- normalizeDefaultMode → ChartDataMode
-
final
- normalizeDefaultThreshold → int?
-
final
- onArchiveExportDeliveryResult → ChartExportDeliveryResultHandler?
-
final
- onArchiveExportJobPlan → ChartExportJobPlanHandler?
-
final
- onArchiveExportJobProgress → ChartExportJobProgressHandler?
-
final
- onArchiveExportJobResult → ChartExportJobResultHandler?
-
final
- onArchiveExportResult → ChartExportArchiveResultHandler?
-
final
- onArchiveExportStarted → ChartExportArchiveStartedHandler?
-
final
- onBatchExportJobPlan → ChartExportJobPlanHandler?
-
final
- onBatchExportJobProgress → ChartExportJobProgressHandler?
-
final
- onBatchExportJobResult → ChartExportJobResultHandler?
-
final
- onBatchExportProgress → ChartExportBatchProgressHandler?
-
final
- onBatchExportResult → ChartExportBatchResultHandler?
-
final
- onBatchExportStarted → ChartExportBatchStartedHandler?
-
final
- onExportDeliveryBatchProgress → ChartExportDeliveryBatchProgressHandler?
-
final
- onExportDeliveryBatchResult → ChartExportDeliveryBatchResultHandler?
-
final
- onExportDeliveryResult → ChartExportDeliveryResultHandler?
-
final
- onExportError → ChartExportControlsErrorHandler?
-
final
- onExportJobPlan → ChartExportJobPlanHandler?
-
final
- onExportJobProgress → ChartExportJobProgressHandler?
-
final
- onExportJobResult → ChartExportJobResultHandler?
-
final
- onExportResult → ChartExportResultHandler?
-
final
- onExportStarted → ChartExportStartedHandler?
-
final
- onPayloadNormalizationResult → void Function(PayloadNormalizationResult result)?
-
final
- onRuntimeDiagnostics → void Function(ChartRuntimeDiagnostics diagnostics)?
-
final
- onValidationResult → void Function(ValidationResult result)?
-
final
- padding → EdgeInsetsGeometry?
-
final
- pixelRatio → double
-
final
- runtimePerformancePolicy → ChartRuntimePerformancePolicy
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sanitizeTradingPayload → bool
-
final
- sheetName → String
-
final
- showArchiveExportButton → bool
-
final
- showBatchExportButton → bool
-
final
- showCancelExportButton → bool
-
final
- showExportControls → bool
-
final
- showExportPreflightDiagnostics → bool
-
final
- showExportStatus → bool
-
final
-
final
- stopBatchOnFirstFailure → bool
-
final
- stopDeliveryBatchOnFirstFailure → bool
-
final
- strictValidation → bool
-
final
- validatePayload → bool
-
final
- validationReportMaxIssues → int
-
final
- width → double?
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ExportableTenunChart> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited