buildWhenInvalid property
If true, config resolution is attempted even when validation has errors. Useful for diagnostics; keep false for normal rendering.
Implementation
final bool buildWhenInvalid;
If true, config resolution is attempted even when validation has errors. Useful for diagnostics; keep false for normal rendering.
final bool buildWhenInvalid;