forceCrossShapeSwitch property
If true, forced type switches may use supported cross-shape conversion.
Implementation
final bool forceCrossShapeSwitch;
If true, forced type switches may use supported cross-shape conversion.
final bool forceCrossShapeSwitch;