safeBuild property
If true, build JSON through TenunOption.tryBuild and render a fallback instead of throwing when validation or config resolution fails.
Implementation
final bool safeBuild;
If true, build JSON through TenunOption.tryBuild and render a fallback instead of throwing when validation or config resolution fails.
final bool safeBuild;