SimpleBoxenPlotSummary class
Constructors
-
SimpleBoxenPlotSummary({required double min, required double median, required double max, required double mean, required int sampleCount, required List<
SimpleBoxenPlotInterval> intervals}) -
const
Properties
- centralInterval → SimpleBoxenPlotInterval?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
intervals
→ List<
SimpleBoxenPlotInterval> -
final
- max → double
-
final
- mean → double
-
final
- median → double
-
final
- min → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited