SimpleCandlestickData class
- Annotations
-
- @Deprecated('Financial chart widgets moved to package:tenun_pro/tenun_pro_financial.dart. ' 'Use SimpleCandlestickData from tenun_pro instead.')
Constructors
Properties
- change → double
-
no setter
- changePercent → double
-
no setter
- close → double
-
final
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- high → double
-
final
- isBullish → bool
-
no setter
- label → String
-
final
- low → double
-
final
- open → double
-
final
- rangeHigh → double
-
no setter
- rangeLow → double
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- volume → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited