charts/forest_plot/simple_forest_plot_chart library
Classes
- SimpleForestPlotChart
- A compact forest plot for treatment effects, experiment lift, risk ratios, research summaries, policy comparisons, and confidence intervals.
- SimpleForestPlotData
Typedefs
- SimpleForestPlotTapCallback = void Function(SimpleForestPlotData data, int index)
- SimpleForestPlotTooltipBuilder = Widget Function(BuildContext context, SimpleForestPlotData data, int index, String formattedEstimate, String formattedLower, String formattedUpper, String? formattedWeight)
- SimpleForestPlotValueFormatter = String Function(double value)