SimpleFunnelChart class
A lightweight funnel chart for conversion, stage drop-off, pipeline, and step-by-step flow summaries.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleFunnelChart
- Available extensions
Constructors
-
SimpleFunnelChart({Key? key, required List<
SimpleFunnelChartData> data, SimpleFunnelMode mode = SimpleFunnelMode.funnel, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 260, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? stageColor, Color? trackColor, Color? borderColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showLabels = true, bool showValues = true, bool showPercentages = true, bool showConversionRates = false, bool showTrack = false, bool showTooltip = true, bool showActiveStage = true, double neckWidthFactor = 0.22, double stageGap = 6, double stageRadius = 6, bool? useGradient, SimpleFunnelValueFormatter? valueFormatter, SimpleFunnelValueFormatter? percentFormatter, SimpleFunnelTapCallback? onStageTap, SimpleFunnelTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - borderColor → Color?
-
final
-
data
→ List<
SimpleFunnelChartData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- mode → SimpleFunnelMode
-
final
- neckWidthFactor → double
-
final
- onStageTap → SimpleFunnelTapCallback?
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- percentFormatter → SimpleFunnelValueFormatter?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveStage → bool
-
final
- showConversionRates → bool
-
final
- showLabels → bool
-
final
- showPercentages → bool
-
final
- showTooltip → bool
-
final
- showTrack → bool
-
final
- showValues → bool
-
final
- stageColor → Color?
-
final
- stageGap → double
-
final
- stageRadius → double
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleFunnelTooltipBuilder?
-
final
- trackColor → Color?
-
final
- useGradient → bool?
-
final
- valueFormatter → SimpleFunnelValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited