LineStyleSpec class
Line chart where each series has configurable dash pattern, line width, dot shape (circle/square/diamond), dot size, and opacity.
Constructors
-
LineStyleSpec({String type = 'solid', double width = 2.0, List<
double> dash = const [8, 4]}) -
const
-
LineStyleSpec.fromJson(Map<
String, dynamic> j) -
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited