SimpleMilestoneChart class
A compact milestone roadmap for launches, curriculum checkpoints, audits, funding stages, release gates, and operations plans.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleMilestoneChart
- Available extensions
Constructors
-
SimpleMilestoneChart({Key? key, required List<
SimpleMilestoneData> milestones, SimpleMilestoneOrientation orientation = SimpleMilestoneOrientation.horizontal, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, DateTime? minDate, DateTime? maxDate, double height = 260, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? markerColor, Color? doneColor, Color? activeColor, Color? blockedColor, Color? connectorColor, Color? trackColor, Color? milestoneBackgroundColor, TextStyle? dateStyle, TextStyle? labelStyle, TextStyle? descriptionStyle, bool sortByDate = true, bool alternating = true, bool showDates = true, bool showDescriptions = true, bool showTags = true, bool showConnector = true, bool showStatusMarks = true, bool showTooltip = true, bool showActiveMilestone = true, double markerRadius = 8, double connectorWidth = 3, double milestoneSpacing = 14, SimpleMilestoneDateFormatter? dateFormatter, SimpleMilestoneTapCallback? onMilestoneTap, SimpleMilestoneTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- alternating → bool
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - blockedColor → Color?
-
final
- connectorColor → Color?
-
final
- connectorWidth → double
-
final
- dateFormatter → SimpleMilestoneDateFormatter?
-
final
- dateStyle → TextStyle?
-
final
- descriptionStyle → TextStyle?
-
final
- doneColor → Color?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- markerColor → Color?
-
final
- markerRadius → double
-
final
- maxDate → DateTime?
-
final
- milestoneBackgroundColor → Color?
-
final
-
milestones
→ List<
SimpleMilestoneData> -
final
- milestoneSpacing → double
-
final
- minDate → DateTime?
-
final
- onMilestoneTap → SimpleMilestoneTapCallback?
-
final
- orientation → SimpleMilestoneOrientation
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveMilestone → bool
-
final
- showConnector → bool
-
final
- showDates → bool
-
final
- showDescriptions → bool
-
final
- showStatusMarks → bool
-
final
- showTags → bool
-
final
- showTooltip → bool
-
final
- sortByDate → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleMilestoneTooltipBuilder?
-
final
- trackColor → Color?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited