SimpleNetworkGraphChart class
A simple node-link network graph for dependencies, relationships, stakeholder maps, ecosystems, systems, and knowledge graphs.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleNetworkGraphChart
- Available extensions
Constructors
-
SimpleNetworkGraphChart({Key? key, required List<
SimpleNetworkNode> nodes, required List<SimpleNetworkLink> links, SimpleNetworkGraphLayout layout = SimpleNetworkGraphLayout.radial, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 280, EdgeInsets padding = _defaultPadding, Color? nodeColor, Color? linkColor, Color? activeColor, Color? labelColor, TextStyle? labelStyle, TextStyle? valueStyle, bool directed = false, bool showLabels = true, bool showValues = false, bool showLinkLabels = false, bool showLegend = true, bool showGroupHulls = true, bool showTooltip = true, bool showActiveItem = true, double minNodeRadius = 8, double maxNodeRadius = 22, double minLinkWidth = 1.2, double maxLinkWidth = 5, double linkOpacity = 0.38, SimpleNetworkValueFormatter? valueFormatter, SimpleNetworkNodeTapCallback? onNodeTap, SimpleNetworkLinkTapCallback? onLinkTap, SimpleNetworkTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - directed → bool
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelColor → Color?
-
final
- labelStyle → TextStyle?
-
final
- layout → SimpleNetworkGraphLayout
-
final
- linkColor → Color?
-
final
- linkOpacity → double
-
final
-
links
→ List<
SimpleNetworkLink> -
final
- maxLinkWidth → double
-
final
- maxNodeRadius → double
-
final
- minLinkWidth → double
-
final
- minNodeRadius → double
-
final
- nodeColor → Color?
-
final
-
nodes
→ List<
SimpleNetworkNode> -
final
- onLinkTap → SimpleNetworkLinkTapCallback?
-
final
- onNodeTap → SimpleNetworkNodeTapCallback?
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveItem → bool
-
final
- showGroupHulls → bool
-
final
- showLabels → bool
-
final
- showLegend → bool
-
final
- showLinkLabels → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleNetworkTooltipBuilder?
-
final
- valueFormatter → SimpleNetworkValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited