PieChartConfig class
Constructors
-
PieChartConfig({required List<Series> series, ChartType? chartType, double centerSpaceRadius = 40.0, double sectionsSpace = 2.0, bool enableSections = true, double startDegreeOffset = 0, bool donut = false, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
-
-
PieChartConfig.fromJson(Map<String, dynamic> json)
-
factory
Methods
-
buildChart()
→ Widget
-
Method to create the appropriate chart widget
override
-
copyWith({List<Series>? series, ChartType? chartType, double? centerSpaceRadius, double? sectionsSpace, bool? enableSections, double? startDegreeOffset, bool? donut, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, ChartTheme? theme, ChartController? controller, ChartAxisConfig? xAxisConfig, ChartAxisConfig? yAxisConfig})
→ PieChartConfig
-
-
getMaxSeriesValue()
→ double
-
Safe maximum value with 10% headroom.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
supportsApiField(String field)
→ bool
-
inherited
-
toJson()
→ Map<String, dynamic>
-
Convert configuration to JSON
override
-
toString()
→ String
-
A string representation of this object.
inherited
-
withController(ChartController controller)
→ PieChartConfig
-
Override in concrete configs to return a controller-attached copy.
override
-
withTheme(ChartTheme theme)
→ PieChartConfig
-
Override in concrete configs to return a themed copy.
override