SimpleRangeChartData class
Constructors
Properties
- color → Color?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- high → double
-
no setter
- label → String
-
final
- low → double
-
no setter
- markerColor → Color?
-
final
- max → double
-
final
- min → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- span → double
-
no setter
- value → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited