SimpleStripPlotChart class
A simple strip plot for showing every observation in a group while keeping mean, median, references, and dense categorical comparison readable.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleStripPlotChart
- Available extensions
Constructors
-
SimpleStripPlotChart({Key? key, required List<
SimpleStripPlotData> data, SimpleBarChartOrientation orientation = SimpleBarChartOrientation.vertical, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double? minValue, double? maxValue, double height = 260, EdgeInsets? padding, List<Color> ? palette, Color? dotColor, Color? meanColor, Color? medianColor, Color? gridColor, Color? axisColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool includeZero = false, bool showGrid = true, bool showLabels = true, bool showValues = false, bool showMean = true, bool showMedian = true, bool showTooltip = true, bool showActiveDot = true, List<SimpleChartReferenceLine> referenceLines = const [], List<SimpleChartReferenceBand> referenceBands = const [], int gridLineCount = 4, double? dotRadius, double dotOpacity = 0.78, double jitter = 0.42, int jitterSeed = 17, SimpleStripPlotValueFormatter? valueFormatter, SimpleStripPlotTapCallback? onPointTap, SimpleStripPlotTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 700), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - axisColor → Color?
-
final
-
data
→ List<
SimpleStripPlotData> -
final
- dotColor → Color?
-
final
- dotOpacity → double
-
final
- dotRadius → double?
-
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- gridColor → Color?
-
final
- gridLineCount → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- includeZero → bool
-
final
- jitter → double
-
final
- jitterSeed → int
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- maxValue → double?
-
final
- meanColor → Color?
-
final
- medianColor → Color?
-
final
- minValue → double?
-
final
- onPointTap → SimpleStripPlotTapCallback?
-
final
- orientation → SimpleBarChartOrientation
-
final
- padding → EdgeInsets?
-
final
-
palette
→ List<
Color> ? -
final
-
referenceBands
→ List<
SimpleChartReferenceBand> -
final
-
referenceLines
→ List<
SimpleChartReferenceLine> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveDot → bool
-
final
- showGrid → bool
-
final
- showLabels → bool
-
final
- showMean → bool
-
final
- showMedian → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleStripPlotTooltipBuilder?
-
final
- valueFormatter → SimpleStripPlotValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited