SimpleTreeDiagramChart class
A simple node-link hierarchy chart for org charts, taxonomies, decision trees, curriculum maps, product architecture, and nested breakdowns.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- SimpleTreeDiagramChart
- Available extensions
Constructors
-
SimpleTreeDiagramChart({Key? key, required List<
SimpleTreeDiagramData> data, SimpleTreeDiagramOrientation orientation = SimpleTreeDiagramOrientation.vertical, SimpleBarChartStyle style = SimpleBarChartStyle.elegant, double height = 280, EdgeInsets padding = _defaultPadding, List<Color> ? palette, Color? nodeColor, Color? linkColor, Color? activeColor, TextStyle? labelStyle, TextStyle? valueStyle, bool showLabels = true, bool showValues = false, bool showRoot = true, bool showTooltip = true, bool showActiveNode = true, bool curvedLinks = true, int maxDepth = 4, double minNodeRadius = 8, double maxNodeRadius = 18, double linkWidth = 1.6, double siblingGap = 18, SimpleTreeValueFormatter? valueFormatter, SimpleTreeNodeTapCallback? onNodeTap, SimpleTreeTooltipBuilder? tooltipBuilder, WidgetBuilder? emptyBuilder, String? semanticLabel, bool excludeFromSemantics = false, Duration animationDuration = const Duration(milliseconds: 720), Curve animationCurve = Curves.easeOutCubic}) -
const
Properties
- activeColor → Color?
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - curvedLinks → bool
-
final
-
data
→ List<
SimpleTreeDiagramData> -
final
- emptyBuilder → WidgetBuilder?
-
final
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelStyle → TextStyle?
-
final
- linkColor → Color?
-
final
- linkWidth → double
-
final
- maxDepth → int
-
final
- maxNodeRadius → double
-
final
- minNodeRadius → double
-
final
- nodeColor → Color?
-
final
- onNodeTap → SimpleTreeNodeTapCallback?
-
final
- orientation → SimpleTreeDiagramOrientation
-
final
- padding → EdgeInsets
-
final
-
palette
→ List<
Color> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- showActiveNode → bool
-
final
- showLabels → bool
-
final
- showRoot → bool
-
final
- showTooltip → bool
-
final
- showValues → bool
-
final
- siblingGap → double
-
final
- style → SimpleBarChartStyle
-
final
- tooltipBuilder → SimpleTreeTooltipBuilder?
-
final
- valueFormatter → SimpleTreeValueFormatter?
-
final
- valueStyle → TextStyle?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited