LargeDataSamplingConfig class
Global large-data sampling policy used by BaseChartConfig.
You can tune this at app startup:
LargeDataSamplingConfig.enabled = true;
LargeDataSamplingConfig.threshold = 1500;
LargeDataSamplingConfig.strategy = null; // auto
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- enabled ↔ bool
-
getter/setter pair
- mode ↔ ChartDataMode
-
getter/setter pair
- strategy ↔ SamplingStrategy?
-
getter/setter pair
- threshold ↔ int
-
getter/setter pair
Static Methods
-
normalizeThreshold(
int threshold) → int - Minimum-safe sampling threshold shared by config parsing and rendering.
Constants
- minimumThreshold → const int