ChartAnimationPreset class
Named animation configuration for a chart.
Constructors
- ChartAnimationPreset({required Duration duration, required Curve curve, required ChartAnimationType type})
-
const
-
ChartAnimationPreset.fromJson(Map<
String, dynamic> ? json) -
factory
Properties
- curve → Curve
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ChartAnimationType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- draw → const ChartAnimationPreset
- Line/area draws from left to right.
- fade → const ChartAnimationPreset
- Elements fade in from transparent (good for scatter / heatmap).
- grow → const ChartAnimationPreset
- Bars grow upward from the baseline (default for bar charts).
- morph → const ChartAnimationPreset
- Data values morph from old to new when the series is updated.
- none → const ChartAnimationPreset
- No animation.
- sweep → const ChartAnimationPreset
- Pie/donut sweeps the arc from 0°.