SweepAnimator class

Constrains an arc sweep to progress * fullSweep.

Constructors

SweepAnimator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

sweepAngle(double progress, double fullSweepRadians) double
Returns the sweep angle for progress of fullSweepRadians.