ChartApiContract class
Constructors
-
ChartApiContract({required String name, required ChartApiFamily family, required String description, required List<
String> supportedFields, List<String> recommendedFields = const <String>[]}) -
const
Properties
- description → String
-
final
- family → ChartApiFamily
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
recommendedFields
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportedFields
→ List<
String> -
final
-
supportedSpecs
→ List<
ChartApiFieldSpec> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommends(
String field) → bool -
supports(
String field) → bool -
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited