ChartApiFields class
Canonical chart API field names shared by JSON configs, builders, and direct chart widgets.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- suggestion → String
-
no setter
Static Methods
-
aliasesFor(
String canonicalField) → List< String> -
canonicalFieldFor(
String field) → String? -
containsAny(
Map< Object?, Object?> map) → bool -
firstField(
Map< Object?, Object?> map, Iterable<String> aliases) → String? -
normalizeFieldName(
String field) → String -
path(
String prefix, String field) → String -
readValue(
Map< Object?, Object?> map, Iterable<String> aliases) → Object? -
schemaJson(
) → List< Map< String, dynamic> > -
specFor(
String field) → ChartApiFieldSpec?
Constants
-
allAliases
→ const Set<
String> - animationCurve → const String
- animationDuration → const String
- axisLabelFormatter → const String
-
canonicalFields
→ const List<
String> - controller → const String
- dataMode → const String
- diagnostics → const String
- emptyBuilder → const String
- excludeFromSemantics → const String
-
fieldSpecs
→ const List<
ChartApiFieldSpec> - grid → const String
- height → const String
- labelFormatter → const String
- legend → const String
- maxValue → const String
- minValue → const String
- onElementHover → const String
- onElementTap → const String
- onSelectionChanged → const String
- padding → const String
- palette → const String
- performancePolicy → const String
- radius → const String
- sampling → const String
- semanticLabel → const String
- series → const String
- showActiveElement → const String
- showAxisLabels → const String
- showGrid → const String
- showLabels → const String
- showLegend → const String
- showTooltip → const String
- showValues → const String
- spacing → const String
- theme → const String
- title → const String
- toolbox → const String
- tooltip → const String
- tooltipBuilder → const String
- type → const String
- valueFormatter → const String
- xAxis → const String
- yAxis → const String