ChartAccessibilityOptions class
Constructors
- ChartAccessibilityOptions({String? semanticLabel, bool excludeFromSemantics = false})
-
const
Properties
- excludeFromSemantics → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
Methods
-
copyWith(
{String? semanticLabel, bool? excludeFromSemantics}) → ChartAccessibilityOptions -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
Widget child, {String? fallbackLabel, bool image = true, bool container = true}) → Widget
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- decorative → const ChartAccessibilityOptions