AsyncChartProcessingReport class
Constructors
- AsyncChartProcessingReport({required bool usedIsolate, required bool isolateEligible, required int isolatePointThreshold, required int dataPointCount, required Duration totalDuration, required ChartDataProcessingReport processingReport, bool processingCacheWritten = false, ChartDataCacheWriteReason? processingCacheWriteReason, ChartDataCacheAdmissionReason? processingCacheWriteAdmissionReason, int? processingCacheWriteEstimatedBytes, int? processingCacheWriteMaxBytes})
-
const
Properties
- cacheHit → bool
-
no setter
- dataPointCount → int
-
final
- effectiveDataPointCount → int
-
no setter
- effectiveDataPointRatio → double
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isolateEligible → bool
-
final
- isolatePointThreshold → int
-
final
- isViewportReduced → bool
-
no setter
- outputPointCount → int
-
no setter
- performanceSummary → ChartPerformanceSummary
-
no setter
- processingCacheWriteAdmissionReason → ChartDataCacheAdmissionReason?
-
final
- processingCacheWriteEstimatedBytes → int?
-
final
- processingCacheWriteMaxBytes → int?
-
final
- processingCacheWriteReason → ChartDataCacheWriteReason?
-
final
- processingCacheWritten → bool
-
final
- processingReport → ChartDataProcessingReport
-
final
- reducedPointCount → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleInputPointCount → int
-
no setter
- samplingOutputRatio → double
-
no setter
- samplingReductionRatio → double
-
no setter
- totalDuration → Duration
-
final
- usedIsolate → bool
-
final
- viewportReductionRatio → double
-
no setter
- wasDownsampled → bool
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited