AsyncChartProcessor class
Moves heavy chart processing (LTTB, stats, binning) off the UI thread.
The isolate decision is based on effective data-point count, not series count: one visible 100k-point series should be offloaded, while 10k empty series or a tiny zoom window should not.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
processAsync(
List< Series> series, {int renderThreshold = 500, SamplingStrategy? samplingStrategy, int? startIndex, int? endIndex, bool? useCache, String? dataSignature, bool? useIsolate, int? isolatePointThreshold, void onReport(AsyncChartProcessingReport report)?}) → Future<ChartProcessingResult> -
processAsyncWithReport(
List< Series> series, {int renderThreshold = 500, SamplingStrategy? samplingStrategy, int? startIndex, int? endIndex, bool? useCache, String? dataSignature, bool? useIsolate, int? isolatePointThreshold}) → Future<AsyncChartProcessingResult> -
shouldUseIsolate(
List< Series> series, {bool? useIsolate, int? startIndex, int? endIndex, int? isolatePointThreshold}) → bool