ChartFactory class
Factory class for creating charts from configurations or JSON
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createChart(
BaseChartConfig config) → Widget - Create a chart from a configuration object
-
fromJson(
Map< String, dynamic> json, {bool validatePayload = false, bool strictValidation = false, void onValidationResult(ValidationResult result)?, void onPayloadNormalizationResult(PayloadNormalizationResult result)?, bool autoNormalizePayload = false, bool sanitizeTradingPayload = true, bool dropUnsupportedSampling = true, int? normalizeDefaultThreshold, ChartDataMode normalizeDefaultMode = ChartDataMode.auto, PayloadNormalizationOptions? normalizationOptions, int validationReportMaxIssues = 5}) → BaseChartConfig - Create a chart configuration from JSON
-
fromJsonToChart(
Map< String, dynamic> json, {bool autoNormalizePayload = false, bool sanitizeTradingPayload = true, bool dropUnsupportedSampling = true, int? normalizeDefaultThreshold, ChartDataMode normalizeDefaultMode = ChartDataMode.auto, PayloadNormalizationOptions? normalizationOptions, void onPayloadNormalizationResult(PayloadNormalizationResult result)?, bool validatePayload = false, bool strictValidation = false, void onValidationResult(ValidationResult result)?, int validationReportMaxIssues = 5}) → Widget - Create and build a chart directly from JSON