catchRenderErrors property
Render JSON payload failures as a diagnostic fallback by default.
Set this to false when tests or developer tools should observe the raw chart parsing/render exception.
Implementation
final bool catchRenderErrors;
Render JSON payload failures as a diagnostic fallback by default.
Set this to false when tests or developer tools should observe the raw chart parsing/render exception.
final bool catchRenderErrors;