PayloadNormalizationResult class
Constructors
-
PayloadNormalizationResult({required Map<
String, dynamic> rawPayload, required Map<String, dynamic> normalizedPayload, required bool wasNormalized, required List<PayloadDiff> diffs}) -
const
-
PayloadNormalizationResult.passThrough(Map<
String, dynamic> payload) -
factory
Properties
-
addedDiffs
→ List<
PayloadDiff> -
no setter
- changed → bool
-
no setter
-
changedDiffs
→ List<
PayloadDiff> -
no setter
-
changedPaths
→ List<
String> -
no setter
-
diffs
→ List<
PayloadDiff> -
final
-
effectivePayload
→ Map<
String, dynamic> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
normalizedPayload
→ Map<
String, dynamic> -
final
-
rawPayload
→ Map<
String, dynamic> -
final
-
removedDiffs
→ List<
PayloadDiff> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → PayloadDiffSummary
-
no setter
- wasNormalized → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{bool includePayloads = false, bool includeDiffValues = false}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited