ValidationReport class
Constructors
-
ValidationReport({required ChartType type, required List<
ValidationIssue> issues, int maxIssues = 8}) -
const
- ValidationReport.fromResult(ValidationResult result, {int maxIssues = 8})
-
factory
Properties
- compactMessage → String
-
no setter
-
counts
→ Map<
String, int> -
no setter
-
errors
→ List<
ValidationIssue> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasIssues → bool
-
no setter
- hasMoreIssues → bool
-
no setter
- hasWarnings → bool
-
no setter
-
infos
→ List<
ValidationIssue> -
no setter
-
issues
→ List<
ValidationIssue> -
final
- isValid → bool
-
no setter
- maxIssues → int
-
final
- normalizedMaxIssues → int
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
no setter
-
suggestions
→ List<
String> -
no setter
- title → String
-
no setter
- type → ChartType
-
final
-
visibleIssues
→ Iterable<
ValidationIssue> -
no setter
-
visibleReportIssues
→ List<
ValidationReportIssue> -
no setter
-
warnings
→ List<
ValidationIssue> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toPlainText(
{bool includeSuggestions = true}) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited