ValidationReportIssue class
Constructors
- ValidationReportIssue({required ValidationIssue issue, required int index})
-
const
Properties
- displayText → String
-
no setter
- fieldPath → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSuggestion → bool
-
no setter
- index → int
-
final
- issue → ValidationIssue
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suggestionText → String
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited