ChartSelection class

Represents a selected data point.

Constructors

ChartSelection({required int seriesIndex, required int dataIndex, dynamic value})
const

Properties

dataIndex int
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seriesIndex int
final
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
snapshot() ChartSelection
Returns an immutable snapshot for JSON-like selected values.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override