ChartDataProcessingCachePolicySnapshot class
Immutable cache-policy values captured for a single processing run.
Constructors
- ChartDataProcessingCachePolicySnapshot({bool enabled = true, int maxEntries = 32, int maxBytes = 32 * 1024 * 1024, int minPointCount = 1000, bool extractionCacheEnabled = true, int maxExtractionEntries = 128, int maxExtractionBytes = 32 * 1024 * 1024, int minExtractionPointCount = 1000})
-
const
- ChartDataProcessingCachePolicySnapshot.fromCurrentConfig()
-
factory
Properties
- enabled → bool
-
final
- extractionCacheEnabled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxBytes → int
-
final
- maxEntries → int
-
final
- maxExtractionBytes → int
-
final
- maxExtractionEntries → int
-
final
- minExtractionPointCount → int
-
final
- minPointCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited