ChartDiagnosticFallbackFields class
Shared diagnostic fallback field names and parsing helpers.
Kept dependency-free so widget options and payload validation can stay in sync without introducing a core-to-widget import.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- suggestion → String
-
no setter
Static Methods
-
containsAny(
Map< Object?, Object?> map) → bool -
isBooleanLike(
Object? raw) → bool -
isNonNegativeIntegerLike(
Object? raw) → bool -
isPreset(
String value) → bool -
parseBool(
Object? raw) → bool? -
parseNonNegativeInt(
Object? raw) → int? -
path(
String prefix, String field) → String -
schemaJson(
) → List< Map< String, dynamic> >
Constants
-
allFields
→ const Set<
String> -
canonicalFields
→ const List<
String> - detailMessage → const String
- detailMessageSpec → const ChartDiagnosticFallbackFieldSpec
- diagnosticFallback → const String
- diagnosticFallbackOptions → const String
- diagnostics → const String
-
diagnosticsContainerFields
→ const List<
String> - fallback → const String
- fallbackOptions → const String
-
fieldSpecs
→ const List<
ChartDiagnosticFallbackFieldSpec> - maxQuickFixes → const String
- maxQuickFixesSpec → const ChartDiagnosticFallbackFieldSpec
- message → const String
- messageSpec → const ChartDiagnosticFallbackFieldSpec
- preset → const String
- presetSpec → const ChartDiagnosticFallbackFieldSpec
-
presetValues
→ const Set<
String> - showDoctorSummary → const String
- showDoctorSummarySpec → const ChartDiagnosticFallbackFieldSpec
- showErrorDetails → const String
- showErrorDetailsSpec → const ChartDiagnosticFallbackFieldSpec
- showQuickFixes → const String
- showQuickFixesSpec → const ChartDiagnosticFallbackFieldSpec
- showValidationDetails → const String
- showValidationDetailsSpec → const ChartDiagnosticFallbackFieldSpec
- title → const String
- titleSpec → const ChartDiagnosticFallbackFieldSpec
-
topLevelContainerFields
→ const List<
String>