ChartExportResult class
Constructors
- ChartExportResult({required ChartExportFormat format, required String mimeType, required String filename, Uint8List? bytes, String? text, String? error, Duration? duration})
-
const
- ChartExportResult.bytes({required ChartExportFormat format, required String filename, required Uint8List bytes, Duration? duration})
-
factory
- ChartExportResult.failure({required ChartExportFormat format, required String filename, required String error, Duration? duration})
-
factory
- ChartExportResult.text({required ChartExportFormat format, required String filename, required String text, Duration? duration})
-
factory
Properties
- base64Payload → String?
-
no setter
- bytes → Uint8List?
-
final
- dataUri → String?
-
no setter
- duration → Duration?
-
final
- error → String?
-
final
- filename → String
-
final
- format → ChartExportFormat
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBinary → bool
-
no setter
- isText → bool
-
no setter
- mimeType → String
-
final
- payloadBytes → Uint8List?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
no setter
- success → bool
-
no setter
- text → String?
-
final
Methods
-
byteSignature(
{int maxBytes = 12}) → String? -
contentDisposition(
{bool attachment = true}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preview(
{int maxTextChars = 160, int maxBytes = 12}) → String -
textPreview(
{int maxChars = 160}) → String? -
toMetadataJson(
{bool includePayload = false}) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
-
withDuration(
Duration duration) → ChartExportResult
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited