ChartExportCapabilities class
Constructors
-
ChartExportCapabilities(Iterable<
ChartExportCapability> capabilities) -
ChartExportCapabilities.evaluate({Iterable<
ChartExportFormat> formats = ChartExportFormat.values, BaseChartConfig? config, Map<String, dynamic> ? jsonConfig, List<List< ? rows, GlobalKey<Object?> >State< ? boundaryKey})StatefulWidget> > -
factory
Properties
-
capabilities
→ List<
ChartExportCapability> -
final
-
exportableFormats
→ List<
ChartExportFormat> -
no setter
-
formats
→ List<
ChartExportFormat> -
no setter
- hasExportableFormats → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
no setter
Methods
-
canExport(
ChartExportFormat format) → bool -
capabilityFor(
ChartExportFormat format) → ChartExportCapability -
disabledReason(
ChartExportFormat format) → String? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMetadataJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
disabledReasonFor(
ChartExportFormat format, {required bool hasDataSource, required bool hasBoundaryKey}) → String? -
evaluateFormat(
ChartExportFormat format, {required bool hasDataSource, required bool hasBoundaryKey}) → ChartExportCapability