ChartExportCapability class
Constructors
- ChartExportCapability({required ChartExportFormat format, required bool canExport, String? disabledReason})
-
const
- ChartExportCapability.available(ChartExportFormat format)
-
factory
-
factory
Properties
- canExport → bool
-
final
- disabledReason → String?
-
final
- format → ChartExportFormat
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMetadataJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited