ChartExportCompositeDeliveryAdapter class

Implemented types

Constructors

ChartExportCompositeDeliveryAdapter(Iterable<ChartExportDeliveryAdapter> adapters, {ChartExportDeliveryIntent intent = ChartExportDeliveryIntent.custom, bool stopOnFirstFailure = true})

Properties

adapters List<ChartExportDeliveryAdapter>
final
hashCode int
The hash code for this object.
no setterinherited
intent ChartExportDeliveryIntent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopOnFirstFailure bool
final

Methods

deliver(ChartExportFile file) Future<ChartExportDeliveryResult>
override
deliverAll(Iterable<ChartExportFile> files) Future<ChartExportDeliveryBatchResult>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited