ChartExportDeliveryResult class
Constructors
-
ChartExportDeliveryResult.failure({ChartExportFile? file, required Object error, StackTrace? stackTrace, int attempts = 1, Iterable<
String> retryErrors = const [], Map<String, Object?> metadata = const {}, Duration? duration}) -
factory
-
ChartExportDeliveryResult.success(ChartExportFile file, {int attempts = 1, Iterable<
String> retryErrors = const [], Map<String, Object?> metadata = const {}, Duration? duration}) -
factory
Properties
- attempts → int
-
final
- duration → Duration?
-
final
- error → Object?
-
final
- errorText → String?
-
no setter
- file → ChartExportFile?
-
final
- filename → String?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, Object?> -
final
-
retryErrors
→ List<
String> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
no setter
- stackTrace → StackTrace?
-
final
- success → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMetadataJson(
{bool includePayload = false}) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
-
withDuration(
Duration duration) → ChartExportDeliveryResult
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited