ChartExportFile class
Constructors
-
ChartExportFile({required String filename, required String mimeType, required Uint8List bytes, String? text, ChartExportFormat? format, Map<
String, Object?> metadata = const {}}) - ChartExportFile.fromResult(ChartExportResult result)
-
factory
Properties
- base64Payload → String
-
no setter
- bytes → Uint8List
-
final
- dataUri → String
-
no setter
- extension → String
-
no setter
- filename → String
-
final
- format → ChartExportFormat?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isBinary → bool
-
no setter
- isText → bool
-
no setter
-
metadata
→ Map<
String, Object?> -
final
- mimeType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sizeBytes → int
-
no setter
- text → String?
-
final
Methods
-
contentDisposition(
{bool attachment = true}) → String -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMetadataJson(
{bool includePayload = false}) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
tryFromResult(
ChartExportResult result) → ChartExportFile?