ChartExportJobEvent class
Constructors
-
ChartExportJobEvent({required ChartExportJobEventType type, required ChartExportJobStage stage, required String message, DateTime? timestamp, int? completed, int? total, ChartExportJobStatus? status, ChartExportFormat? format, String? filename, Map<
String, Object?> metadata = const {}})
Properties
- completed → int?
-
final
- filename → String?
-
final
- format → ChartExportFormat?
-
final
- fraction → double?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
-
metadata
→ Map<
String, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stage → ChartExportJobStage
-
final
- status → ChartExportJobStatus?
-
final
- timestamp → DateTime
-
final
- total → int?
-
final
- type → ChartExportJobEventType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMetadataJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited