ChartExportManifest class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
deliveryBatchFile(ChartExportDeliveryBatchResult batch, {String filename = defaultDeliveryFilename, DateTime? createdAt, bool includePayload = false, bool pretty = true})
→ ChartExportFile
-
-
deliveryBatchJson(ChartExportDeliveryBatchResult batch, {DateTime? createdAt, bool includePayload = false, bool pretty = true})
→ String
-
-
deliveryBatchMetadata(ChartExportDeliveryBatchResult batch, {DateTime? createdAt, bool includePayload = false})
→ Map<String, Object?>
-
-
exportBatchFile(ChartExportBatchResult batch, {String filename = defaultExportFilename, DateTime? createdAt, bool includePayload = false, bool pretty = true})
→ ChartExportFile
-
-
exportBatchJson(ChartExportBatchResult batch, {DateTime? createdAt, bool includePayload = false, bool pretty = true})
→ String
-
-
exportBatchMetadata(ChartExportBatchResult batch, {DateTime? createdAt, bool includePayload = false})
→ Map<String, Object?>
-