ChartJsonOptionPatchEntry class

Constructors

ChartJsonOptionPatchEntry({required String schemaName, required String canonicalField, required String jsonPath, required Object? value, required bool usedOverride, required bool overwritesExistingValue, required ChartJsonOptionValueValidation validation, Object? previousValue, String? valueKey, bool hasPreviousValue = false, ChartJsonOptionPatchChangeKind changeKind = ChartJsonOptionPatchChangeKind.added})
const

Properties

canonicalField String
final
changeKind ChartJsonOptionPatchChangeKind
final
changesValue bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasPreviousValue bool
final
isValid bool
no setter
jsonPath String
final
jsonPointer String
no setter
overwritesExistingValue bool
final
previousValue Object?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
schemaName String
final
usedOverride bool
final
validation ChartJsonOptionValueValidation
final
value Object?
final
valueKey String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited