ChartConfig class
Constructors
-
ChartConfig({ChartType? type, double? maxValueY, double? maxY, TitlesData? title, ChartTooltip? tooltip, ChartLegend? legend, ChartToolbox? toolbox, GridData? grid, XYAxis? xAxis, XYAxis? yAxis, List<
Series> series = const []}) -
ChartConfig.fromJson(Map<
String, dynamic> json) -
factory
Properties
- grid → GridData?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- legend → ChartLegend?
-
final
- maxValueY → double?
-
final
- maxY → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
series
→ List<
Series> -
final
- title → TitlesData?
-
final
- toolbox → ChartToolbox?
-
final
- tooltip → ChartTooltip?
-
final
- type → ChartType?
-
final
- xAxis → XYAxis?
-
final
- yAxis → XYAxis?
-
final
Methods
-
getMax(
) → double -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited