ChartPayloadNormalizationFields class
Shared payload normalization field names and parsing helpers.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- suggestion → String
-
no setter
Static Methods
-
isBooleanLike(
Object? raw) → bool -
isDataMode(
Object? raw) → bool -
isPositiveIntegerLike(
Object? raw) → bool -
parseBool(
Object? raw) → bool? -
parsePositiveInt(
Object? raw) → int? -
path(
String prefix, String field) → String -
schemaJson(
) → List< Map< String, dynamic> >
Constants
-
allFields
→ const Set<
String> - autoNormalizePayload → const String
- autoNormalizePayloadSpec → const ChartPayloadNormalizationFieldSpec
-
canonicalFields
→ const List<
String> -
dataModeValues
→ const Set<
String> - defaultMode → const String
- defaultModeSpec → const ChartPayloadNormalizationFieldSpec
- defaultThreshold → const String
- defaultThresholdSpec → const ChartPayloadNormalizationFieldSpec
- diagnostics → const String
-
diagnosticsContainerFields
→ const List<
String> - dropUnsupportedSampling → const String
- dropUnsupportedSamplingSpec → const ChartPayloadNormalizationFieldSpec
-
fieldSpecs
→ const List<
ChartPayloadNormalizationFieldSpec> - maxInlineLength → const String
- maxInlineLengthSpec → const ChartPayloadNormalizationFieldSpec
- normalization → const String
- normalizationOptions → const String
- payloadNormalization → const String
- sanitizeTradingPayload → const String
- sanitizeTradingPayloadSpec → const ChartPayloadNormalizationFieldSpec
-
topLevelContainerFields
→ const List<
String>