RenderLayer class abstract
One composable layer in a ChartRenderPipeline.
- Implementers
Constructors
Properties
- cacheable → bool
-
Whether this layer should be cached as a ui.Picture.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirty → bool
-
Whether this layer needs to be re-recorded on the next paint.
no setter
- name → String
-
Human-readable name — used for debug logging and profiling.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
markDirty(
) → void - Mark this layer as dirty — will be re-recorded next frame.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onSizeChanged(
Size size) → void -
Called when canvas
sizechanges so layers can recompute geometry. -
paint(
Canvas canvas, Size size) → void -
Draw this layer onto
canvas. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited