TooltipLayer class
- Inheritance
-
- Object
- BaseRenderLayer
- TooltipLayer
Constructors
-
TooltipLayer({required ChartTheme theme, List<
String> ? lines, Offset? anchor})
Properties
- anchor ↔ Offset?
-
getter/setter pair
- cacheable → bool
-
Whether this layer should be cached as a ui.Picture.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- isDirty → bool
-
Whether this layer needs to be re-recorded on the next paint.
no setterinherited
-
lines
↔ List<
String> ? -
getter/setter pair
- name → String
-
Human-readable name — used for debug logging and profiling.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → ChartTheme
-
final
Methods
-
clearDirty(
) → void -
Call at the end of paint to clear the dirty flag.
inherited
-
markDirty(
) → void -
Mark this layer as dirty — will be re-recorded next frame.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onSizeChanged(
Size size) → void -
Called when canvas
sizechanges so layers can recompute geometry.inherited -
paint(
Canvas canvas, Size size) → void -
Draw this layer onto
canvas.override -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited