ChartRuntimePerformanceSummary class

Actionable runtime roll-up for JSON/config-driven chart rendering.

Constructors

ChartRuntimePerformanceSummary({required int sourceDataPointCount, int? effectiveDataPointCount, int? sampleInputPointCount, required int renderedDataPointCount, required int seriesCount, required bool configSampledData, required bool payloadWasNormalized, required bool payloadChanged, required bool largeUnsampled, required double renderedOutputRatio, required double renderedReductionRatio, double? samplingOutputRatio, double? samplingReductionRatio, required double processingCacheHitRate, required double extractionCacheHitRate, required double? processingCacheMemoryPressure, required double? renderCacheHitRate, required int? renderCacheRequests, required double? pictureCacheMemoryPressure, required ChartRuntimePerformanceSeverity severity, required ChartRuntimePerformanceRecommendation recommendation, ChartRuntimePerformancePolicy policy = ChartRuntimePerformancePolicy.defaults})
const
ChartRuntimePerformanceSummary.fromRuntimeInputs({required int sourceDataPointCount, int? effectiveDataPointCount, int? sampleInputPointCount, required int renderedDataPointCount, required int seriesCount, required bool configSampledData, required bool payloadWasNormalized, required bool payloadChanged, required ChartDataProcessingCacheStats processingCacheStats, ChartRenderCacheStats? renderCacheStats, PictureCacheStats? pictureCacheStats, ChartRuntimePerformancePolicy policy = ChartRuntimePerformancePolicy.defaults})
factory

Properties

configSampledData bool
final
effectiveDataPointCount int?
final
extractionCacheHitRate double
final
hashCode int
The hash code for this object.
no setterinherited
hasRecommendation bool
no setter
largeUnsampled bool
final
payloadChanged bool
final
payloadWasNormalized bool
final
pictureCacheMemoryPressure double?
final
policy ChartRuntimePerformancePolicy
final
processingCacheHitRate double
final
processingCacheMemoryPressure double?
final
recommendation ChartRuntimePerformanceRecommendation
final
recommendationHint String
no setter
renderCacheHitRate double?
final
renderCacheRequests int?
final
renderedDataPointCount int
final
renderedOutputRatio double
final
renderedReductionRatio double
final
requiresAction bool
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleInputPointCount int?
final
samplingOutputRatio double?
final
samplingReductionRatio double?
final
seriesCount int
final
severity ChartRuntimePerformanceSeverity
final
sourceDataPointCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited