ChartRuntimePerformancePolicyFields class
Shared runtime performance policy field names and parsing helpers.
Kept dependency-free so both diagnostics and payload validation can use the same aliases without creating import cycles.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- suggestion → String
-
no setter
Static Methods
-
aliasesFor(
String canonicalField) → List< String> -
canonicalFieldFor(
String field) → String? -
containsAny(
Map< Object?, Object?> map) → bool -
firstField(
Map< Object?, Object?> map, Iterable<String> aliases) → String? -
kindFor(
String field) → ChartRuntimePerformancePolicyFieldKind? -
parseInt(
Object? raw) → int? -
parsePositiveInt(
Object? raw) → int? -
parseRatio(
Object? raw) → double? -
path(
String prefix, String field) → String -
readInt(
Map< Object?, Object?> map, Iterable<String> aliases) → int? -
readRatio(
Map< Object?, Object?> map, Iterable<String> aliases) → double? -
readValue(
Map< Object?, Object?> map, Iterable<String> aliases) → Object? -
schemaJson(
) → List< Map< String, dynamic> >
Constants
-
allAliases
→ const Set<
String> - cachePressureWarningThreshold → const String
-
cachePressureWarningThresholdAliases
→ const List<
String> - cachePressureWarningThresholdSpec → const ChartRuntimePerformancePolicyFieldSpec
-
canonicalFields
→ const List<
String> -
fieldSpecs
→ const List<
ChartRuntimePerformancePolicyFieldSpec> - largeDatasetPointThreshold → const String
-
largeDatasetPointThresholdAliases
→ const List<
String> - largeDatasetPointThresholdSpec → const ChartRuntimePerformancePolicyFieldSpec
- lowRenderCacheHitRateThreshold → const String
-
lowRenderCacheHitRateThresholdAliases
→ const List<
String> - lowRenderCacheHitRateThresholdSpec → const ChartRuntimePerformancePolicyFieldSpec
- lowRenderCacheMinRequests → const String
-
lowRenderCacheMinRequestsAliases
→ const List<
String> - lowRenderCacheMinRequestsSpec → const ChartRuntimePerformancePolicyFieldSpec