ChartTypography class
Constructors
- ChartTypography({double titleSize = 16, double subtitleSize = 13, double axisLabelSize = 11, double axisTitleSize = 12, double legendSize = 12, double tooltipSize = 12, double dataLabelSize = 10, String fontFamily = '', FontWeight titleWeight = FontWeight.w600, FontWeight labelWeight = FontWeight.w400})
-
const
Properties
- axisLabelSize → double
-
final
- axisLabelStyle → TextStyle
-
no setter
- axisTitleSize → double
-
final
- dataLabelSize → double
-
final
- dataLabelStyle → TextStyle?
-
no setter
- fontFamily → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- labelWeight → FontWeight
-
final
- legendSize → double
-
final
- legendStyle → TextStyle
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subtitleSize → double
-
final
- titleSize → double
-
final
- titleStyle → TextStyle
-
no setter
- titleWeight → FontWeight
-
final
- tooltipSize → double
-
final
- tooltipStyle → TextStyle
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited