ValidatedChartAutoSwitchResult class
Auto-switch result plus post-switch payload validation.
Constructors
- ValidatedChartAutoSwitchResult({required ChartAutoSwitchResult switchResult, required ValidationResult? validation})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWarnings → bool
-
no setter
- isRenderSafe → bool
-
no setter
- message → String
-
no setter
-
payload
→ Map<
String, dynamic> ? -
no setter
- renderSafetyMessage → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedType → ChartType?
-
no setter
- selectedTypeString → String?
-
no setter
- success → bool
-
no setter
- switchResult → ChartAutoSwitchResult
-
final
- validation → ValidationResult?
-
final
-
validationErrors
→ List<
ValidationIssue> -
no setter
-
validationWarnings
→ List<
ValidationIssue> -
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{bool includePayload = false}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited