GridData class
Constructors
-
GridData({bool? show, String? id, double? left, double? top, double? right, double? bottom, double? width, double? height, bool? containLabel, String? backgroundColor, String? borderColor, double? borderWidth, double horizontalInterval = 0.5, String horizontalColor = 'rgba(0, 0, 0, 0.1)', double horizontalWidth = 0.5, List<
int> horizontalDashArray = const [5, 5], String verticalColor = 'rgba(0, 0, 0, 0.1)', double verticalWidth = 0.5, List<int> verticalDashArray = const [5, 5], bool showHorizontalLines = true, bool showVerticalLines = true, String color = 'rgba(0, 0, 0, 0.1)', ChartLineStyle? lineStyle}) - GridData.fromJson(Object? raw)
-
factory
Properties
- backgroundColor ↔ String?
-
getter/setter pair
- borderColor ↔ String?
-
getter/setter pair
- borderWidth ↔ double?
-
getter/setter pair
- bottom ↔ double?
-
getter/setter pair
- color ↔ String
-
getter/setter pair
- containLabel ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double?
-
getter/setter pair
- horizontalColor ↔ String
-
getter/setter pair
-
horizontalDashArray
↔ List<
int> -
getter/setter pair
- horizontalInterval ↔ double
-
getter/setter pair
- horizontalWidth ↔ double
-
getter/setter pair
- id ↔ String?
-
getter/setter pair
- left ↔ double?
-
getter/setter pair
- lineStyle ↔ ChartLineStyle
-
getter/setter pair
- right ↔ double?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- show ↔ bool?
-
getter/setter pair
- showHorizontalLines ↔ bool
-
getter/setter pair
- showVerticalLines ↔ bool
-
getter/setter pair
- top ↔ double?
-
getter/setter pair
- verticalColor ↔ String
-
getter/setter pair
-
verticalDashArray
↔ List<
int> -
getter/setter pair
- verticalWidth ↔ double
-
getter/setter pair
- width ↔ double?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited