TenunOptionBuildResult class
Non-throwing result for direct TenunOption config building.
Constructors
-
TenunOptionBuildResult({required Map<
String, dynamic> payload, required ValidationResult validation, required BaseChartConfig? config, required Object? error, required StackTrace? stackTrace, required bool buildAttempted}) -
const
Properties
- buildAttempted → bool
-
final
- config → BaseChartConfig?
-
final
- error → Object?
-
final
- hasErrors → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasWarnings → bool
-
no setter
- isRenderSafe → bool
-
no setter
- message → String
-
no setter
-
payload
→ Map<
String, dynamic> -
final
- resolved → bool
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
final
- success → bool
-
no setter
- validation → ValidationResult
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{bool includePayload = false, bool includeStackTrace = false}) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited