ChartTextStyle class
Constructors
- ChartTextStyle({String color = 'black', FontStyle? fontStyle = FontStyle.normal, FontWeight? fontWeight = FontWeight.normal, String? fontFamily = 'sans-serif', double? fontSize = 12.0, Align? align = Align.middle, Align? verticalAlign = Align.middle, double? lineHeight = 1.2, String? backgroundColor = 'transparent', String? borderColor = 'black', double? borderWidth = 0.0, double? borderRadius = 0.0, double? padding = 0.0})
- ChartTextStyle.fromJson(Object? raw)
-
factory
Properties
- align → Align?
-
final
- backgroundColor → String?
-
final
- borderColor → String?
-
final
- borderRadius → double?
-
final
- borderWidth → double?
-
final
- color → String
-
final
- fontFamily → String?
-
final
- fontSize → double?
-
final
- fontStyle → FontStyle?
-
final
- fontWeight → FontWeight?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lineHeight → double?
-
final
- padding → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verticalAlign → Align?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited