XYAxis class
Constructors
- XYAxis({String? id, AxisType? type, String? name, String? position, bool? inverse, dynamic boundaryGap, dynamic min, dynamic max, bool? scale, int? splitNumber, int? minInterval, int? interval, int? maxInterval, double? logBase, bool? silent, bool? triggerEvent, AxisLine? axisLine, AxisTick? axisTick, AxisLabel? axisLabel, SplitLine? splitLine, SplitArea? splitArea, List? data, XAxisPointer? axisPointer, String nameColor = 'rgba(0, 0, 0, 0.1)', double nameSize = 12, double fontSize = 10, String color = 'rgba(0, 0, 0, 0.1)', bool? show, Function? formatter, int? precision})
- XYAxis.fromJson(Object? raw)
-
factory
Properties
- axisLabel ↔ AxisLabel?
-
getter/setter pair
- axisLine ↔ AxisLine?
-
getter/setter pair
- axisPointer ↔ XAxisPointer?
-
getter/setter pair
- axisTick ↔ AxisTick?
-
getter/setter pair
- boundaryGap ↔ dynamic
-
getter/setter pair
- color ↔ String
-
getter/setter pair
- data ↔ List?
-
getter/setter pair
- fontSize ↔ double
-
getter/setter pair
- formatter ↔ Function?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ String?
-
getter/setter pair
- interval ↔ int?
-
getter/setter pair
- inverse ↔ bool?
-
getter/setter pair
- logBase ↔ double?
-
getter/setter pair
- max ↔ dynamic
-
getter/setter pair
- maxInterval ↔ int?
-
getter/setter pair
- min ↔ dynamic
-
getter/setter pair
- minInterval ↔ int?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- nameColor ↔ String
-
getter/setter pair
- nameSize ↔ double
-
getter/setter pair
- position ↔ String?
-
getter/setter pair
- precision ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scale ↔ bool?
-
getter/setter pair
- show ↔ bool?
-
getter/setter pair
- silent ↔ bool?
-
getter/setter pair
- splitArea ↔ SplitArea?
-
getter/setter pair
- splitLine ↔ SplitLine?
-
getter/setter pair
- splitNumber ↔ int?
-
getter/setter pair
- triggerEvent ↔ bool?
-
getter/setter pair
- type ↔ AxisType?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited