ZoomableTenunChart class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- ZoomableTenunChart
- Available extensions
Constructors
- ZoomableTenunChart({Key? key, BaseChartConfig? config, ChartDrillDownController? drillController, double? width, double? height, EdgeInsetsGeometry padding = EdgeInsets.zero, ZoomConstraints zoomConstraints = const ZoomConstraints(), bool showMinimap = false, bool showResetButton = true, bool showBreadcrumbs = true, double minimapHeight = 28, void onTap(double fraction, ChartZoomController zoom)?, void onCrosshairMove(double fraction)?, void onCrosshairEnd()?, void onDoubleTap(double fraction, ChartZoomController zoom)?, ChartZoomController? zoomController})
-
const
- ZoomableTenunChart.drillDown({Key? key, required ChartDrillDownController drillController, double? width, double? height, EdgeInsetsGeometry padding = EdgeInsets.zero, ZoomConstraints zoomConstraints = const ZoomConstraints(), bool showMinimap = false, bool showResetButton = true, bool showBreadcrumbs = true, double minimapHeight = 28, void onTap(double fraction, ChartZoomController zoom)?, void onCrosshairMove(double fraction)?, void onCrosshairEnd()?, void onDoubleTap(double fraction, ChartZoomController zoom)?, ChartZoomController? zoomController})
-
Convenience constructor for drill-down mode.
const
Properties
- apiContract → ChartApiContract?
-
Available on Widget, provided by the ChartWidgetApiContractExtension extension
no setter - config → BaseChartConfig?
-
final
- drillController → ChartDrillDownController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- minimapHeight → double
-
final
- onCrosshairEnd → void Function()?
-
final
- onCrosshairMove → void Function(double fraction)?
-
Called with the x-fraction
0..1during crosshair movement.final - onDoubleTap → void Function(double fraction, ChartZoomController zoom)?
-
Called with the x-fraction when the user double-taps.
final
- onTap → void Function(double fraction, ChartZoomController zoom)?
-
Called with the x-fraction
0..1of the tapped position.final - padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showBreadcrumbs → bool
-
final
- showMinimap → bool
-
final
- showResetButton → bool
-
final
- width → double?
-
final
- zoomConstraints → ZoomConstraints
-
final
- zoomController → ChartZoomController?
-
External zoom controller — pass your own to read the state elsewhere.
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< ZoomableTenunChart> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recommendsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
supportsApiField(
String field) → bool -
Available on Widget, provided by the ChartWidgetApiContractExtension extension
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited