ChartAutoSwitchResult class

Non-throwing result for automatic chart-type switching.

Constructors

ChartAutoSwitchResult({required bool success, required ChartSeriesDataShape sourceShape, required ChartType? selectedType, required ChartSwitchOption? selectedOption, required List<ChartSwitchOption> options, required Map<String, dynamic>? payload, required bool keptCurrentType, required List<String> preservedRuntimeKeys, required List<String> changedTopLevelKeys, required String message})
const

Properties

changedTopLevelKeys List<String>
final
hashCode int
The hash code for this object.
no setterinherited
keptCurrentType bool
final
message String
final
options List<ChartSwitchOption>
final
payload Map<String, dynamic>?
final
preservedRuntimeKeys List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selectedOption ChartSwitchOption?
final
selectedType ChartType?
final
selectedTypeString String?
no setter
sourceShape ChartSeriesDataShape
final
success bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({bool includePayload = false}) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited