ChartSwitchGroup class

Runtime switch compatibility group for a data shape.

Constructors

ChartSwitchGroup({required ChartSeriesDataShape dataShape, required List<ChartCapabilities> charts})
const

Properties

charts List<ChartCapabilities>
final
count int
no setter
dataShape ChartSeriesDataShape
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
typeStrings List<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited