RegistrationBundleAudit class

Audit result for a chart registration bundle.

Constructors

RegistrationBundleAudit({required String bundleName, required int registrationCount, required List<RegistrationAuditIssue> issues})
const

Properties

bundleName String
final
errors List<RegistrationAuditIssue>
no setter
hasErrors bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isClean bool
no setter
issues List<RegistrationAuditIssue>
final
registrationCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
warnings List<RegistrationAuditIssue>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited